/**
 * Class AddressesFeatExtraction
 * @author Dimitra Xidara
 */

package crawling;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Properties;

import crawling.entities.Address;
import crawling.entities.IdDescription;

public class AddressesFeatExtraction {

	private ArrayList<Address> addresses;
	private Connection connection;

	public AddressesFeatExtraction() {
		addresses = new ArrayList<Address>(0);
		openMySQLConnection();
	}

	public void getAddresses(String filename) {
		String source = "";
		try {
			FileInputStream fileInputStream = new FileInputStream(filename);
			InputStreamReader inputStream = new InputStreamReader(fileInputStream,AnnKeywords.UTF8_ENCODING);
			char[] buffer = new char[10000];
			int bytesread = inputStream.read(buffer);
			while (bytesread != -1) {
				String sourcefragment = new String(buffer, 0, bytesread);
				source += sourcefragment;
				buffer = new char[10000];
				bytesread = inputStream.read(buffer);
			}
		} catch (IOException ex) {
			ex.printStackTrace();
		}
		String[] rows = source.split("\n");
		for (String row : rows) {
			String[] words = row.split(",");
			addresses.add(new Address(words[0].replace("\"", ""), words[1]
					.replace("\"", ""), words[2].replace("\"", ""), words[3]
					.replace("\"", ""), words[4].replace("\"", "")));
		}
		addresses.remove(0);
	}
	
	private boolean openMySQLConnection() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			connection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/addressdb", props);

			return true;
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
			return false;
		}
	}

	public void updateDatabase() {
	  for(Address address:addresses){
		  int nomosId = updateNomosTable(address.getNomos());
		  int cityId = updateCityTable(nomosId, address.getCity());
		  int odosId = updateOdoiTable(cityId,address.getStreet());
		  updatePostCodeTable(odosId,address);
	  }
	}

	@SuppressWarnings("finally")
	private int updateNomosTable(String nomos){
		ArrayList<IdDescription> nomoi = selectNomoys();
		for(IdDescription nomo:nomoi){
			if(nomo.getDescription().equals(nomos)){
				return nomo.getId();
			}
		}
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		int nomosId = -1;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO nomoi(DESCRIPTION) VALUES(?)");
			pstmt.setString(1, nomos);
			pstmt.executeUpdate();
			pstmt1 = connection
					.prepareStatement("SELECT MAX(ID) FROM nomoi");
			rset = pstmt1.executeQuery();
			while(rset.next()){
			nomosId = rset.getInt(1);
			}

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return nomosId;
		}
	}
	@SuppressWarnings("finally")
	private ArrayList<IdDescription> selectNomoys(){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> nomoi = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM nomoi";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				nomoi.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return nomoi;
		}
	}
	@SuppressWarnings("finally")
	private int updateCityTable(int nomosId,String city){
		ArrayList<IdDescription> cities = selectCities(nomosId);
		for(IdDescription perioxh:cities){
			if(perioxh.getDescription().equals(city)){
				return perioxh.getId();
			}
		}
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		int cityId = -1;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO perioxes(DESCRIPTION,NOMOS_ID) VALUES(?,?)");
			pstmt.setString(1, city);
			pstmt.setInt(2,nomosId);
			pstmt.executeUpdate();
			pstmt1 = connection
					.prepareStatement("SELECT MAX(ID) FROM perioxes");
			rset = pstmt1.executeQuery();
			while(rset.next()){
			cityId = rset.getInt(1);
			}

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return cityId;
		}
	}
	@SuppressWarnings("finally")
	private ArrayList<IdDescription> selectCities(int nomosId){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> cities = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM perioxes WHERE NOMOS_ID="+nomosId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				cities.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return cities;
		}
	}
	@SuppressWarnings("finally")
	private int updateOdoiTable(int cityId,String street){
		ArrayList<IdDescription> odoi = selectOdoys(cityId);
		for(IdDescription odos:odoi){
			if(odos.getDescription().equals(street) || WordUtilities.findDistance(odos.getDescription(),street)<=1 || odos.getDescription().toUpperCase().equals(street)){
				return odos.getId();
			}
		}
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		int streetId = -1;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO odoi(DESCRIPTION,PERIOXH_ID) VALUES(?,?)");
			pstmt.setString(1, street);
			pstmt.setInt(2,cityId);
			pstmt.executeUpdate();
			pstmt1 = connection
					.prepareStatement("SELECT MAX(ID) FROM odoi");
			rset = pstmt1.executeQuery();
			while(rset.next()){
			streetId = rset.getInt(1);
			}

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return streetId;
		}
	}
	@SuppressWarnings("finally")
	private ArrayList<IdDescription> selectOdoys(int cityId){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> odoi = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM odoi WHERE PERIOXH_ID="+cityId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				odoi.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return odoi;
		}
	}
	private void updatePostCodeTable(int odosId,Address address){
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO postcodes(ODOS_ID,NUMBERS,POSTCODE) VALUES(?,?,?)");
			pstmt.setInt(1, odosId);
			pstmt.setString(2,address.getNumber());
			pstmt.setString(3,address.getPostCode());
			pstmt.executeUpdate();

		} catch (SQLException ex) {
			System.out.println("ERROR...");
//			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}
	}
	public static void main(String[] args) {
		AddressesFeatExtraction addresses = new AddressesFeatExtraction();
		addresses.getAddresses("C:/src/crawling/greek-postcodes.txt");
		addresses.updateDatabase();
	}
}
