/**
 * class AnnFeatExtraction
 * @author Dimitra Xidara 
 */
/****************************************
 * Modified:Syrgiannis Sotirios         *  
 ****************************************/
package crawling;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.IdDescription;

public abstract class AnnFeatExtraction {

	//contains the text of the announcement
	protected String announcement;
	//the second area of the announcement
	protected String secondArea;
	//the id and the description of the main area
	protected IdDescription mainAreaType;
	//the id of the nomos
	protected int nomosId;

	private Connection connection;

	public AnnFeatExtraction(int nomosId, String announcement,
			Connection connection) {
		if (announcement.charAt(0) == ' ') {
			announcement = announcement.substring(1);
		}
		this.announcement = announcement;
		this.connection = connection;
		this.nomosId = nomosId;
		mainAreaType = new IdDescription();
	}

	/**
	 * Edit the announcement and does the announcement feature extraction
	 */
	protected abstract void editAnnFeatures();

	protected void setAreas(String areaPiece) {
		String mainArea;
		// we take every word of the areaPiece
		String[] pieces = areaPiece.split(" ");
		secondArea = null;
		// in every announcement the first word is the main area
		mainArea = pieces[0].trim();
		int size = pieces.length;
		// we do more only if there are more words until the ,
		if (size > 1) {
			String secondWord = pieces[1];
			// some times second word is part of the main area
			// we can understand that if the second word is upper case too
			char[] chars = secondWord.toCharArray();
			boolean isDigit = false; 
			if (chars != null && chars.length > 0) {
				isDigit = Character.isDigit(chars[0]);
			}
			if (!isDigit && Character.isLetter(chars[0])&& secondWord.toUpperCase() == secondWord
					&& !secondWord.endsWith(".") && !secondWord.endsWith("'")&& !secondWord.startsWith("-")) {
				mainArea += " " + secondWord.trim();
				/** ****************************************************** */
				if (size > 2) {
					String thirdWord = pieces[2];
					if (thirdWord.startsWith("(")) {
						// secondArea = secondWord.substring(1);
						for (int i = 2; i < size; i++) {
							String temp = pieces[i];
							if (temp.startsWith("(")) {
								temp = temp.replace("(", "");
							}
							if (temp.endsWith(")")) {
								temp = temp.replace(")", "");
								if (secondArea == null) {
									secondArea = temp;
								} else {
									secondArea += " " + temp;
								}
								break;
							}
							if (secondArea == null) {
								secondArea = temp;
							} else {
								secondArea += " " + temp;
							}
						}
					} else {
						// if thirdWord isn't part of the main area
						// we check if the thirdWord is one of the keywords if
						// so
						// this meens that there is a second area after that or
						// this
						// is the second area
						for (String keyWord : AnnKeywords.SECONDAREA_KEYWORDS) {
							if (keyWord.equals(thirdWord)) {
								secondArea = thirdWord;
								break;
							}
						}
						// if second word isn't one of the keywords we check if
						// this word
						// starts with an upper case character if so we claim
						// that it is part
						// of second area
						if (secondArea == null) {
							char[] secWrdChars = thirdWord.toCharArray();
							if (secWrdChars.length > 0
									&& Character.isUpperCase(secWrdChars[0])) {
								secondArea = thirdWord;
								for (int i = 3; i < size; i++) {
									secondArea += " " + pieces[i];
								}
							}
							// // if size of the pieces' table is 3 and previous
							// // word is
							// // second area third word is second area too.
							// if (size == 4 && secondArea != null) {
							// secondArea += " " + pieces[3];
							// }
							// if the previous word is a keyword then all the
							// other words are
							// second area

						} else {
							// if the previous word is a keyword then all the
							// other words are
							// second area
							for (int i = 3; i < size; i++) {
								secondArea += " " + pieces[i];
							}
						}
					}
				}
				/** ******************************************************************** */
			} else {
				// there is a possibility that second area is between ()
				if (secondWord.startsWith("(")) {
					// secondArea = secondWord.substring(1);
					for (int i = 1; i < size; i++) {
						String temp = pieces[i];
						if (temp.startsWith("(")) {
							temp = temp.replace("(", "");
						}
						if (temp.endsWith(")")) {
							temp = temp.replace(")", "");
							if (secondArea == null) {
								secondArea = temp;
							} else {
								secondArea += " " + temp;
							}
							break;
						}
						if (secondArea == null) {
							secondArea = temp;
						} else {
							secondArea += " " + temp;
						}
					}
				} else {
					// if secondWord isn't part of the main area
					// we check if the secondWord is one of the keywords if so
					// this means that there is a second area after that or this
					// is the second area
					for (String keyWord : AnnKeywords.SECONDAREA_KEYWORDS) {
						if (keyWord.equals(secondWord)) {
							secondArea = secondWord;
							break;
						}
					}
					// if second word isn't one of the keywords we check if this
					// word
					// starts with an upper case character if so we claim that
					// it is part
					// of second area
					if (secondArea == null) {
						char[] secWrdChars = secondWord.toCharArray();
						if (Character.isUpperCase(secWrdChars[0])) {
							secondArea = secondWord;
							for (int i = 2; i < size; i++) {
								secondArea += " " + pieces[i];
							}
						}
						// // if size of the pieces' table is 3 and previous
						// word
						// // is
						// // second area third word is second area too.
						// if (size == 3) {
						// secondArea += " " + pieces[2];
						// }
					} else {
						// if the previous word is a keyword then all the other
						// words are
						// second area
						for (int i = 2; i < size; i++) {
							secondArea += " " + pieces[i];
						}
					}
				}
			}
		}
		if (secondArea != null && secondArea.startsWith("-")) {
			secondArea = secondArea.substring(1);
		}
		ArrayList<IdDescription> perioxes = DatabaseSelectManager
				.getPerioxesOfNomos(nomosId, connection);
		boolean alreadyIn = false;
		for (IdDescription type : perioxes) {
			if (type.getDescription().equals(mainArea) || WordUtilities.findDistance(type.getDescription(),mainArea)<=1 || type.getDescription().toUpperCase().equals(mainArea)
					||mainArea.toUpperCase().equals(type.getDescription())
					||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
				alreadyIn = true;
				mainAreaType.setId(type.getId());
				break;
			}
		}
		if (!alreadyIn) {
			mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
					mainArea, nomosId, connection));
		}

		mainAreaType.setDescription(mainArea);
	}

	protected String getPrice(String[] text){
		
		for (int i=0;i < text.length; i++){
			String text_low =text[i].toLowerCase();
			String text_up = text[i].toUpperCase();
			if((text[i].contains("0"))&&(text_low.equals(text_up))&&(((text[i].contains("."))&&(!text[i].endsWith(".00")))||((text[i].length()==3)&&(text[i].endsWith("0"))))&&(!text[i].contains("-"))){
				return text[i];
			}
		}
		return "";
	}
	protected String getPrice2(String[] text){
		String ant = "";
		for (int i=0;i < text.length;i++){
			if (text[i].contains("€")){
				return text[i].substring(0, text[i].indexOf("€"));
			}
			if ((text[i].contains("ευρώ"))||(text[i].contains("Ευρώ"))){
				return text[i].substring(0, (text[i].indexOf("υρώ"))-1);
			}
			if ((text[i].length()==4)&&((text[i].contains("Ευρώ"))||(text[i].contains("ευρώ")))){
				return ant;
			}
			ant=text[i];
		}
		return "";
	}

	

	protected DoubleStringFormat getEmbadon(String[] text) {
		DoubleStringFormat embadon = null;
		String num;
		if (text.length > 1 && text != null) {
			for (int i = 1; i < text.length; i++) {
				String txt = text[i].trim();
				if (txt.startsWith(AnnKeywords.TM)
						|| txt.startsWith(AnnKeywords.STR)
						|| txt.startsWith(AnnKeywords.STREMMATA)
						|| txt.startsWith(AnnKeywords.STREMMATWN)) {
					num = text[i - 1].trim();
					Double emb = Utilities.toNumber(num);
					if (emb != null) {
						if (txt.startsWith(AnnKeywords.STR)
								|| txt.startsWith(AnnKeywords.STREMMATA)
								|| txt.startsWith(AnnKeywords.STREMMATWN)) {
							embadon = new DoubleStringFormat(num + " " + txt,
									emb * 1000);
						} else {
							embadon = new DoubleStringFormat(num + " " + txt,
									emb);
						}
						break;
					}
				}
			}
		}
		return embadon;
	}

	protected IdDescription getType(String[] text,
			ArrayList<IdDescription> types) {
		for (String txt : text) {
			for (IdDescription type : types) {
				if (txt.equals(type.getDescription())|| txt.equalsIgnoreCase(type.getDescription())|| (WordUtilities.findDistance(txt.toLowerCase(),type.getDescription())<=1)) {
					return type;
				}
			}
		}
		return null;
	}
	
	/**
	 * Returns number of bedrooms in a house
	 * 
	 * @param text
	 * @return number of bedrooms in a house
	 */
	protected String getBedRooms(String[] text) {
		
		for (int i = 0; i < text.length; i++) {
		//System.out.println(text[i].trim());
			//Eishxthei kai h periptwsh pou ta ypnodwmatia anaferontai ws õä
			if((text[i].contains(AnnKeywords.YPD) && text[i].length()<=3)|| 
			  ((text[i].contains(AnnKeywords.YD) &&text[i].length()<=5)))
			{
				System.out.println("ROOM NUMBERS = "+Utilities.getOnlyNumbers(text[i]));
				return(Utilities.getOnlyNumbers(text[i]));	
			}
			if(text[i].contains(AnnKeywords.ypnodwmatia)){
				return	(Utilities.getOnlyNumbers(text[i]));	
			}
			
			if (text[i].equals(AnnKeywords.YD)
					|| text[i].equals(AnnKeywords.YPNODWMATIA)
					|| text[i].equals(AnnKeywords.KREBATOKAMARES)
					|| text[i].equals(AnnKeywords.YPNO)
					|| text[i].equals(AnnKeywords.YPNOY)
					|| text[i].equals(AnnKeywords.YPN)
			      || text[i].equals(AnnKeywords.YPNODWMATIA) ) {  
				//Ean o xarakthrismos gia ta ypnodomatia einai ths morfhs
				//3 aneta ypnodwmatia
				//tote lamvane ws arithmo ton text[i-1] ,dld to aneta
				//enw dhmiourgwntas mia methodo sthn Klash Utilities
				//elegxoume ean to text[i-1] exei mono letters
				//kai an nai lamvanoume to text[i-2] pou einai o pragmatikos arithmos
				if(Utilities.hasOnlyLetters(text[i-1])==true || text[i-1]==null){
					//System.out.println(text[i-1]);
					try{System.out.println("NULL");
					return text[i-2];
					}
					catch(Exception e){
						System.out.println("Wrong");
					}
				}
				
				else{
				return text[i - 1];	
			}
				}
		}
		return null;
	}
	
	/**
	 * Returns phones in an advertisement
	 * 
	 * @param text
	 * @return ArrayList<String> phones in an advertisement
	 */
	protected ArrayList<String> getPhones(String[] text) {
		ArrayList<String> phones = new ArrayList<String>(0);
		for (int i = 0; i < text.length; i++) {
			if (text[i].startsWith(AnnKeywords.THL)||text[i].startsWith(AnnKeywords.THLEFWNO)||
					text[i].startsWith(AnnKeywords.THLMIKRO)||text[i].startsWith(AnnKeywords.THL_ENG)) {
				//phones.add(text[i+1]);
				if(i+2<text.length){
					if(text[i+2].equals("êáé")){
						phones.add(text[i+3]);
					}
				}
				return phones;
			}
		}
		return null;
	}
	
	protected ArrayList<String> getPhones2(String[] text){
		ArrayList<String> phones = new ArrayList<String>(0);
		for (int i=0; i < text.length; i++){
			String text_low =text[i].toLowerCase();
			String text_up = text[i].toUpperCase();
			if ((text[i].contains("-"))&&(text[i].length()>=11)&&(text_low.equals(text_up))){
				if (text[i].length()>13){
					phones.add(text[i].substring(text[i].indexOf("Τηλ.")+3));
				}
				else{
					phones.add(text[i]);
				}
				return phones;
			}
		}
		return null;
	}
	/**
	 * Returns an <code>ArrayList</code> of the levels of the house found in
	 * the text in case of mezoneta there are 2 levels
	 * 
	 * @param text
	 * @param isMezoneta
	 * @returnan <code>ArrayList</code> of the levels of the house found in
	 *           the text in case of mezoneta
	 */
	protected ArrayList<Integer> getOrofoys(String[] text, boolean isMezoneta) {
		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		for (int i = 0; i < text.length; i++) {
			if (text[i].trim().equals(AnnKeywords.OROFOS)||text[i].trim().equals(AnnKeywords.OROFOY)||text[i].trim().equals(AnnKeywords.OROFWN)) {
				if (isMezoneta && i - 3 >= 0 && text[i - 2].equals("-")) {
					Integer temp = getOrofos(text[i - 3].trim());
					if (temp != null) {
						orofoi.add(temp);
					}
					Integer temp2 = getOrofos(text[i - 1].trim());
					if (temp2 != null) {
						orofoi.add(temp2);
					}
					return orofoi;
				}
				if (isMezoneta && i - 1 > 0) {
					String tmp = text[i - 1].trim();
					String[] tmpArray = tmp.split("-");
					if (tmpArray.length > 1) {
						for (String tmp1 : tmpArray) {
							Integer num = getOrofos(tmp1.trim());
							if (num != null) {
								orofoi.add(num);
							}
						}
						return orofoi;
					}
				}
				Integer temp3 = getOrofos(text[i - 1].trim());
				if (temp3 != null) {
					orofoi.add(temp3);
				}
				return orofoi;
			}
			if (text[i].equals(AnnKeywords.ISOGEIO)
					|| text[i].equals(AnnKeywords.YPOGEIO)
					|| text[i].equals(AnnKeywords.ISOGEIO_XWRIS)) {
				if (isMezoneta && i + 2 < text.length
						&& text[i + 1].equals("-")) {
					Integer temp4 = getOrofos(text[i].trim());
					if (temp4 != null) {
						orofoi.add(temp4);
					}
					Integer temp5 = getOrofos(text[i + 2].trim());
					if (temp5 != null) {
						orofoi.add(temp5);
					}
					return orofoi;
				}
				if (isMezoneta && i + 1 < text.length) {
					String tmp = text[i + 1].trim();
					String[] tmpArray = tmp.split("-");
					if (tmpArray.length > 1) {
						for (String tmp1 : tmpArray) {
							Integer num = getOrofos(tmp1.trim());
							if (num != null) {
								orofoi.add(num);
							}
						}
						return orofoi;
					}
				}
				Integer temp6 = getOrofos(text[i].trim());
				if (temp6 != null) {
					orofoi.add(temp6);
				}
				return orofoi;
			}
			if(text[i].length()<=4&&(text[i].endsWith("ïò")||text[i].endsWith("ïõ"))){
				text[i] = text[i].substring(0, text[i].length() - 2);
				try {
					Integer orf = Integer.parseInt(text[i].trim());
					orofoi.add(orf);
					return orofoi;
				} catch (NumberFormatException ex) {
					return null;
				}
			}
		}
		return null;
	}


	protected Integer getOrofos(String temp) {
		if (temp.endsWith("ïò") || temp.endsWith("ïõ")) {
			temp = temp.substring(0, temp.length() - 2);
			try {
				Integer orf = Integer.parseInt(temp.trim());
				return orf;
			} catch (NumberFormatException ex) {
				return null;
			}
		}
		if (temp.equals(AnnKeywords.ISOGEIO)
				|| temp.equals(AnnKeywords.ISOGEIO_XWRIS)) {
			return 0;
		}
		if (temp.equals(AnnKeywords.YPOGEIO)) {
			return -1;
		}
		return null;
	}

	protected String getSxedio(String[] text){
		String sxedio = null;
		for(int i=0;i<text.length;i++){
			String txt = text[i].trim();
			if(txt.equals(AnnKeywords.ENTOS) || txt.equals(AnnKeywords.EKTOS)){
				if(i+1<text.length){
					String tempTxt = text[i+1].trim();
					if(tempTxt.equals(AnnKeywords.SXEDIOY)){
						if(sxedio == null){
							sxedio = txt+" "+AnnKeywords.SXEDIOY;
						}else{
							sxedio += " "+txt+" "+AnnKeywords.SXEDIOY;
						}
					}
				}
			}
		}
		return sxedio;
	}
	
	public Connection getConnection() {
		return connection;
	}

	public void setConnection(Connection connection) {
		this.connection = connection;
	}
}
