/**
 * class HouseFeatExtr
 * @author Dimitra Xidara
 */
package crawling;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.database.DatabaseSelectManager;
import crawling.entities.*;

public class HouseFeatExtr extends AnnFeatExtraction {

	protected HouseAnnouncement annFeatures;

	public HouseFeatExtr(int nomosId,String announcementText, Connection connection) {
		super(nomosId,announcementText, connection);
		annFeatures = new HouseAnnouncement();
		annFeatures.setOtherFeatures(announcement);
		editAnnFeatures();
	}

	/**
	 * Edit the announcement and does the announcement feature extraction
	 @Override
	 */
	protected void editAnnFeatures() {
		String[] annPieces = announcement.split(",");
		String areaPiece = annPieces[0];
		setAreas(areaPiece);
		DoubleStringFormat embadon = null;
		String bedrooms = null;
		String price = null;
		String otherFeatures = annFeatures.getOtherFeatures();

		annPieces = otherFeatures.split(",");
		for (String piece : annPieces) {
			price = getPrice(piece.split(" "));
			if (price != null) {
				String priceNum = Utilities.getOnlyNumbers(price);
				if(!priceNum.equals("")){
					if(price.contains(AnnKeywords.ANA_XRONO)||price.contains(AnnKeywords.ETHSIW)){
						annFeatures.setPrice(Double.parseDouble(priceNum)/12);
					}else{
				annFeatures.setPrice(Double.parseDouble(priceNum));
					}
				otherFeatures = otherFeatures.replace(AnnKeywords.TIMH, "");
				otherFeatures = otherFeatures.replace(AnnKeywords.EYRW, "");
				otherFeatures = otherFeatures.replace(price, "");
				annFeatures.setOtherFeatures(otherFeatures);
				break;
				}
			}
		}

		boolean isMezoneta = false;
		IdDescription typeOfHouse ;
		annPieces = otherFeatures.split(",");
		for(String piece : annPieces){
			typeOfHouse = getType(piece.split(" "), DatabaseSelectManager.getTypesOfHouse(getConnection()));
			if (typeOfHouse != null) {
				if(typeOfHouse.getDescription().equals(AnnKeywords.MEZONETA)){
					isMezoneta = true;
				}
				annFeatures.setType(typeOfHouse);
				otherFeatures = otherFeatures.replace(typeOfHouse.getDescription(), "");
				annFeatures.setOtherFeatures(otherFeatures);
				break;
			}
		}

		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		annPieces = otherFeatures.split(",");
		for(String piece : annPieces){
		orofoi = getOrofoys(piece.split(" "),isMezoneta);
		if(orofoi != null){
			annFeatures.setOrofoi(orofoi);
			for(Integer orf : orofoi){
				otherFeatures = otherFeatures.replace(orf+"ïò","");
				otherFeatures = otherFeatures.replace(orf+"ïõ","");
			}
			otherFeatures = otherFeatures.replace(AnnKeywords.OROFOS,"");
			otherFeatures = otherFeatures.replace(AnnKeywords.ISOGEIO,"");
			otherFeatures = otherFeatures.replace(AnnKeywords.ISOGEIO_XWRIS,"");
			otherFeatures = otherFeatures.replace(AnnKeywords.YPOGEIO,"");
			otherFeatures = otherFeatures.replace(AnnKeywords.HMIOROFOS,"");
			annFeatures.setOtherFeatures(otherFeatures);
			break;
		}
	}		
		
		
		annPieces = otherFeatures.split(",");
		for(String piece : annPieces){
		  bedrooms = getBedRooms(piece.split(" "));
		  if(bedrooms != null){
			  try{
			  annFeatures.setRoomNumber(bedrooms.trim());
			  }catch(NumberFormatException ex){
				  System.out.println(bedrooms+" :IS NOT A NUMBER!!!");
				  ex.printStackTrace();
			  }
			  otherFeatures = otherFeatures.replace(bedrooms+" "+AnnKeywords.YD,"");
			  annFeatures.setOtherFeatures(otherFeatures);
			  break;
		  }
		}
		

		annPieces = otherFeatures.split(" ");
		embadon = getEmbadon(annPieces);
		if(embadon !=null){
			otherFeatures = otherFeatures.replace(embadon.getStringFormat(),"");
			annFeatures.setEmbadon(embadon);
			annFeatures.setOtherFeatures(otherFeatures);
		}
		otherFeatures = annFeatures.getOtherFeatures();
		otherFeatures = otherFeatures.replace(", ,","");
		otherFeatures = otherFeatures.replace(",  ,","");
		otherFeatures = otherFeatures.replace(" ,   , ","");
		otherFeatures = otherFeatures.replace(" ,    ,","");
		otherFeatures = otherFeatures.replace("()","");
		
		char[] characters = otherFeatures.toCharArray();
		int i =0;
		int j = characters.length-1;
		while((i<characters.length) && (Character.isWhitespace(characters[i])|| (characters[i] ==',') || (characters[i]=='-'))){
			i++;
		}
		while((j>=0)&& (Character.isWhitespace(characters[j])|| (characters[j] ==',') || (characters[j]=='-'))){
			j--;
		}
		if(j<=0){
			otherFeatures = "";
		}else{
		otherFeatures = otherFeatures.substring(i,j);
		}
        annFeatures.setOtherFeatures(otherFeatures);
	}

	/**
	 * Returns an <code>ArrayList</code> of the levels of the house found in the text in case of mezoneta 
	 * there are 2 levels
	 * @param text
	 * @param isMezoneta
	 * @returnan <code>ArrayList</code> of the levels of the house found in the text in case of mezoneta 
	 */
	protected ArrayList<Integer> getOrofoys(String[] text, boolean isMezoneta){
		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		for(int i=0;i<text.length;i++){
			if(text[i].trim().equals(AnnKeywords.OROFOS)){
				if(isMezoneta && i-3>=0 && text[i-2].equals("-")){
					Integer temp = getOrofos(text[i-3].trim());
					if(temp != null){
					orofoi.add(temp);
					}
					Integer temp2 = getOrofos(text[i-1].trim());
					if(temp2 != null){
					orofoi.add(temp2);
					}
					return orofoi;
				}
				if(isMezoneta && i-1>0){
					String tmp = text[i-1].trim();
					String[] tmpArray = tmp.split("-");
					if(tmpArray.length>1){
						for(String tmp1 : tmpArray){
							Integer num = getOrofos(tmp1.trim());
							if(num!= null){
								orofoi.add(num);
							}
						}
						return orofoi;
					}
				}
				Integer temp3 =getOrofos(text[i-1].trim());
				if(temp3 != null){
				orofoi.add(temp3);
				}
				return orofoi;
			}
			if(text[i].equals(AnnKeywords.ISOGEIO) || text[i].equals(AnnKeywords.YPOGEIO) || text[i].equals(AnnKeywords.ISOGEIO_XWRIS)){
				if(isMezoneta && i+2<text.length && text[i+1].equals("-")){
					Integer temp4 =getOrofos(text[i].trim());
					if(temp4 != null){
					orofoi.add(temp4);
					}
					Integer temp5 =getOrofos(text[i+2].trim());
					if(temp5 != null){
					orofoi.add(temp5);
					}
					return orofoi;
				}
				if(isMezoneta && i+1<text.length){
					String tmp = text[i+1].trim();
					String[] tmpArray = tmp.split("-");
					if(tmpArray.length>1){
						for(String tmp1 : tmpArray){
							Integer num = getOrofos(tmp1.trim());
							if(num!= null){
								orofoi.add(num);
							}
						}
						return orofoi;
					}
				}
				Integer temp6 =getOrofos(text[i].trim());
				if(temp6 != null){
				orofoi.add(temp6);
				}
				return orofoi;
			}
		}
		return null;
	}
	
	protected Integer getOrofos(String temp){
		if(temp.endsWith("ïò")|| temp.endsWith("ïõ")){
			temp = temp.substring(0,temp.length()-2);
			try{
			Integer orf = Integer.parseInt(temp.trim());
			return orf;
			}catch(NumberFormatException ex){
				return null;
			}
		}
		if(temp.equals(AnnKeywords.ISOGEIO) || temp.equals(AnnKeywords.ISOGEIO_XWRIS)){
			return 0;
		}
		if(temp.equals(AnnKeywords.YPOGEIO)){
			return -1;
		}
		return null;
	}
	/**
	 * Returns number of bedrooms in a house
	 * @param text
	 * @return number of bedrooms in a house
	 */
	protected String getBedRooms(String[] text){
		for(int i =0; i< text.length; i++){
			if(text[i].equals(AnnKeywords.YD) || text[i].equals(AnnKeywords.YPNODWMATIA)||text[i].equals(AnnKeywords.KREBATOKAMARES)|| text[i].equals(AnnKeywords.YPNO)){
				return text[i-1];
			}
		}
		return null;
	}


	
	@Override
	protected void setAreas(String areaPiece) {		
		super.setAreas(areaPiece);
		annFeatures.setMainArea(mainAreaType);
		if (secondArea != null) {
			annFeatures.setSecArea(secondArea);
		}
		String otherFeatures = annFeatures.getOtherFeatures();
		otherFeatures = otherFeatures.replace(mainAreaType.getDescription(), "");
		if(secondArea != null){
		otherFeatures = otherFeatures.replace(secondArea, "");
		}
		annFeatures.setOtherFeatures(otherFeatures);
	}

	public HouseAnnouncement getAnnFeatures() {
		return annFeatures;
	}

	public void setAnnFeatures(HouseAnnouncement annFeatures) {
		this.annFeatures = annFeatures;
	}

}
