/**
 * class Utilities
 * @author Dimitra Xidara
 */
package crawling;

import java.sql.Date;
import java.util.ArrayList;

import crawling.entities.Announcement;

public class Utilities {
	
	public static final String ODOS = "ÏÄÏÓ";
	public static final String ANW = "ÁÍÙ";
	public static final String PALAIO = "ÐÁËÁÉÏ";
	
	/**
	 * Finds if the given word contains only number characters
	 * @param word
	 * @return true if it has only numbers otherwise false
	 */
	public static boolean hasOnlyNumbers(String word){
		char[] wordLetters=word.toCharArray();
		for(char ch:wordLetters){
			if(!Character.isDigit(ch)){
				return false;
			}
		}
		return true;
	}
	/*
	 * Finds if the given word contains only Letters
	 */
	public static boolean hasOnlyLetters(String word)
	{
		char[] wordLetters=word.toCharArray();
		for(char ch:wordLetters){
			if(!Character.isLetter(ch)){
				return false;
			}
		}
		return true;
	}
	
	
	/**
	 * Given a string returns a substring contains only digits
	 * @param number
	 * @return a substring of the given string contains only digits
	 */
	
	public static String getOnlyNumbers(String number){
		char[] chars = number.toCharArray();
		
		String num = "";
		for(char ch:chars){
			if(Character.isDigit(ch)){
				num+=ch;
			}
		}
		return num.trim();
	}
	
	/**
	 * Given a string returns a substring contains only letters
	 * @param text
	 * @return a substring of the given string contains only letters
	 */
	public static String getOnlyLetters(String text){
		char[] chars = text.toCharArray();
		String txt = "";
		for(char ch: chars){
			if(Character.isLetter(ch)){
				txt += ch;
			}
		}
		return txt.trim();
	}

	/**
	 * accepts as parameter a <code>text</code> without blanks 
	 * like 7.877,8089 and it turns this string into double. It can also takes
	 * as parameter a string like test,758 and keep only the number and turn this into double too.
	 * @param text
	 * @return Double format of text else if it looks like 3434,test it returns <code>null</code>
	 */	
		public static Double toNumber(String text){
			char[] textChars = text.toCharArray();
			Integer commaPlace = null;
			String beforeComma="";
			for(int i=0;i<textChars.length;i++){
				if(textChars[i] =='.') continue;
				if(textChars[i]==','){
					commaPlace=i;
					break;
				}
				if(Character.isDigit(textChars[i])){
					beforeComma +=text.substring(i,i+1);
				}
			}
		    Double tempDouble = null;
			if(commaPlace != null){
		    String temp = text.substring(commaPlace+1,text.length());
		     char[] afterCommaChars = temp.toCharArray();
		     String afterComma = "0.";
		     if(beforeComma.equals("")){
		    	 afterComma = "";
		     }
		     for(int i=0;i<afterCommaChars.length;i++){
		    	 if(Character.isDigit(afterCommaChars[i])){
		    		 afterComma += temp.substring(i,i+1);
		    	 }
		     }
		     try{
		    	 if(!afterComma.equals("0.") && !afterComma.equals("")){
		           tempDouble = Double.parseDouble(afterComma.trim());
		    	 }
		     }catch(NumberFormatException ex){
		    	 System.out.println("Error in parsing to Double afterComma string");
		    	 System.out.println(afterComma+": isn't a number");
		    	 ex.printStackTrace();
		     }
			}
			Double befComma = null;
			try{ 
				if(!beforeComma.equals("")){
				 befComma =Double.parseDouble(beforeComma);
				}else{
					return tempDouble;
				}
			}catch(NumberFormatException ex){
				System.out.println("Error in parsing to Double beforeComma string");
				System.out.println(beforeComma+": isn't a number");
				ex.printStackTrace();
			}
			if(tempDouble!= null){
				return tempDouble+befComma;	
			}
			return befComma;
		}
		

		/**
		 * Given the start and the end tag of a given <code>source</code> it returns 
		 * from the first occurence of them the text between them.In case that there is no
		 * match to these tags it returns ""
		 * @param source
		 * @param startTag
		 * @param endTag
		 * @return the text between the startTag and the endTag if exists else ""
		 */
		public static String getText(String source,String startTag, String endTag) {
			String text = "";
			int start = source.indexOf(startTag);
			if(start>=0){
			int end = source.indexOf(endTag, start);
			if(end>=0){
			text = source.substring(start + startTag.length(), end);
			}
			}
			return text;
		}
		
		/**
		 * Given the startTag and the endTag and a text to edit,this function returns an ArrayList<String> that
		 * contains different texts that are between the start and the end tag.
		 * @param source
		 * @param startTag
		 * @param endTag
		 * @return ArrayList<String> contains all texts between startTag and endTag
		 */
		public static  ArrayList<String> extractAllTexts(String source, String startTag,String endTag) {
			ArrayList<String> textToEdit = new ArrayList<String>(0);
			String text = "";
			int start = source.indexOf(startTag);
			while (start >= 0) {
				int end = source.indexOf(endTag, start);
				if (end >= 0) {
					text = source.substring(start + startTag.length(), end);
					textToEdit.add(text);
					source=source.substring(end+endTag.length());
				}else{
					source=source.substring(start+startTag.length());
				}
				start = source.indexOf(startTag);
			}
			return textToEdit;
		}
	
	
		
		
		public static boolean hasCommonWord(String firstWord,String secondWord){
			String[] firstWordArray = firstWord.split(" ");
			String[] secondWordArray = secondWord.split(" ");
			int firstSize = firstWordArray.length;
			int secondSize = secondWordArray.length;
			if(firstSize!=secondSize && !firstWord.contains(PALAIO)&& !firstWord.contains(ANW)&& !firstWord.contains(ODOS) &&
					!secondWord.contains(PALAIO)&& !secondWord.contains(ANW)&& !secondWord.contains(ODOS)){
				if(firstSize>secondSize){
					for(int i=0;i<secondSize;i++){
						if(!firstWordArray[i].equals(secondWordArray[i])){
							return false;
						}
					}
				}else{
					for(int i=0;i<firstSize;i++){
						if(!firstWordArray[i].equals(secondWordArray[i])){
							return false;
						}
					}
				}
				return true;
			}
			return false;
		}
		
		public static boolean isTheSameLetterInLatin(char ch1,char ch2){
			if((ch1=='A'&&ch2=='Á')||(ch1=='Â'&& ch2=='Â')||(ch1=='E'&& ch2=='Å')
					||(ch1=='H'&& ch2=='Ç')||(ch1=='I'&& ch2=='É')||(ch1=='K'&& ch2=='Ê')
					||(ch1=='M'&& ch2=='Ì')||(ch1=='N'&& ch2=='Í')||(ch1=='O'&& ch2=='Ï')
					||(ch1=='P'&& ch2=='Ñ')||(ch1=='T'&& ch2=='Ô')||(ch1=='X'&& ch2=='×')
					||(ch1=='Y'&& ch2=='Õ')||(ch1=='Z'&& ch2=='Æ')||(ch2=='A'&&ch1=='Á')
					||(ch2=='Â'&& ch1=='Â')||(ch2=='E'&& ch1=='Å')
					||(ch2=='H'&& ch1=='Ç')||(ch2=='I'&& ch1=='É')||(ch2=='K'&& ch1=='Ê')
					||(ch2=='M'&& ch1=='Ì')||(ch2=='N'&& ch1=='Í')||(ch2=='O'&& ch1=='Ï')
					||(ch2=='P'&& ch1=='Ñ')||(ch2=='T'&& ch1=='Ô')||(ch2=='X'&& ch1=='×')
					||(ch2=='Y'&& ch1=='Õ')||(ch2=='Z'&& ch1=='Æ')){
				return true;
			}

			return false;
		}
		
		public static ArrayList<String> getManyInOneAnnTexts(ArrayList<String> announcements){
			ArrayList<String> newAnns = new ArrayList<String>(0);
			ArrayList<String> outAnns = new ArrayList<String>(0);
			String tag = "<img src=\"./i/t.gif\" align=\"absbottom\">";
			for(String ann: announcements){
				if(ann.contains("á)")){
					int place = ann.indexOf("á)");
					String basicPart = ann.substring(0,place);
					int place2 = ann.indexOf("â)");
					if(place2>0){
					String ann1 = ann.substring(place, place2);
					if(ann.contains("ã)")){
						int place3 = ann.indexOf("ã)");
						if(place3>0){
						String ann2 = ann.substring(place2,place3);
						if(ann.contains("ä)")){
							int place4 = ann.indexOf("ä)");
							if(place4>0){
							String ann3 = ann.substring(place3,place4);
							String ann4 = ann.substring(place4, ann.length());
							ann1 = basicPart.concat(ann1).replace("á)","");
							ann2 = basicPart.concat(ann2).replace("â)","");
							ann3 = basicPart.concat(ann3).replace("ã)","");
							ann4 = basicPart.concat(ann4).replace("ä)","");
							if(ann4.contains(tag)){
								int positionOfTag = ann4.indexOf(tag);
								String extra = ann4.substring(positionOfTag,ann4.length());
								ann1.concat(" "+extra);
								ann2.concat(" "+extra);
								ann3.concat(" "+extra);
							}
							newAnns.add(ann1);
							newAnns.add(ann2);
							newAnns.add(ann3);
							newAnns.add(ann4);
							outAnns.add(ann);}
						}else{
							String ann3 = ann.substring(place3,ann.length());
							ann1 = basicPart.concat(ann1).replace("á)","");
							ann2 = basicPart.concat(ann2).replace("â)","");
							ann3 = basicPart.concat(ann3).replace("ã)","");	
							if(ann3.contains(tag)){
								int positionOfTag = ann3.indexOf(tag);
								String extra = ann3.substring(positionOfTag,ann3.length());
								ann1.concat(" "+extra);
								ann2.concat(" "+extra);
							}
							newAnns.add(ann1);
							newAnns.add(ann2);
							newAnns.add(ann3);
							outAnns.add(ann);
						}
						}
					}else{
						String ann2 = ann.substring(place2,ann.length());
						ann1 = basicPart.concat(ann1).replace("á)","");
						ann2 = basicPart.concat(ann2).replace("â)","");	
						if(ann2.contains(tag)){
							int positionOfTag = ann2.indexOf(tag);
							String extra = ann2.substring(positionOfTag,ann2.length());
							ann1.concat(" "+extra);
						}
						newAnns.add(ann1);
						newAnns.add(ann2);
						outAnns.add(ann);
					}
				}
				}
				
			}
			for(String newAnn : newAnns){
				announcements.add(newAnn);
			}
			for(String outAnn : outAnns){
				announcements.remove(outAnn);
			}
			return announcements;
		}
		
		public static ArrayList<Announcement> getManyInOneAnn(ArrayList<Announcement> announcements){
			ArrayList<Announcement> newAnns = new ArrayList<Announcement>(0);
			ArrayList<Announcement> outAnns = new ArrayList<Announcement>(0);
			for(Announcement ann: announcements){
				String descr = ann.getDescription();
				if(descr.contains("á)")){
					int place = descr.indexOf("á)");
					String basicPart = descr.substring(0,place);
					int place2 = descr.indexOf("â)");
					String ann1 = descr.substring(place, place2);
					if(descr.contains("ã)")){
						int place3 = descr.indexOf("ã)");
						String ann2 = descr.substring(place2,place3);
						if(descr.contains("ä)")){
							int place4 = descr.indexOf("ä)");
							String ann3 = descr.substring(place3,place4);
							String ann4 = descr.substring(place4, descr.length());
							ann1 = basicPart.concat(ann1).replace("á)","");
							ann2 = basicPart.concat(ann2).replace("â)","");
							ann3 = basicPart.concat(ann3).replace("ã)","");
							ann4 = basicPart.concat(ann4).replace("ä)","");
							newAnns.add(new Announcement(ann1));
							newAnns.add(new Announcement(ann2));
							newAnns.add(new Announcement(ann3));
							newAnns.add(new Announcement(ann4));
							outAnns.add(ann);
						}else{
							String ann3 = descr.substring(place3,descr.length());
							ann1 = basicPart.concat(ann1).replace("á)","");
							ann2 = basicPart.concat(ann2).replace("â)","");
							ann3 = basicPart.concat(ann3).replace("ã)","");;
							newAnns.add(new Announcement(ann1));
							newAnns.add(new Announcement(ann2));
							newAnns.add(new Announcement(ann3));
							outAnns.add(ann);
						}
					}else{
						String ann2 = descr.substring(place2,descr.length());
						ann1 = basicPart.concat(ann1).replace("á)","");
						ann2 = basicPart.concat(ann2).replace("â)","");;
						newAnns.add(new Announcement(ann1));
						newAnns.add(new Announcement(ann2));
						outAnns.add(ann);
					}
				}else if(descr.contains("1)")){
					int place = descr.indexOf("1)");
					String basicPart = descr.substring(place);
					int place2 = descr.indexOf("2)");
					String ann1 = descr.substring(place, place2);
					if(descr.contains("3)")){
						int place3 = descr.indexOf("3)");
						String ann2 = descr.substring(place2,place3);
						if(descr.contains("4)")){
							int place4 = descr.indexOf("4)");
							String ann3 = descr.substring(place3,place4);
							String ann4 = descr.substring(place4, descr.length());
							ann1 = basicPart.concat(ann1).replace("1)","");
							ann2 = basicPart.concat(ann2).replace("2)","");
							ann3 = basicPart.concat(ann3).replace("3)","");
							ann4 = basicPart.concat(ann4).replace("4)","");
							newAnns.add(new Announcement(ann1));
							newAnns.add(new Announcement(ann2));
							newAnns.add(new Announcement(ann3));
							newAnns.add(new Announcement(ann4));
							outAnns.add(ann);
						}else{
							String ann3 = descr.substring(place3,descr.length());
							ann1 = basicPart.concat(ann1).replace("1)","");
							ann2 = basicPart.concat(ann2).replace("2)","");
							ann3 = basicPart.concat(ann3).replace("3)","");
							newAnns.add(new Announcement(ann1));
							newAnns.add(new Announcement(ann2));
							newAnns.add(new Announcement(ann3));
							outAnns.add(ann);
						}
					}else{
						String ann2 = descr.substring(place2,descr.length());
						ann1 = basicPart.concat(ann1).replace("1)","");
						ann2 = basicPart.concat(ann2).replace("2)","");
						newAnns.add(new Announcement(ann1));
						newAnns.add(new Announcement(ann2));
						outAnns.add(ann);
					}
				}
				
			}
			for(Announcement newAnn : newAnns){
				announcements.add(newAnn);
			}
			for(Announcement outAnn : outAnns){
				announcements.remove(outAnn);
			}
			return announcements;
		}
		
		public static boolean isEqual(Double a,Double b){
		   if(a==null && b==null){
				return true;
			}else if ((a==null && b!=null)||(a!=null && b==null)){
				return false;
			}else if(a.doubleValue()==b.doubleValue()){
				return true;
			}
			return false;
		}
		public static boolean isEqual(Integer a,Integer b){
			   if(a==null && b==null){
					return true;
				}else if ((a==null && b!=null)||(a!=null && b==null)){
					return false;
				}else if(a.intValue()==b.intValue()){
					return true;
				}
				return false;
			}
		public static boolean isEqualOtherFeatures(String a, String b){
			if((a==null && b==null)){
				return true;
			}else if ((a==null && b!=null)||(a!=null && b==null)){
				return false;
			}else{		
				while(a.endsWith(" ")||a.endsWith(",")){
					a=a.substring(0,a.length()-1);
				}
				while(b.endsWith(" ")||b.endsWith(",")){
					b=b.substring(0,b.length()-1);
				}
				if(WordUtilities.findDistance(a,b)<=2){
					return true;
			}
			}
			return false;
		}
		
		public static boolean isEqual(String a, String b){
			if((a==null && b==null)){
				return true;
			}else if ((a==null && b!=null)||(a!=null && b==null)){
				return false;
			}else if(a.equals(b)){
				return true;
			}
			return false;
		}
		
		public static ArrayList<Date> sortDates(ArrayList<Date> dates){
			boolean hasChange=false;
			do{
			hasChange=false;	
			for(int i=0;i<dates.size()-1;i++){
				if(i+1<dates.size()&& dates.get(i+1)!=null){
				if(dates.get(i).compareTo(dates.get(i+1))>0){
					Date temp = dates.get(i+1);
					dates.set(i+1,dates.get(i));
					dates.set(i,temp);
					hasChange=true;
				}
				}
			}
			}while(hasChange);
			return dates;
		}
		
		
}
