/**
 * class AggelFeatExtraction
 * @author Dimitra Xidara
 */
package crawling.aggel;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.IdDescription;
import crawling.entities.SearchInfo;
import crawling.AnnFeatExtraction;

public class AggelFeatExtraction extends AnnFeatExtraction {

	protected IdDescription mainAreaType;

	protected String secondArea;

	private SearchInfo searchInfo;

	public AggelFeatExtraction(int nomosId, String announcement,
			Connection connection, SearchInfo searchInfo) {
		super(nomosId, announcement, connection);
		setSearchInfo(searchInfo);
	}

	public AggelFeatExtraction(int nomosId, String announcement,
			Connection connection) {
		super(nomosId, announcement, connection);
	}

	@Override
	protected void editAnnFeatures() {
		mainAreaType = new IdDescription();
		String[] advWords = announcement.split(" ");
		String mainArea = Utilities.getText(announcement, "<b>", "</b>");
		announcement = announcement.replace("<b>" + mainArea + "</b>", "");
		char[] mainAreaLetters = mainArea.toCharArray();
		int pos = 1;
		secondArea = "";
		if (Character.isDigit(mainAreaLetters[0])) {
			mainArea = mainArea + " " + advWords[1];
			pos = 2;
			announcement = announcement.replace(advWords[1],"");
		}
		for (String keyword : AnnKeywords.SECONDAREA_KEYWORDS) {
			if (keyword.equals(advWords[pos])) {
				secondArea = advWords[pos] + " ";
				break;
			}
		}
		if (!secondArea.equals("")) {
			secondArea += advWords[pos + 1];
		} else {
			char[] advWordLetter = advWords[pos].toCharArray();
			if (advWordLetter.length > 1) {
				if (!Character.isLowerCase(advWordLetter[0])
						&& Character.isLowerCase(advWordLetter[1])) {
					secondArea = advWords[pos];
				}
			}
		}
		if (!secondArea.equals("")) {
			announcement = announcement.replace(secondArea, "");
		}
		ArrayList<String> otherWordsList = new ArrayList<String>(0);
		for (int i = pos + 1; i < advWords.length; i++) {
			otherWordsList.add(advWords[i]);
		}
		if (searchInfo.getNomos() != null) {
			ArrayList<IdDescription> perioxes = DatabaseSelectManager
					.getPerioxesOfNomos(searchInfo.getNomos().getId(), getConnection());
			boolean alreadyIn = false;
			for (IdDescription type : perioxes) {
				if (type.getDescription().equals(mainArea)
						|| WordUtilities.findDistance(type.getDescription(),
								mainArea) <= 1
						|| type.getDescription().toUpperCase().equals(mainArea)
						||mainArea.toUpperCase().equals(type.getDescription())
						||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
					alreadyIn = true;
					mainAreaType.setId(type.getId());
					break;
				}
			}
			if (!alreadyIn) {
				mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
						mainArea, searchInfo.getNomos().getId(), getConnection()));
			}

			mainAreaType.setDescription(mainArea);
		} else {
			if (searchInfo.getDiamerisma() == null) {
				ArrayList<IdDescription> diamerismata = DatabaseSelectManager
						.getDiamerismata(getConnection());
				boolean alreadyIn = false;
				for (IdDescription diam : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diam.getId(),
									getConnection());
					for (IdDescription nomos : nomoi) {
						ArrayList<IdDescription> perioxes = DatabaseSelectManager
								.getPerioxesOfNomos(nomos.getId(), getConnection());
						for (IdDescription type : perioxes) {
							if (type.getDescription().equals(mainArea)
									|| WordUtilities.findDistance(type
											.getDescription(), mainArea) <= 1
									|| type.getDescription().toUpperCase()
											.equals(mainArea)
											||mainArea.toUpperCase().equals(type.getDescription())
											||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
								alreadyIn = true;
								mainAreaType.setId(type.getId());
								mainAreaType.setDescription(type.getDescription());
								searchInfo.setDiamerisma(diam);
								searchInfo.setNomos(nomos);
								break;
							}
						}
						if(alreadyIn){
							break;
						}
					}
					if(alreadyIn){
						break;
					}
					
				}if (!alreadyIn) {
					mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
							mainArea, -1, getConnection()));
					mainAreaType.setDescription(mainArea);
					searchInfo.setDiamerisma(new IdDescription(-1));
					searchInfo.setNomos(new IdDescription(-1));
				}
			}else if(searchInfo.getDiamerisma().getDescription().equals(AnnKeywords.MAKEDONIA_THRAKH)){
				ArrayList<IdDescription> diamerismata = new ArrayList<IdDescription>(0);
				diamerismata.add(new IdDescription(AnnKeywords.THRAKH_ID));
				diamerismata.add(new IdDescription(AnnKeywords.MAKEDONIA_ID));
				boolean alreadyIn = false;
				for (IdDescription diam : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diam.getId(),
									getConnection());
					for (IdDescription nomos : nomoi) {
						ArrayList<IdDescription> perioxes = DatabaseSelectManager
								.getPerioxesOfNomos(nomos.getId(), getConnection());
						for (IdDescription type : perioxes) {
							if (type.getDescription().equals(mainArea)
									|| WordUtilities.findDistance(type
											.getDescription(), mainArea) <= 1
									|| type.getDescription().toUpperCase()
											.equals(mainArea)
											||mainArea.toUpperCase().equals(type.getDescription())
											||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
								alreadyIn = true;
								mainAreaType.setId(type.getId());
								mainAreaType.setDescription(type.getDescription());
								searchInfo.setDiamerisma(diam);
								searchInfo.setNomos(nomos);
								break;
							}
						}
						if(alreadyIn){
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}	
				if (!alreadyIn) {
					diamerismata = DatabaseSelectManager
					.getDiamerismata(getConnection());
			for (IdDescription diam : diamerismata) {
				ArrayList<IdDescription> nomoi = DatabaseSelectManager
						.getNomoysOfDiamerismata(diam.getId(),
								getConnection());
				for (IdDescription nomos : nomoi) {
					ArrayList<IdDescription> perioxes = DatabaseSelectManager
							.getPerioxesOfNomos(nomos.getId(), getConnection());
					for (IdDescription type : perioxes) {
						if (type.getDescription().equals(mainArea)
								|| WordUtilities.findDistance(type
										.getDescription(), mainArea) <= 1
								|| type.getDescription().toUpperCase()
										.equals(mainArea)
										||mainArea.toUpperCase().equals(type.getDescription())
										||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
							alreadyIn = true;
							mainAreaType.setId(type.getId());
							mainAreaType.setDescription(type.getDescription());
							searchInfo.setDiamerisma(diam);
							searchInfo.setNomos(nomos);
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}
				if(alreadyIn){
					break;
				}
			
				
			}	if (!alreadyIn) {
				mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
						mainArea, -1, getConnection()));
				mainAreaType.setDescription(mainArea);
				searchInfo.setDiamerisma(new IdDescription(-1));
				searchInfo.setNomos(new IdDescription(-1));
			}
				}
			}else if(searchInfo.getDiamerisma().getDescription().equals(AnnKeywords.HPEIRO_THESSALIA_STELLADA)){
				ArrayList<IdDescription> diamerismata = new ArrayList<IdDescription>(0);
				diamerismata.add(new IdDescription(AnnKeywords.HPEIRO_ID));
				diamerismata.add(new IdDescription(AnnKeywords.THESSALIA_ID));
				diamerismata.add(new IdDescription(AnnKeywords.STELLADA_BEYBOIA_ID));
				boolean alreadyIn = false;
				for (IdDescription diam : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diam.getId(),
									getConnection());
					for (IdDescription nomos : nomoi) {
						ArrayList<IdDescription> perioxes = DatabaseSelectManager
								.getPerioxesOfNomos(nomos.getId(), getConnection());
						for (IdDescription type : perioxes) {
							if (type.getDescription().equals(mainArea)
									|| WordUtilities.findDistance(type
											.getDescription(), mainArea) <= 1
									|| type.getDescription().toUpperCase()
											.equals(mainArea)
											||mainArea.toUpperCase().equals(type.getDescription())
											||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
								alreadyIn = true;
								mainAreaType.setId(type.getId());
								mainAreaType.setDescription(type.getDescription());
								searchInfo.setDiamerisma(diam);
								searchInfo.setNomos(nomos);
								break;
							}
						}
						if(alreadyIn){
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}
				if (!alreadyIn) {
					diamerismata = DatabaseSelectManager
					.getDiamerismata(getConnection());
			for (IdDescription diam : diamerismata) {
				ArrayList<IdDescription> nomoi = DatabaseSelectManager
						.getNomoysOfDiamerismata(diam.getId(),
								getConnection());
				for (IdDescription nomos : nomoi) {
					ArrayList<IdDescription> perioxes = DatabaseSelectManager
							.getPerioxesOfNomos(nomos.getId(), getConnection());
					for (IdDescription type : perioxes) {
						if (type.getDescription().equals(mainArea)
								|| WordUtilities.findDistance(type
										.getDescription(), mainArea) <= 1
								|| type.getDescription().toUpperCase()
										.equals(mainArea)
										||mainArea.toUpperCase().equals(type.getDescription())
										||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
							alreadyIn = true;
							mainAreaType.setId(type.getId());
							mainAreaType.setDescription(type.getDescription());
							searchInfo.setDiamerisma(diam);
							searchInfo.setNomos(nomos);
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}
				if(alreadyIn){
					break;
				}
				
				
			}if (!alreadyIn) {
				mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
						mainArea, -1, getConnection()));
				mainAreaType.setDescription(mainArea);
				searchInfo.setDiamerisma(new IdDescription(-1));
				searchInfo.setNomos(new IdDescription(-1));
			}
				}
			}else if(searchInfo.getDiamerisma().getDescription().equals(AnnKeywords.NHSIA)){
				ArrayList<IdDescription> diamerismata = new ArrayList<IdDescription>(0);
				diamerismata.add(new IdDescription(AnnKeywords.KRHTH_ID));
				diamerismata.add(new IdDescription(AnnKeywords.NHSIA_AIGAIOY_ID));
				diamerismata.add(new IdDescription(AnnKeywords.NHSIA_IONIOY_ID));
				boolean alreadyIn = false;
				for (IdDescription diam : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diam.getId(),
									getConnection());
					for (IdDescription nomos : nomoi) {
						ArrayList<IdDescription> perioxes = DatabaseSelectManager
								.getPerioxesOfNomos(nomos.getId(), getConnection());
						for (IdDescription type : perioxes) {
							if (type.getDescription().equals(mainArea)
									|| WordUtilities.findDistance(type
											.getDescription(), mainArea) <= 1
									|| type.getDescription().toUpperCase()
											.equals(mainArea)||mainArea.toUpperCase().equals(type.getDescription())
											||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
								alreadyIn = true;
								mainAreaType.setId(type.getId());
								mainAreaType.setDescription(type.getDescription());
								searchInfo.setDiamerisma(diam);
								searchInfo.setNomos(nomos);
								break;
							}
						}
						if(alreadyIn){
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}
				if (!alreadyIn) {
					diamerismata = DatabaseSelectManager
					.getDiamerismata(getConnection());
			for (IdDescription diam : diamerismata) {
				ArrayList<IdDescription> nomoi = DatabaseSelectManager
						.getNomoysOfDiamerismata(diam.getId(),
								getConnection());
				for (IdDescription nomos : nomoi) {
					ArrayList<IdDescription> perioxes = DatabaseSelectManager
							.getPerioxesOfNomos(nomos.getId(), getConnection());
					for (IdDescription type : perioxes) {
						if (type.getDescription().equals(mainArea)
								|| WordUtilities.findDistance(type
										.getDescription(), mainArea) <= 1
								|| type.getDescription().toUpperCase()
										.equals(mainArea)||mainArea.toUpperCase().equals(type.getDescription())
										||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
							alreadyIn = true;
							mainAreaType.setId(type.getId());
							mainAreaType.setDescription(type.getDescription());
							searchInfo.setDiamerisma(diam);
							searchInfo.setNomos(nomos);
							break;
						}
					}
					if(alreadyIn){
						break;
					}
				}
				if(alreadyIn){
					break;
				}
			
				
			}	if (!alreadyIn) {
				mainAreaType.setId(DatabaseUpdateManager.updatePerioxesTable(
						mainArea, -1, getConnection()));
				mainAreaType.setDescription(mainArea);
				searchInfo.setDiamerisma(new IdDescription(-1));
				searchInfo.setNomos(new IdDescription(-1));
			}
				}
			}
		}
	}

	@Override
	protected DoubleStringFormat getEmbadon(String[] text) {
		DoubleStringFormat embadon = null;
		String num = "";
		Double emb = null;
		if (text.length > 1 && text != null) {
			for (int i = 1; i < text.length; i++) {
				String txt = text[i];
				if (txt.endsWith(AnnKeywords.TMSKETO)&&!txt.contains("-")&&!txt.contains("+")&&!txt.contains("/")) {
					num = txt.replace(AnnKeywords.TMSKETO, "");
					emb = Utilities.toNumber(num);
					embadon = new DoubleStringFormat(txt, emb);
					return embadon;
				} else if (txt.endsWith(AnnKeywords.STR)&&!txt.contains("-")&&!txt.contains("+")&&!txt.contains("/")) {
					num = txt.replace(AnnKeywords.STR, "");
					emb = Utilities.toNumber(num);
					if (emb != null) {
						embadon = new DoubleStringFormat(txt, emb * 1000);
					}
					return embadon;
				}
			}
		}
		return embadon;
	}

	@Override
	protected String getPrice(String[] text) {
		for (int i=0;i < text.length; i++){
			String text_low =text[i].toLowerCase();
			String text_up = text[i].toUpperCase();
			if((text[i].contains("0"))&&(text_low.equals(text_up))&&(((text[i].contains("."))&&(!text[i].endsWith(".00")))||((text[i].length()==3)&&(text[i].endsWith("0"))))&&(!text[i].contains("-"))){	
				return text[i];
			}
		}
		return "";
	}

	protected ArrayList<String> getPhones() {
		String phoneStartTag = "<img src=\"./i/t.gif\" align=\"absbottom\"><b>";
		String phoneEndTag = "</b>";
		ArrayList<String> phones = Utilities.extractAllTexts(announcement,
				phoneStartTag, phoneEndTag);
		announcement = announcement.replace(phoneStartTag, "");
		announcement = announcement.replace(phoneEndTag, "");
		for (String phone : phones) {
			announcement = announcement.replace(phone, "");
		}
		return phones;
	}

	public SearchInfo getSearchInfo() {
		return searchInfo;
	}

	public void setSearchInfo(SearchInfo searchInfo) {
		this.searchInfo = searchInfo;
	}

}
