/**
 * class AggelHouseFeatExtraction
 * @author Dimitra Xidara
 */
package crawling.aggel;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.database.DatabaseSelectManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.PlotSellingAnnouncement;
import crawling.entities.SearchInfo;

public class AggelHouseFeatExtraction extends AggelFeatExtraction{

	private HouseAnnouncement houseAnnouncement;
	
	public AggelHouseFeatExtraction(int nomosId, String announcement, Connection connection, SearchInfo searchInfo) {
		super(nomosId, announcement, connection,searchInfo);
		houseAnnouncement = new HouseAnnouncement();
		editAnnFeatures();
	}


	protected void editAnnFeatures() {
		
		super.editAnnFeatures();
		houseAnnouncement.setMainArea(mainAreaType);
		houseAnnouncement.setSecArea(secondArea);
	    DoubleStringFormat embadon = getEmbadon(announcement.split(" "));
	    if(embadon!=null){
	    	houseAnnouncement.setEmbadon(embadon);
	    	announcement = announcement.replace(embadon.getStringFormat(),"");
	    }
	
	    ArrayList<IdDescription> types = DatabaseSelectManager.getTypesOfHouse(getConnection());
	    IdDescription type = getType(announcement.split(" "),types);
	    if(type!=null){
	    	houseAnnouncement.setType(type);
	    }
	    String orofos = getOrofos(announcement.split(" "));
	    if(!orofos.equals("")){
	    	announcement=announcement.replace(orofos,"");
	     orofos = orofos.replace(AnnKeywords.OS,"");
	     ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
	     String num = Utilities.getOnlyNumbers(orofos);
	     if(!num.equals("")){
	     orofoi.add(Integer.parseInt(num));
	     }
	     houseAnnouncement.setOrofoi(orofoi);
	    }
	    String bedrooms = getBedrooms(announcement.split(" "));
	    if(!bedrooms.equals("")){
	    	houseAnnouncement.setRoomNumber(bedrooms);
	    }
	    houseAnnouncement.setPhones(getPhones());
	    String price = getPrice(announcement.split(" "));
	    if(!price.equals("")){
	    	double priceDouble = Utilities.toNumber(price);
	    	if(priceDouble<1000000000){
	    	houseAnnouncement.setPrice(Utilities.toNumber(price));
	    	announcement = announcement.replace(price,"");
	    	}
	    }
	    houseAnnouncement.setOtherFeatures(announcement);
	}
	
	protected IdDescription getType(String[] text, ArrayList<IdDescription> types) {
		for(int i=0;i<text.length;i++){
			if(text[i].equals(AnnKeywords.DIAM)||
					text[i].equals(AnnKeywords.DIAMTA)||
					text[i].equals(AnnKeywords.DIAMTOS)||
					text[i].equals(AnnKeywords.DIAMERISMA)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.DIAMERISMA;
			}else if(text[i].equals(AnnKeywords.OROFODIAM)||
					text[i].equals(AnnKeywords.OROFODIAMERISMA)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.OROFODIAMERISMA;
			}else if(text[i].equals(AnnKeywords.STUDIO_XWRIS)||
					text[i].equals(AnnKeywords.STUDIO)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.STUDIO;
			}else if(text[i].equals(AnnKeywords.GARSONIERAS)||
					text[i].equals(AnnKeywords.GARSONIERES)||
					text[i].equals(AnnKeywords.GARSONIERA)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.GARSONIERA;
			}else if(text[i].equals(AnnKeywords.MEZONETWN)||
					text[i].equals(AnnKeywords.MEZONETA)||
					text[i].equals(AnnKeywords.MEZONETES)||
					text[i].equals(AnnKeywords.MEZONETAS)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.MEZONETA;
			}else if(text[i].equals(AnnKeywords.MONOKATOIKIA)){
				announcement = announcement.replace(text[i],"");
			}else if(text[i].equals(AnnKeywords.BILA)||
					text[i].equals(AnnKeywords.BILES)||
					text[i].equals(AnnKeywords.BILLA)){
				announcement=announcement.replace(text[i],"");
				text[i]=AnnKeywords.BILA;
			}else if(text[i].equals(AnnKeywords.RETIRE)){
				announcement = announcement.replace(text[i],"");
			}
		}
		return super.getType(text, types);
	}
	
	protected String getOrofos(String[] text){
		for(String txt:text){
			if(txt.length()==3 && txt.endsWith(AnnKeywords.OS)){
				return txt;
			}
		}
		return "";
	}
	
	protected String getBedrooms(String[] text){
		for(String txt:text){
			char[] letters = txt.toCharArray();
			if(letters.length>1 && letters != null){
				if(Character.isDigit(letters[0])&& letters[1]=='Ä'){
				Character digit = new Character(letters[0]);
				Character letter = new Character(letters[1]);
				announcement=announcement.replace(digit.toString()+letter.toString(),"");
				return digit.toString();
			}else if((letters[0]=='Ä')&&(!Character.isLowerCase(letters[1]))){
				return "1";
			}
			}
		}
		return "";
	}


	public HouseAnnouncement getHouseAnnouncement() {
		return houseAnnouncement;
	}


	public void setHouseAnnouncement(HouseAnnouncement houseAnnouncement) {
		this.houseAnnouncement = houseAnnouncement;
	}


	
}
