package crawling.database;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Properties;

import crawling.entities.AreaNumPriceEntity;
import crawling.entities.SecondAreaPriceOtherEntity;

public class DatabaseQueriesManager {

	/**
	 * Creates an ArrayList contains the average price of rent of a
	 * type_of_house in the Areas of Attikh
	 * 
	 * @param type_of_house
	 * @param connection
	 * @return
	 */
	public static ArrayList<AreaNumPriceEntity> averageAreasHousesPrice(
			int type_of_house, int type_of_adv, Connection connection) {
		ArrayList<AreaNumPriceEntity> results = new ArrayList<AreaNumPriceEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT P.DESCRIPTION AS AREA, COUNT(*) AS NUMBER, AVG( H.PRICE / H.EMBADON ) AS AVERAGE_PRICE"
					+ " FROM type_of_ann AS A, ann_search_info AS I, ann_house AS H, geo_perioxes AS P "
					+ "WHERE I.CATEGORY_ID=A.ID"
					+ " AND A.ID="
					+ type_of_adv
					+ " AND I.ISOFFER =1"
					+ " AND I.SEARCHID=H.SEARCHID"
					+ " AND H.MAINAREA_ID=P.ID"
					+ " AND P.NOMOS_ID=1"
					+ " AND H.TYPE_ID="
					+ type_of_house
					+ " GROUP BY P.DESCRIPTION";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new AreaNumPriceEntity(rset.getString("AREA"), rset
						.getInt("NUMBER"), rset.getDouble("AVERAGE_PRICE")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static ArrayList<AreaNumPriceEntity> averageAreasEarthPrice(
			int type_of_earth, Connection connection) {
		ArrayList<AreaNumPriceEntity> results = new ArrayList<AreaNumPriceEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT P.DESCRIPTION AS AREA, COUNT(*) AS NUMBER, AVG( H.PRICE / H.EMBADON ) AS AVERAGE_PRICE"
					+ " FROM type_of_ann AS A, ann_search_info AS I, ann_sell_earth AS H, geo_perioxes AS P "
					+ "WHERE I.CATEGORY_ID=A.ID"
					+ " AND A.ID=697"
					+ " AND I.ISOFFER =1"
					+ " AND I.SEARCHID=H.SEARCHID"
					+ " AND H.MAINAREA_ID=P.ID"
					+ " AND P.NOMOS_ID=1"
					+ " AND H.TYPE_ID="
					+ type_of_earth
					+ " GROUP BY P.DESCRIPTION";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new AreaNumPriceEntity(rset.getString("AREA"), rset
						.getInt("NUMBER"), rset.getDouble("AVERAGE_PRICE")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static ArrayList<AreaNumPriceEntity> averageNomoiHousePrice(
			int type_of_house, int type_of_adv, Connection connection) {
		ArrayList<AreaNumPriceEntity> results = new ArrayList<AreaNumPriceEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT N.DESCRIPTION AS AREA, COUNT(*) AS NUMBER, AVG( H.PRICE / H.EMBADON ) AS AVERAGE "
					+ "FROM type_of_ann AS A, ann_search_info AS I, ann_house AS H, geo_nomoi AS N, geo_perioxes AS P "
					+ "WHERE I.CATEGORY_ID=A.ID "
					+ "AND A.ID="
					+ type_of_adv
					+ " AND I.ISOFFER =1 "
					+ "AND I.SEARCHID=H.SEARCHID "
					+ "AND H.MAINAREA_ID=P.ID "
					+ "AND P.NOMOS_ID=N.ID "
					+ "AND H.TYPE_ID="
					+ type_of_house
					+ " GROUP BY N.DESCRIPTION ";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new AreaNumPriceEntity(rset.getString("AREA"), rset
						.getInt("NUMBER"), rset.getDouble("AVERAGE_PRICE")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static ArrayList<AreaNumPriceEntity> averageNomoiEarthPrice(
			int type_of_earth, Connection connection) {
		ArrayList<AreaNumPriceEntity> results = new ArrayList<AreaNumPriceEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT N.DESCRIPTION AS AREA, COUNT(*) AS NUMBER, AVG( H.PRICE / H.EMBADON ) AS AVERAGE "
					+ "FROM type_of_ann AS A, ann_search_info AS I, ann_house AS H, geo_nomoi AS N, geo_perioxes AS P "
					+ "WHERE I.CATEGORY_ID=A.ID "
					+ "AND A.ID=697"
					+ " AND I.ISOFFER =1 "
					+ "AND I.SEARCHID=H.SEARCHID "
					+ "AND H.MAINAREA_ID=P.ID "
					+ "AND P.NOMOS_ID=N.ID "
					+ "AND H.TYPE_ID="
					+ type_of_earth
					+ " GROUP BY N.DESCRIPTION ";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new AreaNumPriceEntity(rset.getString("AREA"), rset
						.getInt("NUMBER"), rset.getDouble("AVERAGE_PRICE")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static ArrayList<SecondAreaPriceOtherEntity> extractAdvsWithSpecialFeatures(
			int type_of_house, double price, int type_of_adv, String area,
			Connection connection) {
		ArrayList<SecondAreaPriceOtherEntity> results = new ArrayList<SecondAreaPriceOtherEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT H.SECONDAREA, H.PRICE, H.OTHER "
					+ "FROM type_of_ann AS A, ann_search_info AS I, ann_house AS H, geo_perioxes AS P "
					+ "WHERE I.CATEGORY_ID=A.ID " + "AND A.ID=" + type_of_adv
					+ " AND I.ISOFFER =1 " + "AND I.SEARCHID=H.SEARCHID "
					+ "AND H.PRICE <" + price + " AND H.TYPE_ID ="
					+ type_of_house + " AND H.MAINAREA_ID = P.ID "
					+ "AND P.DESCRIPTION = '" + area
					+ "' AND OTHER LIKE '%ãêáñÜæ%' ";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new SecondAreaPriceOtherEntity(rset
						.getString("SECONDAREA"), rset.getDouble("PRICE"), rset
						.getString("OTHER")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static ArrayList<SecondAreaPriceOtherEntity> extractAdvsAboveAverage(
			int type_of_house, double price, int type_of_adv, String area,
			Connection connection) {
		ArrayList<SecondAreaPriceOtherEntity> results = new ArrayList<SecondAreaPriceOtherEntity>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT H.SECONDAREA, H.PRICE, H.OTHER "
					+ "FROM type_of_ann AS A, ann_search_info AS I, ann_house AS H, geo_perioxes AS P "
					+ "WHERE H.PRICE < "
					+ "("
					+ "SELECT AVG(PRICE) "
					+ "FROM ann_house AS H, geo_perioxes AS P, type_of_ann AS A, ann_search_info AS I "
					+ "WHERE H.TYPE_ID=1 " + "AND I.CATEGORY_ID=A.ID "
					+ "AND A.ID="+type_of_adv
					+ " AND I.ISOFFER =1 "
					+ "AND I.SEARCHID=H.SEARCHID "
					+ "AND H.MAINAREA_ID = P.ID "
					+ "AND P.DESCRIPTION = 'ÊÏËÙÍÁÊÉ' " + ")"
					+ "AND I.CATEGORY_ID=A.ID " + "AND A.ID="+type_of_adv
					+ " AND I.ISOFFER = 1 " + "AND I.SEARCHID=H.SEARCHID "
					+ "AND H.TYPE_ID ="+type_of_house + " AND H.MAINAREA_ID = P.ID "
					+ "AND P.DESCRIPTION = '"+area+"'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				results.add(new SecondAreaPriceOtherEntity(rset
						.getString("SECONDAREA"), rset.getDouble("PRICE"), rset
						.getString("OTHER")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return results;
	}

	public static void main(String[] args) {
		Connection connection;
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			connection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/temp09062008", props);
			ArrayList<AreaNumPriceEntity> res1 = averageAreasHousesPrice(1,
					917, connection);
			ArrayList<AreaNumPriceEntity> res2 = averageAreasEarthPrice(1,
					connection);
			for (AreaNumPriceEntity result : res1) {
				System.out.println(result);
			}
			for (AreaNumPriceEntity result : res2) {
				System.out.println(result);
			}
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
		}

	}
}
