/**
 * class DatabaseSelectManager
 * @author Dimitra Xidara
 */
package crawling.database;

import java.sql.Connection;
import java.sql.Date;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.HashMap;

import crawling.AnnKeywords;
import crawling.entities.Auction;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.IdPrice;
import crawling.entities.MainArea;
import crawling.entities.Period;
import crawling.entities.PlotSellingAnnouncement;

public class DatabaseSelectManager {
	
	public static ArrayList<MainArea> getUnknownNomosAreas(Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<MainArea> areas = new ArrayList<MainArea>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_perioxes WHERE NOMOS_ID=-1";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				areas.add(new MainArea(rset.getInt("ID"),rset.getString("DESCRIPTION"),
						rset.getInt("NOMOS_ID")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_house table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return areas;
	}
	
	public static ArrayList<MainArea> getAllKnownAreas(Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<MainArea> areas = new ArrayList<MainArea>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_perioxes WHERE NOMOS_ID<>-1";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				areas.add(new MainArea(rset.getInt("ID"),rset.getString("DESCRIPTION"),
						rset.getInt("NOMOS_ID")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_house table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return areas;
	}
	
	public static ArrayList<Integer> getOnlyBigPricesRentHouseAnn(Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Integer> anns = new ArrayList<Integer>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_house as H, ann_search_info as S WHERE S.SEARCHID=H.SEARCHID AND CATEGORY_ID=917 AND PRICE>10000";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_house table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return anns;
	}
	public static ArrayList<Integer> getOnlyBigPricesSellHouseAnn(Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Integer> anns = new ArrayList<Integer>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_house as H, ann_search_info as S WHERE S.SEARCHID=H.SEARCHID AND CATEGORY_ID=256 AND PRICE>1000000";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_house table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return anns;
	}
	
	
	public static ArrayList<Integer> getOnlyBigPricesSellEarthAnn(Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Integer> anns = new ArrayList<Integer>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_sell_earth WHERE PRICE>1000000";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("\nERROR:Can't execute query in ann_house table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return anns;
	}
	public static ArrayList<IdDescription> getPerioxhIdFromDhmosThatAreNull(int nomosId,Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> dhmoi = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID,DESCRIPTION FROM geo_dhmoi_koinothtes WHERE PERIOXH_ID IS NULL AND NOMOS_ID="+nomosId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				dhmoi.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_cooperator table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return dhmoi;
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getSearchIdS(Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Integer> ids = new ArrayList<Integer>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT SEARCHID FROM ann_search_info";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				ids.add(rset.getInt("SEARCHID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return ids;
		}
	}

	public static ArrayList<String> getAlterPerioxesNames(int mainAreaId,Connection connection){
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<String> alterNames = new ArrayList<String>(0);
		try{
			stmt = connection.createStatement();
			String query = "SELECT DESCRIPTION FROM alter_perioxes WHERE PERIOXH_ID='"
					+ mainAreaId+"'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				alterNames.add(rset.getString("DESCRIPTION"));
			}
		}catch(SQLException ex){
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in alter_perioxes table");
		}finally{
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return alterNames;
	}
	
	public static ArrayList<IdDescription> getNamesOfTypeCoo(int cooId,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> names = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID,NAME FROM ann_cooperator WHERE COO_TYPE='"
					+ cooId+"'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				names.add(new IdDescription(rset.getInt("ID"), rset
						.getString("NAME")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out
					.println("\nERROR:Can't execute query in ann_cooperator table");
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
		}
		return names;
	}

	@SuppressWarnings("finally")
	public static ArrayList<IdDescription> getTypesOfCooperators(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM type_of_cooperator";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * It returns an ArrayList containing the id and description of all types of
	 * houses
	 * 
	 * @param connection
	 * @return an ArrayList containing the id and description of all types of
	 *         houses
	 */
	@SuppressWarnings("finally")
	public static ArrayList<IdDescription> getTypesOfHouse(Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM type_of_house";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("TYPE_ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<IdDescription> getTypesOfHouseEstate(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT TYPE_ID,ESTATEID FROM type_of_house";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("TYPE_ID"), rset
						.getString("ESTATEID")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	public static ArrayList<IdDescription> getTypesOfAuction(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM type_of_auction";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * It returns an ArrayList containing the id and description of all the
	 * perioxes of attikhs
	 * 
	 * @param connection
	 * @return an ArrayList containing the id and description of all the
	 *         perioxes of attikhs
	 */
	public static ArrayList<IdDescription> getPerioxesOfAttikhs(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_perioxes_attikhs";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * It returns an ArrayList containing the id and description of all
	 * diamerismata
	 * 
	 * @param connection
	 * @return an ArrayList containing the id and description of all
	 *         diamerismata
	 */
	public static ArrayList<IdDescription> getDiamerismata(Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_diamerismata";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * It returns an ArrayList containing the id and description of all types of
	 * earth
	 * 
	 * @param connection
	 * @return an ArrayList containing the id and description of all types of
	 *         earth
	 */
	public static ArrayList<IdDescription> getTypesOfEarth(Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM type_of_earth";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("TYPE_ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	public static ArrayList<IdDescription> getTypesOfEarthEstate(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT TYPE_ID,ESTATEID FROM type_of_earth";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("TYPE_ID"), rset
						.getString("ESTATEID")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * Gives all the ids and descriptions of all the perioxes of a specific
	 * nomos
	 * 
	 * @param nomosId
	 * @param connection
	 * @return all the ids and descriptions of all the perioxes of a specific
	 *         nomos
	 */
	public static ArrayList<IdDescription> getPerioxesOfNomos(int nomosId,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_perioxes WHERE NOMOS_ID="
					+ nomosId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
				////System.out.println(types);
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}

	}
	public static ArrayList<IdDescription> getDhmKoinOfNomos(int nomosId,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID,DESCRIPTION FROM geo_dhmoi_koinothtes WHERE NOMOS_ID="
					+ nomosId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}

	}
	/**
	 * Gives all nomoys of a specific diamerisma
	 * 
	 * @param diamerismaId
	 * @param connection
	 * @return all nomoys of a specific diamerisma
	 */
	public static ArrayList<IdDescription> getNomoysOfDiamerismata(
			int diamerismaId, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<IdDescription> types = new ArrayList<IdDescription>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT * FROM geo_nomoi WHERE DIAM_ID="
					+ diamerismaId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.add(new IdDescription(rset.getInt("ID"), rset
						.getString("DESCRIPTION")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	public static HashMap<IdDescription, Integer> getNomoyseEstate(
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		HashMap<IdDescription, Integer> types = new HashMap<IdDescription, Integer>(
				0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID,ESTATEID,DIAM_ID FROM geo_nomoi";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				types.put(new IdDescription(rset.getInt("ID"), rset
						.getString("ESTATEID")), rset.getInt("DIAM_ID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return types;
		}
	}

	/**
	 * Given the description a nomos it returns the its id
	 * 
	 * @param description
	 * @param connection
	 * @return the id of the given description of nomos
	 */
	public static int getNomosId(String description, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		int nomosId = -1;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID FROM geo_nomoi WHERE DESCRIPTION='"
					+ description + "'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				nomosId = rset.getInt("ID");
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return nomosId;
		}
	}

	/**
	 * Given the description a diamerisma it returns the its id
	 * 
	 * @param description
	 * @param connection
	 * @return the id of the given description of diamerisma
	 */
	public static int getDiamerismaId(String description, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		int nomosId = -1;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID FROM geo_diamerismata WHERE DESCRIPTION='"
					+ description + "'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				nomosId = rset.getInt("ID");
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return nomosId;
		}
	}

	/**
	 * Given the description of the an advertisement type it returns its id
	 * 
	 * @param description
	 * @param connection
	 * @return the advertisement's type id
	 */
	@SuppressWarnings("finally")
	public static int getAggeliasId(String description, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		int aggeliaId = -1;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID FROM type_of_ann WHERE DESCRIPTION='"
					+ description + "'";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				aggeliaId = rset.getInt("ID");
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return aggeliaId;
		}
	}

	/**
	 * Given the id of the type of advertisement and the description of nomos it
	 * returns the special id of the nomos that represents the specified type
	 * 
	 * @param typeId
	 * @param description
	 * @param connection
	 * @return a special id of the given nomos description
	 */
	@SuppressWarnings("finally")
	public static int getNomosSpecialId(int typeId, String description,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		String query = null;
		int nomosId = -1;
		try {
			stmt = connection.createStatement();
			if (AnnKeywords.SELL_EARTH_CODE == typeId) {
				query = "SELECT SELL_EARTH_ID FROM geo_nomoi WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("SELL_EARTH_ID");
				}
			} else if (AnnKeywords.RENT_HOUSE_CODE == typeId) {
				query = "SELECT RENT_HOUSE_ID FROM geo_nomoi WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("RENT_HOUSE_ID");
				}
			} else if (AnnKeywords.SELL_HOUSE_CODE == typeId) {
				query = "SELECT SELL_HOUSE_ID FROM geo_nomoi WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("SELL_HOUSE_ID");
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return nomosId;
		}
	}

	/**
	 * Given the id of the type of advertisement and the description of the
	 * perioxh of attikh it returns the special id of the perioxh of attikh that
	 * represents the specified type
	 * 
	 * @param typeId
	 * @param description
	 * @param connection
	 * @return a special id of the given nomos description
	 */
	@SuppressWarnings("finally")
	public static int getPerioxesAttikhsSpecialId(int typeId,
			String description, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		String query = null;
		int nomosId = -1;
		try {
			stmt = connection.createStatement();
			if (AnnKeywords.SELL_EARTH_CODE == typeId) {
				query = "SELECT SELL_EARTH_ID FROM geo_perioxes_attikhs WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("SELL_EARTH_ID");
				}
			} else if (AnnKeywords.RENT_HOUSE_CODE == typeId) {
				query = "SELECT RENT_HOUSE_ID FROM geo_perioxes_attikhs WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("RENT_HOUSE_ID");
				}
			} else if (AnnKeywords.SELL_HOUSE_CODE == typeId) {
				query = "SELECT SELL_HOUSE_ID FROM geo_perioxes_attikhs WHERE DESCRIPTION='"
						+ description + "'";
				rset = stmt.executeQuery(query);
				while (rset.next()) {
					nomosId = rset.getInt("SELL_HOUSE_ID");
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return nomosId;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<PlotSellingAnnouncement> getEarthAnnouncement(
			int isOffer, int sourceId, int nomosId, Date date,Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<PlotSellingAnnouncement> anns = new ArrayList<PlotSellingAnnouncement>(
				0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,INMAP,EMBADON,PRICE,COO_ID,OTHER,E.SEARCHID FROM ann_search_info as S INNER JOIN ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND DATE>'"
					+ date
					+ "' AND SOURCE_ID=" + sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement(
						rset.getInt("ANID"), new IdDescription(rset
								.getInt("MAINAREA_ID")), rset
								.getString("SECONDAREA"), new IdDescription(
								rset.getInt("TYPE_ID")), rset
								.getString("INMAP"), new DoubleStringFormat(
								rset.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), AnnKeywords.SELL_EARTH_CODE,
								connection), rset.getInt("E.SEARCHID"));
				plotAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(plotAnn);
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	@SuppressWarnings("finally")
	public static ArrayList<PlotSellingAnnouncement> getEarthAnnouncement(
			int isOffer, int sourceId, int nomosId,Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<PlotSellingAnnouncement> anns = new ArrayList<PlotSellingAnnouncement>(
				0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,INMAP,EMBADON,PRICE,COO_ID,OTHER,E.SEARCHID FROM ann_search_info as S,ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND SOURCE_ID=" + sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement(
						rset.getInt("ANID"), new IdDescription(rset
								.getInt("MAINAREA_ID")), rset
								.getString("SECONDAREA"), new IdDescription(
								rset.getInt("TYPE_ID")), rset
								.getString("INMAP"), new DoubleStringFormat(
								rset.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), AnnKeywords.SELL_EARTH_CODE,
								connection), rset.getInt("E.SEARCHID"));
				plotAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(plotAnn);
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<PlotSellingAnnouncement> getEarthAnnouncementSpecificDate(
			int isOffer, int sourceId, int nomosId,Date date,Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<PlotSellingAnnouncement> anns = new ArrayList<PlotSellingAnnouncement>(
				0);
		try {
			System.out.println("nomos:"+nomosId+" offer:"+isOffer+"date:"+date+" source:"+sourceId);
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,INMAP,EMBADON,PRICE,COO_ID,OTHER,E.SEARCHID FROM ann_search_info as S,ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+" AND DATE="
					+ date
					+ " AND SOURCE_ID=" + sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement(
						rset.getInt("ANID"), new IdDescription(rset
								.getInt("MAINAREA_ID")), rset
								.getString("SECONDAREA"), new IdDescription(
								rset.getInt("TYPE_ID")), rset
								.getString("INMAP"), new DoubleStringFormat(
								rset.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), AnnKeywords.SELL_EARTH_CODE,
								connection), rset.getInt("E.SEARCHID"));
				plotAnn.setCoo_id(rset.getInt("COO_ID"));
				System.out.println(plotAnn);
				anns.add(plotAnn);
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<PlotSellingAnnouncement> getEarthAnnouncementWithSpecificOther(
			int isOffer, int sourceId, int nomosId, String other,Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<PlotSellingAnnouncement> anns = new ArrayList<PlotSellingAnnouncement>(
				0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,INMAP,EMBADON,PRICE,COO_ID,OTHER,E.SEARCHID FROM ann_search_info as S,ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+" AND OTHER='"
					+ other
					+ "' AND SOURCE_ID=" + sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement(
						rset.getInt("ANID"), new IdDescription(rset
								.getInt("MAINAREA_ID")), rset
								.getString("SECONDAREA"), new IdDescription(
								rset.getInt("TYPE_ID")), rset
								.getString("INMAP"), new DoubleStringFormat(
								rset.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), AnnKeywords.SELL_EARTH_CODE,
								connection), rset.getInt("E.SEARCHID"));
				plotAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(plotAnn);
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<Integer> getSpecificEarthAnnouncement(
			int isOffer, int sourceId, int nomosId, PlotSellingAnnouncement ann,Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		String embadon=null;
		String price=null;
		String secondArea="";
		String inmap="";
		ArrayList<Integer> annsIds = new ArrayList<Integer>(
				0);
		if(ann.getEmbadon()!=null)
		{
			embadon="AND EMBADON="+ann.getEmbadon().getDoubleFormat();
		}
		else{
			embadon = " AND EMBADON IS NULL ";
		}
		if(ann.getPrice()!=null){
			price = " AND PRICE="+ann.getPrice();
		}else{
			price = " AND PRICE IS NULL ";
		}
		if(ann.getSecArea()!=null){
			secondArea=" AND SECONDAREA='"+ann.getSecArea()+"'";
		}else
		{
			secondArea=" AND SECONDAREA IS NULL ";
			}
		if(ann.getInMap()!=null){
			inmap=" AND INMAP='"+ann.getInMap()+"'";
		}else{
			inmap=" AND INMAP IS NULL ";
		}
		//Den xreiazontai afou o elenxos gia to ean uparxei "'" sta other feuatures
		//pragmatopoeitai otan ginetai insert h agellia sthn temp vash
		//an yparxei to sunvolo tha antikatastathei apo to ""
	   /* if(ann.getOtherFeatures().contains("'")){
			System.out.println("contains");
			ann.setOtherFeatures(ann.getOtherFeatures().replace("'",""));
		}
		if(ann.getSecArea()!=null && ann.getSecArea().contains("'")){
			ann.setSecArea(ann.getSecArea().replace("'"," "));
		}*/
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_search_info as S ,ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+" AND OTHER='"
					+ ann.getOtherFeatures()
					+"'AND MAINAREA_ID= "
					+ ann.getMainAreaType().getId()
				   // +secondArea
					+" AND TYPE_ID="
					+ ann.getType().getId()
				  //+inmap
				  //+price
				  //+embadon
				  //+" AND COO_ID="
				  //+ ann.getCoo_id()
					+ " AND SOURCE_ID=" 
					+ sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				annsIds.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annsIds;
		}
	}
	public static ArrayList<Auction> getAuctionAnnouncement(int isOffer,
			int sourceId, int nomosId, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Auction> anns = new ArrayList<Auction>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,PERCENTAGE,PRICE,OTHER FROM ann_search_info as S,ann_auction as A WHERE S.SEARCHID = A.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND SOURCE_ID=" + sourceId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(new Auction(rset.getInt("ANID"), new IdDescription(
						rset.getInt("MAINAREA_ID")), rset
						.getString("SECONDAREA"), new Double(rset
						.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rset
								.getString("PERCENTAGE")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	@SuppressWarnings( { "finally" })
	public static ArrayList<HouseAnnouncement> getHouseAnnouncement(
			int isOffer, int categoryId, int sourceId, int nomosId,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<HouseAnnouncement> anns = new ArrayList<HouseAnnouncement>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER,H.SEARCHID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				HouseAnnouncement houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("H.SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(houseAnn);

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	
	public static ArrayList<HouseAnnouncement> getHouseAnnouncementSpecificDate(
			int isOffer, int categoryId, int sourceId,int nomosId,Date date,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<HouseAnnouncement> anns = new ArrayList<HouseAnnouncement>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER,H.SEARCHID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+" AND DATE="
					+ date
					+ " AND SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				HouseAnnouncement houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("H.SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(houseAnn);

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	@SuppressWarnings( { "finally" })
	public static ArrayList<HouseAnnouncement> getHouseAnnouncement(
			int isOffer, int categoryId, int sourceId, int nomosId, Date date,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<HouseAnnouncement> anns = new ArrayList<HouseAnnouncement>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER,H.SEARCHID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND SOURCE_ID="
					+ sourceId
					+ " AND DATE>'"
					+ date
					+ "' AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				HouseAnnouncement houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("H.SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(houseAnn);

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<HouseAnnouncement> getHouseAnnouncementSpecificHouse(
			int isOffer, int categoryId, int sourceId, int nomosId,int typeId,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<HouseAnnouncement> anns = new ArrayList<HouseAnnouncement>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER,H.SEARCHID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+ " AND SOURCE_ID="
					+ sourceId
					+ " AND TYPE_ID="
					+ typeId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				HouseAnnouncement houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("H.SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(houseAnn);

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<HouseAnnouncement> getHouseAnnouncementSpecificOther(
			int isOffer, int categoryId, int sourceId, int nomosId,String other,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<HouseAnnouncement> anns = new ArrayList<HouseAnnouncement>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER,H.SEARCHID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					+ nomosId
					+ " AND ISOFFER="
					+ isOffer
					+" AND OTHER='"
					+ other
					+ "' AND SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				HouseAnnouncement houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("H.SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));
				anns.add(houseAnn);

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	public static ArrayList<IdDescription> getSpecificHouseAnnouncement(
			int isOffer, int categoryId, int sourceId, int nomosId,HouseAnnouncement ann,
			Connection connection) {
		String secondArea="";
		String inmap="";
		String price=null;
		String bedRooms=null;
		String coo_id=null;
		String embadon = null;
		Statement stmt = null;
		ResultSet rset = null;
		boolean rent = false;
		ArrayList<IdDescription> annsIds = new ArrayList<IdDescription>(0);
		if (categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			rent = true;
		}
		if(ann.getEmbadon()!=null)
		{
			embadon="AND EMBADON="+ann.getEmbadon().getDoubleFormat();
		}
		else{
			embadon = " AND EMBADON IS NULL ";
		}
		if(ann.getPrice()!=null){
			price = " AND PRICE="+ann.getPrice();
		}else{
			price = " AND PRICE IS NULL ";
		}
		if(ann.getSecArea()!=null){
			secondArea=" AND SECONDAREA='"+ann.getSecArea()+"'";
		}else
		{
			secondArea=" AND SECONDAREA IS NULL ";
			}
		
				if(ann.getCoo_id()!=null){
					coo_id = " AND COO_ID="+ann.getCoo_id();
				}else{
					coo_id = " AND COO_ID IS NULL ";
				}
				if(ann.getRoomNumber()!=null){
					bedRooms = " AND BEDROOMS=="+ann.getRoomNumber();
				}else{
					bedRooms= " AND BEDROOMS= IS NULL ";
				}
			/*	if(ann.getOtherFeatures().contains("'")){
					ann.setOtherFeatures(ann.getOtherFeatures().replace("'"," "));
				}
				if(ann.getSecArea()!=null && ann.getSecArea().contains("'")){
					ann.setSecArea(ann.getSecArea().replace("'"," "));
				}*/

		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,OTHER FROM ann_search_info as S  INNER JOIN ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " NOMOS_ID="
					 +nomosId
					+" AND ISOFFER="
					+ isOffer
					+" AND MAINAREA_ID="
					+ ann.getMainArea().getId()
					//+" AND TYPE_ID="
					//+ ann.getType().getId()
				//	+bedRooms
					//+secondArea
				    //+embadon
				    //+price
				    //+coo_id
					+ " AND SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				//System.out.println("has");
				annsIds.add(new IdDescription(rset.getInt("ANID"),rset.getString("OTHER")));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annsIds;
		}
	}
	@SuppressWarnings( { "finally" })
	public static HouseAnnouncement getHouseAnnouncement(int categoryId,boolean rent,
			int anid,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		HouseAnnouncement houseAnn=null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,SEARCHID,TYPE_ID,MAINAREA_ID,SECONDAREA,EMBADON,BEDROOMS,PRICE,COO_ID,OTHER FROM ann_house WHERE ANID="+anid;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				houseAnn = new HouseAnnouncement(rset
						.getInt("ANID"), new IdDescription(rset
						.getInt("MAINAREA_ID")), rset.getString("SECONDAREA"),
						rset.getString("BEDROOMS"), new DoubleStringFormat(rset
								.getDouble("EMBADON")), new Double(rset
								.getDouble("PRICE")), rset.getString("OTHER"),
						new IdDescription(rset.getInt("TYPE_ID")), rent,
						DatabaseSelectManager.getOrofoysOfAnnouncement(rset
								.getInt("ANID"), connection),
						DatabaseSelectManager.getPhonesOfAnnouncement(rset
								.getInt("ANID"), categoryId, connection), rset
								.getInt("SEARCHID"));
				houseAnn.setCoo_id(rset.getInt("COO_ID"));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return houseAnn;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Period> getPeriodOfAnnouncement(int id,
			int annType, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Period> periods = new ArrayList<Period>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT PID,START,END FROM ann_period WHERE ANID="
					+ id + " AND AN_TYPE=" + annType;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				periods.add(new Period(rset.getInt("PID"), rset
						.getDate("START"), rset.getDate("END")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return periods;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getOrofoysOfAnnouncement(int anid,
			Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT OROFOS FROM ann_orofos WHERE ANID=" + anid;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				orofoi.add(new Integer(rset.getInt("OROFOS")));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return orofoi;
		}
	}

	public static ArrayList<String> getPhonesOfAnnouncement(int anid,
			int anType, Connection connection) {
		Statement stmt = null;
		ResultSet rset = null;
		ArrayList<String> phones = new ArrayList<String>(0);
		try {
			stmt = connection.createStatement();
			String query = "SELECT PHONES FROM ann_phones WHERE ANID=" + anid
					+ " AND AN_TYPE=" + anType;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				phones.add(rset.getString("PHONES"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return phones;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getIdFromPerioxhId(Connection connection) {
		ArrayList<Integer> wrongwordsIds = new ArrayList<Integer>(0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ID FROM geo_perioxes WHERE DESCRIPTION="
					+ AnnKeywords.wrongWords[0];
			for (int i = 1; i < AnnKeywords.wrongWords.length; i++) {
				query += " OR DESCRIPTION=" + AnnKeywords.wrongWords[i];
			}
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				wrongwordsIds.add(rset.getInt("ID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return wrongwordsIds;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getIdsFromAnnHouse(
			ArrayList<Integer> perioxesId, Connection connection) {
		ArrayList<Integer> annHouseIds = new ArrayList<Integer>(0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_house WHERE MAINAREA_ID="
					+ perioxesId.get(0);
			for (int i = 1; i < perioxesId.size(); i++) {
				query += " OR MAINAREA_ID=" + perioxesId.get(i);
			}
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				annHouseIds.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annHouseIds;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getIdsFromAnnSellEarth(
			ArrayList<Integer> perioxesId, Connection connection) {
		ArrayList<Integer> annHouseIds = new ArrayList<Integer>(0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_sell_earth WHERE MAINAREA_ID="
					+ perioxesId.get(0);
			for (int i = 1; i < perioxesId.size(); i++) {
				query += " OR MAINAREA_ID=" + perioxesId.get(i);
			}
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				annHouseIds.add(rset.getInt("ANID"));
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annHouseIds;
		}
	}

	public static Date getSaveDataDate(int searchId, Connection connection) {
		Date date = null;
		Statement stmt = null;
		ResultSet rset = null;
		String query = "SELECT DATE FROM ann_search_info WHERE SEARCHID="
				+ searchId;
		try {
			stmt = connection.createStatement();
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				date = rset.getDate("DATE");
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return date;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getAllHouseAnnouncements(int categoryId,
			int sourceId, Connection connection) {
		ArrayList<Integer> annsId = new ArrayList<Integer>(0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_search_info as S,ann_house as H WHERE S.SEARCHID = H.SEARCHID AND"
					+ " SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				annsId.add(rset.getInt("ANID"));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annsId;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<Integer> getAllPlotAnnouncements(int categoryId,
			int sourceId, Connection connection) {
		ArrayList<Integer> annsId = new ArrayList<Integer>(0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID FROM ann_search_info as S,ann_sell_earth as E WHERE S.SEARCHID = E.SEARCHID AND"
					+ " SOURCE_ID="
					+ sourceId
					+ " AND CATEGORY_ID="
					+ categoryId;
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				annsId.add(rset.getInt("ANID"));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return annsId;
		}
	}

	@SuppressWarnings("finally")
	public static ArrayList<PlotSellingAnnouncement> getPlotAnnsWithNullType(
			Connection connection) {
		ArrayList<PlotSellingAnnouncement> anns = new ArrayList<PlotSellingAnnouncement>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT ANID,SECONDAREA,PRICE,EMBADON,OTHER FROM ann_sell_earth WHERE TYPE_ID=0";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(new PlotSellingAnnouncement(rset.getInt("ANID"), rset
						.getString("SECONDAREA"), new DoubleStringFormat(rset
						.getDouble("EMBADON")), rset.getDouble("PRICE"), rset
						.getString("OTHER")));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}

	
	public static ArrayList<IdDescription> getHouseAnnWithYpogeio(
			Connection connection) {
		ArrayList<IdDescription> anns = new ArrayList<IdDescription>(
				0);
		Statement stmt = null;
		ResultSet rset = null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT H.ANID,OTHER FROM ANN_HOUSE AS H,ANN_OROFOS AS O WHERE O.OROFOS=-1 AND O.ANID=H.ANID";
			rset = stmt.executeQuery(query);
			while (rset.next()) {
				anns.add(new IdDescription(rset.getInt("H.ANID"),rset.getString("OTHER")));

			}
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing result set");
				}
			}
			if (stmt != null) {
				try {
					stmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("\nError in closing statement");
				}
			}
			return anns;
		}
	}
	@SuppressWarnings({ "null", "finally" })
	public static ArrayList<String> getXE_url(int id,Connection connection) {
		Statement stmt = null;
		ArrayList<String> urls =new ArrayList<String>(0) ;
		ResultSet rset=null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT Url FROM xe_crawl WHERE ID > "+id;
							 
			rset = stmt.executeQuery(query);
			
			while ( rset.next()) {
				try{
				urls.add(rset.getString("Url"));
				}catch(Exception e ){
					
					e.printStackTrace();
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("WRong Query");
			}finally {
				if (rset != null) {
					try {
						rset.close();
					} catch (SQLException ex) {
						ex.printStackTrace();
						System.out.println("\nError in closing result set");
					}
				}
		
		return  urls;
	}
	}
	public static ArrayList<String> getXE_url_RENT(int id,Connection connection) {
		Statement stmt = null;
		ArrayList<String> urls =new ArrayList<String>(0) ;
		ResultSet rset=null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT Url FROM xe_crawl_RENT WHERE ID > "+id;
							 
			rset = stmt.executeQuery(query);
			
			while ( rset.next()) {
				try{
				urls.add(rset.getString("Url"));
				}catch(Exception e ){
					
					e.printStackTrace();
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("WRong Query");
			}finally {
				if (rset != null) {
					try {
						rset.close();
					} catch (SQLException ex) {
						ex.printStackTrace();
						System.out.println("\nError in closing result set");
					}
				}
		
		return  urls;
	}
	}
	public static ArrayList<String> getXE_url_EARTH(int id,Connection connection) {
		Statement stmt = null;
		ArrayList<String> urls =new ArrayList<String>(0) ;
		ResultSet rset=null;
		try {
			stmt = connection.createStatement();
			String query = "SELECT Url FROM xe_crawl_EARTH WHERE ID > "+id;
							 
			rset = stmt.executeQuery(query);
			
			while ( rset.next()) {
				try{
				urls.add(rset.getString("Url"));
				}catch(Exception e ){
					
					e.printStackTrace();
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();
			System.out.println("WRong Query");
			}finally {
				if (rset != null) {
					try {
						rset.close();
					} catch (SQLException ex) {
						ex.printStackTrace();
						System.out.println("\nError in closing result set");
					}
				}
		
		return  urls;
	}
	}
}
