/**
 * class DatabaseUpdateManager
 * @author Dimitra Xidara
 */
package crawling.database;

import java.sql.Connection;
import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.entities.*;

public class DatabaseUpdateManager {
	@SuppressWarnings("finally")
	public static int updateSearchTable(SearchInfo searchInfo,Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt2 = null;
		ResultSet rset = null;
		try {
		//	System.out.println(searchInfo.getNomos().getId());
			pstmt = connection
					.prepareStatement("INSERT INTO ann_search_info(DATE,CATEGORY_ID,NOMOS_ID,SOURCE_ID,ISOFFER,ISSOLD) VALUES (?,?,?,?,?,?);");
			pstmt.setDate(1, searchInfo.getDate());
			pstmt.setInt(2, searchInfo.getCategory().getId());
			pstmt.setInt(3, searchInfo.getNomos().getId());
			pstmt.setInt(4, searchInfo.getSourceId());
			pstmt.setInt(5, searchInfo.isOffer());
			if (searchInfo.isSold())
				pstmt.setInt(6, 1);
			else{
				pstmt.setInt(6, 0);
			}
			pstmt.executeUpdate();

			pstmt2 = connection
					.prepareStatement("SELECT MAX(SEARCHID) FROM ann_search_info");
			rset = pstmt2.executeQuery();
			rset.next();
			searchInfo.setSearchId(rset.getInt(1));
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt2 != null) {
				try {
					pstmt2.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}

			return searchInfo.getSearchId();
		}
	}

	public static void updateHouseAnnTable(Announcement announcement,
			HouseAnnouncement annFeatures, int searchId, int anType,
			Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		//System.out.println("hello");
		try{
			if(annFeatures.getOtherFeatures().contains("'")){
		//	System.out.println("*********************contains************************");
			annFeatures.setOtherFeatures(annFeatures.getOtherFeatures().replace("'",""));
		}
		}catch(Exception e){
			System.out.println("Wrong");
		}
		
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_house(SEARCHID,MAINAREA_ID, SECONDAREA, TYPE_ID,BEDROOMS,EMBADON, PRICE, COO_ID,OTHER)"
							+ " VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");

			pstmt.setInt(1, searchId);
			pstmt.setInt(2, annFeatures.getMainArea().getId());
			pstmt.setString(3, annFeatures.getSecArea());
			IdDescription type = annFeatures.getType();
			//System.out.println("hello");
			if (type != null) {
				pstmt.setInt(4, new Integer(type.getId()));
			} else {
				pstmt.setNull(4, Types.INTEGER);
			}
			pstmt.setString(5, annFeatures.getRoomNumber());
			DoubleStringFormat temp = annFeatures.getEmbadon();
			if (temp != null) {
				Double doubleNumber = temp.getDoubleFormat();
				if (doubleNumber != null && doubleNumber!=0) {
					pstmt.setDouble(6, doubleNumber);
				} else {
					pstmt.setNull(6, Types.DOUBLE);
				}
			} else {
				pstmt.setNull(6, Types.DOUBLE);
			}
			Double price = annFeatures.getPrice();
			if (price != null && price!=0) {
				pstmt.setDouble(7, price);
			} else {
				pstmt.setNull(7, Types.DOUBLE);
			}
			Integer cooId = annFeatures.getCoo_id();
			if(cooId!=null){
				pstmt.setInt(8,cooId);
			}else{
				pstmt.setNull(8,Types.INTEGER);
			}
			pstmt.setString(9, annFeatures.getOtherFeatures());
			pstmt.executeUpdate();

			pstmt1 = connection
					.prepareStatement("SELECT MAX(ANID) FROM ann_house");
			rset = pstmt1.executeQuery();
			rset.next();
			int anId = rset.getInt(1);
			announcement.setAnId(anId);
			ArrayList<Period> periods = announcement.getPeriods();
			if(periods!=null && periods.size()>0){
			for (Period period : periods) {
				updateAnnPeriodTable(period, anId, anType, connection);
			}
			}
			ArrayList<Integer> orofoi = annFeatures.getOrofoi();
			if (orofoi != null) {
				for (Integer orofos : orofoi) {
					updateOrofosTable(orofos, anId, connection);
				}
			}
			ArrayList<String> phones = annFeatures.getPhones();
			if (phones != null && phones.size() > 0) {
				for (String phone : phones) {
					updatePhonesTable(phone, anId, anType, connection);
				}
			}
		} catch (SQLException ex) {
			System.out.println("ERROR:Problem in updating ann_house table!!!\n");
			ex.printStackTrace();

		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}

		}

	}

	public static void updateAuctionTable(Announcement announcement,
			Auction annFeatures, int searchId, Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_auction(SEARCHID,MAINAREA_ID, SECONDAREA, TYPE_ID,PERCENTAGE, PRICE,OTHER)"
							+ " VALUES (?, ?, ?, ?, ?, ?, ?)");

			pstmt.setInt(1, searchId);
			pstmt.setInt(2, annFeatures.getMainAreaType().getId());
			pstmt.setString(3, annFeatures.getSecArea());
			IdDescription type = annFeatures.getType();
			if (type != null) {
				pstmt.setInt(4, new Integer(type.getId()));
			} else {
				pstmt.setNull(4, Types.INTEGER);
			}
			pstmt.setString(5, annFeatures.getPercentage());
			if (annFeatures.getPrice() != null && annFeatures.getPrice()!=0) {
				pstmt.setDouble(6, annFeatures.getPrice());
			} else {
				pstmt.setNull(6, Types.DOUBLE);
			}
			pstmt.setString(7, annFeatures.getOtherFeatures());
			pstmt.executeUpdate();

			pstmt1 = connection
					.prepareStatement("SELECT MAX(ANID) FROM ann_auction");
			rset = pstmt1.executeQuery();
			rset.next();
			int anId = rset.getInt(1);
			announcement.setAnId(anId);
			ArrayList<Period> periods = announcement.getPeriods();
			if(periods!=null && periods.size()>0){
			for (Period period : periods) {
				updateAnnPeriodTable(period, anId, AnnKeywords.AUCTION_CODE,
						connection);
			}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();

		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}

		}

	}

	public static void updateOrofosTable(Integer orofos, int anId,
			Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_orofos(ANID, OROFOS) VALUES (?, ?)");
			pstmt.setInt(1, anId);
			pstmt.setInt(2, orofos);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}

	public static void updateAlterPerioxesTable(int mainAreaId,String description,
			Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO alter_perioxes(DESCRIPTION,PERIOXH_ID) VALUES (?, ?)");
			pstmt.setString(1, description);
			pstmt.setInt(2,mainAreaId);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}
	public static void updateDhmoiTable(int nomosId,String description,int typeId,
			Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO geo_dhmoi_koinothtes(DESCRIPTION,NOMOS_ID,TYPE_ID) VALUES (?, ?, ?)");
			pstmt.setString(1, description);
			pstmt.setInt(2,nomosId);
			pstmt.setInt(3,typeId);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}
	public static void updatePhonesTable(String phones, int anId, int anType,
			Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_phones(ANID, PHONES, AN_TYPE) VALUES (?, ?, ?)");
			pstmt.setInt(1, anId);
			pstmt.setString(2, phones);
			pstmt.setInt(3, anType);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}

	public static void updateSellEarthAnnTable(Announcement announcement,
			PlotSellingAnnouncement annFeatures, int searchId,
			Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		if(annFeatures.getOtherFeatures().contains("'")){
			//System.out.println("*********************contains************************");
			annFeatures.setOtherFeatures(annFeatures.getOtherFeatures().replace("'",""));
		}
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_sell_earth( SEARCHID, MAINAREA_ID, SECONDAREA, TYPE_ID, INMAP, EMBADON, PRICE, COO_ID,OTHER)"
							+ " VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
			pstmt.setInt(1, searchId);
			pstmt.setInt(2, annFeatures.getMainAreaType().getId());
			pstmt.setString(3, annFeatures.getSecArea());
			IdDescription type = annFeatures.getType();
			if (type != null) {
				pstmt.setInt(4, type.getId());
			} else {
				pstmt.setNull(4, Types.INTEGER);
			}
			pstmt.setString(5, annFeatures.getInMap());
			DoubleStringFormat temp = annFeatures.getEmbadon();
			if (temp != null) {
				if (temp.getDoubleFormat() != null && temp.getDoubleFormat()!=0) {
					pstmt.setDouble(6, temp.getDoubleFormat());
				} else {
					pstmt.setNull(6, Types.DOUBLE);
				}
			} else {
				pstmt.setNull(6, Types.DOUBLE);
			}
			Double price = annFeatures.getPrice();
			if (price != null) {
				pstmt.setDouble(7, annFeatures.getPrice());
			} else {
				pstmt.setNull(7, Types.DOUBLE);
			}
			Integer cooId = annFeatures.getCoo_id();
			if(cooId!=null){
				pstmt.setInt(8,cooId);
			}else{
				pstmt.setNull(8,Types.INTEGER);
			}
			pstmt.setString(9, annFeatures.getOtherFeatures());
			pstmt.executeUpdate();

			pstmt1 = connection
					.prepareStatement("SELECT MAX(ANID) FROM ann_sell_earth");
			rset = pstmt1.executeQuery();
			rset.next();
			int anId = rset.getInt(1);
			announcement.setAnId(anId);
			ArrayList<Period> periods = announcement.getPeriods();
			if(periods!=null&& periods.size()>0){
			for (Period period : periods) {
				updateAnnPeriodTable(period, anId, AnnKeywords.SELL_EARTH_CODE,
						connection);
			}
			}
			ArrayList<String> phones = annFeatures.getPhones();
			if (phones != null && phones.size() > 0) {
				for (String phone : phones) {
					updatePhonesTable(phone, anId, AnnKeywords.SELL_EARTH_CODE,
							connection);
				}
			}
		} catch (SQLException ex) {
			ex.printStackTrace();

		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}

		}
	}

	public static void updateAnnPeriodTable(Period period, int anId,
			int anType, Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_period(ANID, START, END, AN_TYPE) VALUES (?, ?, ?, ?)");
			pstmt.setInt(1, anId);
			pstmt.setDate(2, period.getStart());
			pstmt.setDate(3, period.getEnd());
			pstmt.setInt(4, anType);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}

	public static void updateAnnPeriodDD(int id, Date ddDate,Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("UPDATE ann_period SET DD="+ddDate+" WHERE PID="+id);
//			pstmt.setInt(1, anId);
//			pstmt.setDate(2, period.getStart());
//			pstmt.setDate(3, period.getEnd());
//			pstmt.setInt(4, anType);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}

	}
	
	public static void updatePerioxesAttikhs(String description,
			int sellEarthId, Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO geo_perioxes_attikhs(DESCRIPTION, SELL_EARTH_ID) VALUES (?, ?)");
			pstmt.setString(1, description);
			pstmt.setInt(2, sellEarthId);
			pstmt.executeUpdate();
		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
		}
	}

	public static int updatePerioxesTable(String description, int nomosCode,
			Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		int areaId = -1;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO geo_perioxes(DESCRIPTION,NOMOS_ID) VALUES(?,?)");
			pstmt.setString(1, description);
			pstmt.setInt(2, nomosCode);
			pstmt.executeUpdate();
			pstmt1 = connection
					.prepareStatement("SELECT MAX(ID) FROM geo_perioxes");
			rset = pstmt1.executeQuery();
			rset.next();
			areaId = rset.getInt(1);

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return areaId;
		}

	}

	public static void updatePerioxesTable(IdDescription mainArea,
			int nomosCode, Connection connection) {
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO geo_perioxes(ID,DESCRIPTION,NOMOS_ID) VALUES(?,?,?)");
			pstmt.setInt(1, mainArea.getId());
			pstmt.setString(2, mainArea.getDescription());
			pstmt.setInt(3, nomosCode);
			System.out.println(mainArea.getDescription());
			pstmt.executeUpdate();

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}

		}

	}
	@SuppressWarnings("finally")
	public static int updateAnnCooTable(String name, int cooTypeId,
			Connection connection) {
		PreparedStatement pstmt = null;
		PreparedStatement pstmt1 = null;
		ResultSet rset = null;
		int cooId = -1;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO ann_cooperator(COO_TYPE,NAME) VALUES(?,?)");
			pstmt.setInt(1, cooTypeId);
			pstmt.setString(2, name);
			pstmt.executeUpdate();
			pstmt1 = connection
					.prepareStatement("SELECT MAX(ID) FROM ann_cooperator");
			rset = pstmt1.executeQuery();
			rset.next();
			cooId = rset.getInt(1);

		} catch (SQLException ex) {
			ex.printStackTrace();
		} finally {
			if (pstmt != null) {
				try {
					pstmt.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			if (rset != null) {
				try {
					rset.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing result set");
				}
			}
			if (pstmt1 != null) {
				try {
					pstmt1.close();
				} catch (SQLException ex) {
					ex.printStackTrace();
					System.out.println("Error in closing statement");
				}
			}
			return cooId;
		}

	}
	public static void update_xe_crawl(String URL,String descr,Connection connection)
	{
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO xe_crawl(Url,Description) VALUES(?,?)");
			pstmt.setString(1, URL);
			pstmt.setString(2,descr);
			pstmt.executeUpdate();
	}catch(SQLException ex){
		ex.printStackTrace();
		System.out.println("Updating xe_crawl Failed!!!!!");
	}
	}
	public static void update_xe_crawl_RENT(String URL,String descr,Connection connection)
	{
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO xe_crawl_RENT(Url,Description) VALUES(?,?)");
			pstmt.setString(1, URL);
			pstmt.setString(2,descr);
			pstmt.executeUpdate();
	}catch(SQLException ex){
		ex.printStackTrace();
		System.out.println("Updating xe_crawl Failed!!!!!");
	}
	}
	public static void update_xe_crawl_EARTH(String URL,String descr,Connection connection)
	{
		PreparedStatement pstmt = null;
		try {
			pstmt = connection
					.prepareStatement("INSERT INTO xe_crawl_EARTH(Url,Description) VALUES(?,?)");
			pstmt.setString(1, URL);
			pstmt.setString(2,descr);
			pstmt.executeUpdate();
	}catch(SQLException ex){
		ex.printStackTrace();
		System.out.println("Updating xe_crawl Failed!!!!!");
	}
	}
}
