
package crawling.database;

import java.sql.Connection;
import java.sql.Date;
import java.sql.DriverManager;
import java.util.ArrayList;
import java.util.Properties;
import crawling.AnnKeywords;
import crawling.DatabaseConstants;
import crawling.Utilities;
import crawling.entities.Announcement;
import crawling.entities.Auction;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.Period;
import crawling.entities.PlotSellingAnnouncement;
import crawling.entities.SearchInfo;

public class DistinctionNew {

	private Connection tempConnection;

	private Connection warehouseConn;

	private Date currentDate;

	private Date fromDate;

	public DistinctionNew(Date fromDate) {
		//currentDate = Date.valueOf("2010-07-13");
		currentDate = Date.valueOf("2011-02-19");
		this.fromDate = fromDate;
		if (!openMySQLConnection()) {
			throw new RuntimeException();
		}
	}

	/**
	 * For every cooperator in the temporary database if not exist in warehouse
	 * it adds it in
	 */
	private void compareCooperators() {
		for (int i = 1; i <= DatabaseConstants.NUMBER_OF_COOPERATORS_TYPES; i++) {
			ArrayList<IdDescription> tempCoos = DatabaseSelectManager
					.getNamesOfTypeCoo(i, tempConnection);
			for (IdDescription tempCoo : tempCoos) {
				if (DatabaseManager.isCooperatorAlreadyIn(tempCoo, i,
						warehouseConn)) {
					DatabaseUpdateManager.updateAnnCooTable(tempCoo
							.getDescription(), i, warehouseConn);
				}
			}
		}
	}

	private void comparePerioxes() {
		for (int i = 1; i <= DatabaseConstants.NUMBER_OF_NOMOI; i++) {
			ArrayList<IdDescription> tempPerioxes = DatabaseSelectManager.getPerioxesOfNomos(i, tempConnection);
			for (IdDescription perioxh : tempPerioxes) {
				if (!DatabaseManager.isPerioxhAlreadyIn(perioxh, i,warehouseConn)) {
					System.out.println("Nea perioxi="+perioxh);
					DatabaseUpdateManager.updatePerioxesTable(perioxh, i,warehouseConn);
				}
			}
		}

		ArrayList<IdDescription> tempPerioxes = DatabaseSelectManager
				.getPerioxesOfNomos(-1, tempConnection);
		for (IdDescription perioxh : tempPerioxes) {
			if (!DatabaseManager.isPerioxhAlreadyIn(perioxh, -1, warehouseConn)) {
				System.out.println("Nea perioxi="+perioxh);
				DatabaseUpdateManager.updatePerioxesTable(perioxh, -1,warehouseConn);
			}
		}
	}

	private void compareAnnouncements(int categoryId, int sourceId,
			int isOffer, boolean isSold) {
		// 
		for (int i = 1; i <= DatabaseConstants.NUMBER_OF_NOMOI ; i++) {
			//
			System.out.println("NOMOS:" + i);
			// Update search table
			int searchId = DatabaseUpdateManager.updateSearchTable(
					new SearchInfo(currentDate, new IdDescription(categoryId),
							new IdDescription(i), sourceId, isOffer, isSold),
					warehouseConn);
			if (categoryId == AnnKeywords.SELL_EARTH_CODE) {

				comparePlotAnnouncements(i, isOffer, sourceId, searchId,
						categoryId, fromDate);
			}
			if (categoryId == AnnKeywords.AUCTION_CODE) {
				compareAuctionAnnouncements(i, sourceId, searchId);
			} else {
				compareHouseAnnouncements(i, isOffer, sourceId, searchId,
						categoryId, fromDate);
			}
		}
	}

	private void comparePlotAnnouncements(int nomosId, int isOffer,
			int sourceId, int searchId, int categoryId, Date date) {
		ArrayList<Period> tempperiods = null;
		int newAnnouncements = 0;
		System.out
				.println("Getting earth announcements from temporary database...");
		ArrayList<PlotSellingAnnouncement> tempanns = DatabaseSelectManager
				.getEarthAnnouncement(isOffer, sourceId, nomosId,tempConnection);
		if (tempanns.size() == 0){
			System.out.println("ZERO Advertisments");
			
			return;
			}
		System.out.println("For this area there are " + tempanns.size()
				+ " available announcements.");
		if (sourceId == AnnKeywords.XRYSH_EYKAIRIA) {
			for (PlotSellingAnnouncement ann : tempanns) {
				if (DatabaseManager.isEarthAnnAlreadyIn(isOffer, sourceId, ann,
						warehouseConn)) {
					tempperiods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									tempConnection);
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									warehouseConn);
					addNewPeriods(tempperiods, periods, ann.getId(), categoryId);
				} else {
					DatabaseUpdateManager.updateSellEarthAnnTable(
							new Announcement(tempperiods), ann, searchId,
							warehouseConn);
					newAnnouncements++;
				}
			}
			System.out.println("New Advertisments :" + newAnnouncements+"\n");
		} else {
			for (PlotSellingAnnouncement ann : tempanns) {
				if (DatabaseManager.isEarthAnnAlreadyIn(isOffer, sourceId, ann,
						warehouseConn)) {
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									warehouseConn);
					if (periods.size() > 0) {
						ArrayList<Date> dates = new ArrayList<Date>(0);
						for (Period period : periods) {
							dates.add(period.getStart());
							dates.add(period.getEnd());
						}
						if (periods.size() == 1) {
							Period tempPeriod = periods.get(0);
							if (tempPeriod.getStart().compareTo(
									tempPeriod.getEnd()) == 0
									&& tempPeriod.getDd() == null) {
								DatabaseDeleteManager.deletePeriodsRecord(ann
										.getId(), categoryId, warehouseConn);
							}
						}
						dates = Utilities.sortDates(dates);
						int size = dates.size();
						Date startDate = dates.get(size - 1);
						Period newPeriod = null;
						for (Period period : periods) {
							if ((startDate.compareTo(period.getEnd()) == 0)
									&& (period.getDd() != null)) {
								newPeriod = new Period(currentDate, currentDate);
								break;
							}
						}
						if (newPeriod == null) {
							newPeriod = new Period(startDate, currentDate);
						}
						System.out.println("Updating Ann period");
						DatabaseUpdateManager.updateAnnPeriodTable(newPeriod,
								ann.getId(), AnnKeywords.SELL_EARTH_CODE,
								warehouseConn);
						ArrayList<String> phones = DatabaseSelectManager
								.getPhonesOfAnnouncement(ann.getId(),
										AnnKeywords.SELL_EARTH_CODE,
										warehouseConn);
						ArrayList<String> tempphones = DatabaseSelectManager
								.getPhonesOfAnnouncement(ann.getId(),
										AnnKeywords.SELL_EARTH_CODE,
										tempConnection);
						addNewPhones(tempphones, phones, ann.getId(),
								AnnKeywords.SELL_EARTH_CODE);
					}
				} else {
					tempperiods = new ArrayList<Period>(0);
					tempperiods.add(new Period(currentDate, currentDate));
					DatabaseUpdateManager.updateSellEarthAnnTable(
							new Announcement(tempperiods), ann, searchId,
							warehouseConn);
					newAnnouncements++;
				}
				System.out.println("NEW ANNOUNCEMENTS:" + newAnnouncements);
			}
		}
	}

	private boolean compareAuctionAnnouncements(int nomosId, int sourceId,
			int searchId) {
		boolean hasNew = false;
		ArrayList<Period> tempperiods = null;
		System.out.println("Getting house announcements from temporary database...");
		ArrayList<Auction> tempanns = DatabaseSelectManager
				.getAuctionAnnouncement(1, sourceId, nomosId, tempConnection);
		if (tempanns.size() == 0)
			return false;

		System.out.println("For this area there are " + tempanns.size()
				+ " new announcements.");
		System.out
				.println("Getting earth announcements from warehouse database...");

		for (Auction ann : tempanns) {
			if (DatabaseManager.isAuctionAnnAlreadyIn(1, sourceId, ann,
					warehouseConn)) {
				ArrayList<Period> periods = DatabaseSelectManager
						.getPeriodOfAnnouncement(ann.getId(),
								AnnKeywords.AUCTION_CODE, warehouseConn);
				addNewPeriods(tempperiods, periods, ann.getId(),
						AnnKeywords.AUCTION_CODE);
			} else {
				DatabaseUpdateManager.updateAuctionTable(new Announcement(
						tempperiods), ann, searchId, warehouseConn);
				hasNew = true;
			}
		}
		return hasNew;
	}

	private void compareHouseAnnouncements(int nomosId, int isOffer,
			int sourceId, int searchId, int categoryId, Date date) {
		ArrayList<Period> tempperiods = null;
		int newAnnouncements = 0;
		System.out
				.println("Getting house announcements from temporary database...");
		ArrayList<HouseAnnouncement> tempanns = DatabaseSelectManager
				.getHouseAnnouncement(isOffer, categoryId, sourceId, nomosId,
						tempConnection);
		if (tempanns.size() == 0)
			return;

		System.out.println("For this area there are " + tempanns.size()
				+ " new announcements.");
		/*if (sourceId == AnnKeywords.XRYSH_EYKAIRIA) {
			for (HouseAnnouncement ann : tempanns) {
				if (DatabaseManager.isHouseAnnAlreadyIn(isOffer, sourceId,
					                categoryId, ann, warehouseConn)) {
					System.out.println("Advertisment   Already In ");
					tempperiods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									tempConnection);
					
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									warehouseConn);
					addNewPeriods(tempperiods, periods, ann.getId(), categoryId);
				} else {
					System.out.println("Updating house");
					DatabaseUpdateManager.updateHouseAnnTable(new Announcement(
							tempperiods), ann, searchId, categoryId,
							warehouseConn);
					System.out.println("is writing announsment "+newAnnouncements);
					newAnnouncements++;
				}
			}
			System.out.println("NEW ANNOUNCEMENTS:" + newAnnouncements);
		} else {
		*/	
		for (HouseAnnouncement ann : tempanns) {
				if (DatabaseManager.isHouseAnnAlreadyIn(isOffer, sourceId,
						categoryId, ann, warehouseConn)) {
				//	System.out.println("Advertisment   Already In ");
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									warehouseConn);
					if (periods.size() > 0) {
						ArrayList<Date> dates = new ArrayList<Date>(0);
						for (Period period : periods) {
							dates.add(period.getStart());
							dates.add(period.getEnd());
						}
						if (periods.size() == 1) {
							Period tempPeriod = periods.get(0);
							if (tempPeriod.getStart().compareTo(
									tempPeriod.getEnd()) == 0) {
								DatabaseDeleteManager.deletePeriodsRecord(ann
										.getId(), categoryId, warehouseConn);
							}
						}
						dates = Utilities.sortDates(dates);
						int size = dates.size();
						Date startDate = dates.get(size - 1);
						Period newPeriod = null;
						for (Period period : periods) {
							if ((startDate.compareTo(period.getEnd()) == 0)
									&& (period.getDd() != null)) {
								newPeriod = new Period(currentDate, currentDate);
								break;
							}
						}
						if (newPeriod == null) {
							newPeriod = new Period(startDate, currentDate);
						}
						
						DatabaseUpdateManager.updateAnnPeriodTable(newPeriod,
								ann.getId(), categoryId, warehouseConn);
						ArrayList<String> phones = DatabaseSelectManager
								.getPhonesOfAnnouncement(ann.getId(),
										categoryId, warehouseConn);
						ArrayList<String> tempphones = DatabaseSelectManager
								.getPhonesOfAnnouncement(ann.getId(),
										categoryId, tempConnection);
						addNewPhones(tempphones, phones, ann.getId(),
								categoryId);
					}
				} else {
					tempperiods = new ArrayList<Period>(0);
					tempperiods.add(new Period(currentDate, currentDate));
					DatabaseUpdateManager.updateHouseAnnTable(new Announcement(
							tempperiods), ann, searchId, categoryId,
							warehouseConn);
					newAnnouncements++;
				}
				
			}
		System.out.println("NEW ANNOUNCEMENTS:" + newAnnouncements);	
		}
	//}

	private boolean hasCommonFloors(ArrayList<Integer> tempFloors,
			ArrayList<Integer> floors) {
		boolean same = false;
		for (Integer tempfloor : tempFloors) {
			for (Integer floor : floors) {
				if (floor.intValue() == tempfloor.intValue()) {
					same = true;
					break;
				}
			}
			if (!same) {
				return false;
			}
		}
		return true;
	}

	private void addNewPeriods(ArrayList<Period> tempperiods,
			ArrayList<Period> periods, int annId, int annType) {
		if (tempperiods != null && tempperiods.size() > 0) {
			for (Period tempPeriod : tempperiods) {
				boolean isAlreadyIn = false;
				for (Period period : periods) {
					if (Period.equal(period, tempPeriod)) {
						isAlreadyIn = true;
						break;
					}
				}
				if (!isAlreadyIn) {
					DatabaseUpdateManager.updateAnnPeriodTable(tempPeriod,
							annId, annType, warehouseConn);
				}
			}
		}
	}

	private void addNewPhones(ArrayList<String> tempphones,
			ArrayList<String> phones, int annId, int annType) {
		for (String tempphone : tempphones) {
			boolean isAlreadyIn = false;
			for (String phone : phones) {
				if (Utilities.isEqual(phone, tempphone)) {
					isAlreadyIn = true;
					break;
				}
			}
			if (!isAlreadyIn) {
				DatabaseUpdateManager.updatePhonesTable(tempphone, annId,
						annType, warehouseConn);
			}
		}
	}

	public void updatePeriodDD(int categoryId, int sourceId) {
		ArrayList<Integer> ids = new ArrayList<Integer>(0);
		if (categoryId == AnnKeywords.SELL_EARTH_CODE) {
			ids = DatabaseSelectManager.getAllPlotAnnouncements(categoryId,
					sourceId, warehouseConn);
		} else {
			ids = DatabaseSelectManager.getAllHouseAnnouncements(categoryId,
					sourceId, warehouseConn);
		}
		for (Integer id : ids) {
			ArrayList<Period> periodsAnn = DatabaseSelectManager
					.getPeriodOfAnnouncement(id, categoryId, warehouseConn);
			ArrayList<Date> dates = new ArrayList<Date>(0);
			for (Period period : periodsAnn) {
				dates.add(period.getStart());
				dates.add(period.getEnd());
			}
			ArrayList<Date> sortDates = Utilities.sortDates(dates);
			if (sortDates.size() > 0) {
				Date newestDate = sortDates.get(sortDates.size() - 1);
				if (newestDate.compareTo(currentDate) != 0) {
					for (Period period : periodsAnn) {
						if (period.getEnd().compareTo(newestDate) == 0
								&& period.getDd() == null) {
							DatabaseUpdateManager.updateAnnPeriodDD(id,
									currentDate, warehouseConn);
						}
					}
				}
			}
		}
	}

	/**
	 * Opens a connection with the mysql connection of ptyxiakh database
	 */
	private boolean openMySQLConnection() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			tempConnection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/temp09062009", props);
			warehouseConn = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/warehouse", props);

			return true;
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
			return false;
		}
	}

	/**
	 * @param args
	 * @throws InterruptedException
	 */
	@SuppressWarnings("static-access")
	public static void main(String args[]) throws InterruptedException {
		DistinctionNew distinction = new DistinctionNew(Date.valueOf("2010-07-12"));
		Thread t=new Thread();
		t.start();
		System.out.println("\t \t ******************************************************************************************");
		System.out.println("\t \t *  Transfering New Advertisments From Date "+distinction.fromDate+ " To Date " +distinction.currentDate+ "  Into Warehouse *");
	    System.out.println("\t \t ******************************************************************************************");
	    t.sleep(3000);
	    System.out.println("\t \t \t\t ******************************************************************");
		System.out.println(" \t\t\t\t *  Updating geo_perioxes WareHouse Table With Non Existing Areas *");
		System.out.println("\t \t \t \t ******************************************************************");
        t.sleep(2000);
	    distinction.comparePerioxes();
		/*distinction.compareCooperators();*/
	 	/*t.sleep(3000);
	 	System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t\tSource:����� ��������            *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t  DEMAND RENT HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(4000);
		distinction.compareAnnouncements(AnnKeywords.RENT_HOUSE_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 1, false);
		System.out.println("\t \t \t ****** Finished Demant Rent House Distinction ********\n");
		
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t  DEMAND SELL HOUSE DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(4000);
		distinction.compareAnnouncements(AnnKeywords.SELL_HOUSE_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 0, true);
		System.out.println("\t \t \t ****** Finished Demant SELL House Distinction ********\n");
		t.sleep(2000);
	    //	
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t  DEMAND SELL EARTH DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(4000);
		distinction.compareAnnouncements(AnnKeywords.SELL_EARTH_CODE,AnnKeywords.XRYSH_EYKAIRIA, 1, false);
		System.out.println("\t \t \t ****** Finished Demant Sell Earth Distinction  ********\n");
		t.sleep(2000);
		System.out.println("\t \t \t \t\t**************************************************");
		System.out.println(" \t\t\t \t\t*\t     Finished ����� ��������             *");
		System.out.println("\t \t \t \t\t**************************************************");
		*/
	    /*
	    System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t\tSource:�����������             *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(2000);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL EARTH 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.SELL_EARTH_CODE,
				AnnKeywords.ESTATE, 0, true);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     RENT HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.RENT_HOUSE_CODE,
				AnnKeywords.NEOMESITIKH, 1, false);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.SELL_HOUSE_CODE,
				AnnKeywords.NEOMESITIKH, 0, true);
		t.sleep(2000);		
		System.out.println("\t \t \t \t\t**************************************************");
		System.out.println(" \t\t\t \t\t*\t     Finished �����������            *");
		System.out.println("\t \t \t \t\t**************************************************");
		*/
	 /* System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t\tSource:E-state             *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(2000);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL EARTH 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.SELL_EARTH_CODE,
				AnnKeywords.ESTATE, 0, true);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     RENT HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.RENT_HOUSE_CODE,
				AnnKeywords.ESTATE, 1, false);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.SELL_HOUSE_CODE,
				AnnKeywords.ESTATE, 0, true);
		t.sleep(2000);		
		System.out.println("\t \t \t \t\t**************************************************");
		System.out.println(" \t\t\t \t\t*\t     Finished E-state               *");
		System.out.println("\t \t \t \t\t**************************************************");
		*/
	    
	/*	System.out.println("XRYSH EYKAIRA:OFFER EKSWXIKA DATA DISTINCTION...");
		distinction.compareAnnouncements(AnnKeywords.EKSWXIKA_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 1, false);
		System.out.println("XRYSH EYKAIRA:DEMAND EKSWXIKA DATA DISTINCTION...");
		distinction.compareAnnouncements(AnnKeywords.EKSWXIKA_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 0, false);
		System.out.println("XRYSH EYKAIRA:OFFER AUCTION DATA DISTINCTION...");
		distinction.compareAnnouncements(AnnKeywords.AUCTION_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 1, false);
		System.out.println("XRYSH EYKAIRA:DEMAND AUCTION DATA DISTINCTION...");
		distinction.compareAnnouncements(AnnKeywords.AUCTION_CODE,
				AnnKeywords.XRYSH_EYKAIRIA, 0, false);
*/
	    
	    
	/*    System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t\tSource:����������             *");
		System.out.println("\t \t \t **************************************************");
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL EARTH 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		distinction.compareAnnouncements(AnnKeywords.SELL_EARTH_CODE,
				AnnKeywords.KATHIMERINI, 0, true);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     RENT HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
		
		distinction.compareAnnouncements(AnnKeywords.RENT_HOUSE_CODE,
				AnnKeywords.KATHIMERINI, 1, false);
		t.sleep(2000);
		System.out.println("\t \t \t **************************************************");
		System.out.println(" \t\t\t *\t     SELL HOUSE 	DATA DISTINCTION...   *");
		System.out.println("\t \t \t **************************************************");
	
		distinction.compareAnnouncements(AnnKeywords.SELL_HOUSE_CODE,
				AnnKeywords.KATHIMERINI, 0, true);
		t.sleep(2000);
		System.out.println("\t \t \t \t\t**************************************************");
		System.out.println(" \t\t\t \t\t*\t     Finished ����������           *");
		System.out.println("\t \t \t \t\t**************************************************");
	
	/*/
	    }
}
