package crawling.databasecleaner;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Properties;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseChangeManager;
import crawling.database.DatabaseDeleteManager;
import crawling.database.DatabaseSelectManager;
import crawling.entities.IdDescription;
import crawling.entities.MainArea;
import crawling.entities.PlotSellingAnnouncement;

public class CleaningDatabase {

	private Connection connection;

	public CleaningDatabase() {
		if (openMySQLConnection()) {
			findWhereUnknownAreasAre();
			System.out.println("CLEANING WRONG WORDS...");
			cleanWrongWords();
			System.out.println("CLEANING NO CAPS WORDS...");
			cleanNoCapsAreas();
			System.out.println("TURN AREAS IN TO SUITABLE FORM...");
			turnAreasInToSuitableForm();
			System.out.println("TURN COMMON AREAS IN TO SUITABLE FORM...");
			cleanCommonAreaRecords();
			System.out
					.println("TURN COMMON AREAS WITH MORE WORDS IN TO SUITABLE FORM...");
			findTwoWordsAreas();
			System.out.println("CLEANING DOUBLE RECORDS...");
			cleanDoubleAreaRecords();
			cleanDoubleCooperatorsRecords();
		} else {
			System.out.println("ERROR:Can't open connection to database");
		}
		try {
			connection.close();
		} catch (SQLException ex) {
			ex.printStackTrace();
		}
	}

	/**
	 * Clean records that have wrong word in place of an area
	 */
	private void cleanWrongWords() {
		ArrayList<Integer> perioxesId = DatabaseSelectManager
				.getIdFromPerioxhId(connection);
		ArrayList<Integer> annHouseIds = DatabaseSelectManager
				.getIdsFromAnnHouse(perioxesId, connection);
		DatabaseDeleteManager.deleteOrofosRecords(annHouseIds, connection);
		DatabaseDeleteManager.deletePeriodsRecords(annHouseIds, 0, connection);
		DatabaseDeleteManager.deletePhonesRecords(annHouseIds, 0, connection);
		ArrayList<Integer> annSellEarthIds = DatabaseSelectManager
				.getIdsFromAnnSellEarth(perioxesId, connection);
		DatabaseDeleteManager.deletePeriodsRecords(annSellEarthIds,
				AnnKeywords.SELL_EARTH_CODE, connection);
		DatabaseDeleteManager.deletePhonesRecords(annSellEarthIds,
				AnnKeywords.SELL_EARTH_CODE, connection);

		DatabaseDeleteManager.deleteAnnHousesRecords(annHouseIds, connection);
		DatabaseDeleteManager.deleteAnnSellEarthRecords(annSellEarthIds,
				connection);
		DatabaseDeleteManager.deletePerioxesRecords(perioxesId, connection);
	}

	/**
	 * Change the words that aren't in caps with the same in caps
	 * 
	 */
	private void cleanNoCapsAreas() {
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
		for (IdDescription diamerisma : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diamerisma.getId(), connection);
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> areas = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), connection);
				ArrayList<IdDescription> checkAreas = (ArrayList<IdDescription>) areas
						.clone();
				ArrayList<Integer> idsChanged = new ArrayList<Integer>(0);
				for (IdDescription area : areas) {
					boolean changed = false;
					for (Integer id : idsChanged) {
						if (area.getId() == id.intValue()) {
							changed = true;
							break;
						}
					}
					if (!changed) {
						for (IdDescription checkArea : checkAreas) {
							if (WordUtilities.findDistance(area.getDescription(),
									checkArea.getDescription().toUpperCase()) <= 1
									&& (area.getId() != checkArea.getId())) {
								System.out.println("THIS AREA:"
										+ checkArea.getDescription()
										+ " CHANGE INTO:"
										+ area.getDescription());
								idsChanged.add(checkArea.getId());
								DatabaseChangeManager.changeAnnHouseTable(
										checkArea.getId(), area.getId(),
										connection);
								DatabaseChangeManager.changeAnnSellEarthTable(
										checkArea.getId(), area.getId(),
										connection);
								DatabaseChangeManager.changeGeoOdoiTable(
										checkArea.getId(), area.getId(),
										connection);
								DatabaseDeleteManager.deleteAreaRecords(
										checkArea.getId(), connection);
							}
						}
					}
				}
			}
		}
	}

	/**
	 * Correct some records replacing �GIOS klp me AG. kai NEOS klp me N.
	 */
	private void turnAreasInToSuitableForm() {
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
		for (IdDescription diam : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diam.getId(), connection);
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> perioxes = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), connection);
				for (IdDescription perioxh : perioxes) {
					int id = perioxh.getId();
					String descr = perioxh.getDescription();
					System.out.println("change perioxes table="+descr);
					DatabaseChangeManager.changePerioxesTable(id, WordUtilities
							.turnIntoSuitableForm(descr), connection);

				}
			}
		}

	}

	/**
	 * Finds the areas that differ in the two last letters end make them one
	 */
	private void cleanCommonAreaRecords() {
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
		for (IdDescription diamerisma : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diamerisma.getId(), connection);
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> areas = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), connection);
				ArrayList<IdDescription> tempAreas = (ArrayList<IdDescription>) areas
						.clone();
				ArrayList<Integer> idsChanged = new ArrayList<Integer>(0);
				for (IdDescription area : areas) {
					boolean changed = false;
					for (Integer id : idsChanged) {
						if (area.getId() == id.intValue()) {
							changed = true;
							break;
						}
					}
					if (!changed) {
						for (IdDescription tempArea : tempAreas) {
							if ((WordUtilities.findEndDistance(area
									.getDescription(), tempArea
									.getDescription()) == 0)
									&& (area.getId() != tempArea.getId())) {
								idsChanged.add(tempArea.getId());
								System.out.println("THIS AREA:"
										+ tempArea.getDescription()
										+ " CHANGE INTO:"
										+ area.getDescription());
								DatabaseChangeManager.changePerioxesTable(
										tempArea.getId(),
										area.getDescription(), connection);
							}
						}
					}
				}
			}
		}
	}

	/**
	 * Find the areas that have common the first words and different the last
	 * one and make them one
	 */
	private void findTwoWordsAreas() {
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
		for (IdDescription diamerisma : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diamerisma.getId(), connection);
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> areas = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), connection);
				ArrayList<IdDescription> tempAreas = (ArrayList<IdDescription>) areas
						.clone();
				ArrayList<Integer> idsChanged = new ArrayList<Integer>(0);
				for (IdDescription area : areas) {
					boolean changed = false;
					for (Integer id : idsChanged) {
						if (area.getId() == id.intValue()) {
							changed = true;
							break;
						}
					}
					if (!changed) {
						for (IdDescription tempArea : tempAreas) {
							if ((Utilities.hasCommonWord(area.getDescription(),
									tempArea.getDescription()))
									&& (area.getId() != tempArea.getId())) {
								idsChanged.add(tempArea.getId());
								System.out.println("THIS AREA:"
										+ tempArea.getDescription()
										+ " CHANGE INTO:"
										+ area.getDescription());
								DatabaseChangeManager.changePerioxesTable(
										tempArea.getId(),
										area.getDescription(), connection);
							}
						}
					}
				}
			}
		}
	}

	private void cleanDoubleAreaRecords() {
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
		for (IdDescription diamerisma : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diamerisma.getId(), connection);
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> areas = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), connection);
				ArrayList<IdDescription> tempAreas = (ArrayList<IdDescription>) areas
						.clone();
				ArrayList<Integer> idsDeleted = new ArrayList<Integer>(0);
				for (IdDescription area : areas) {
					boolean deleted = false;
					for (Integer id : idsDeleted) {
						if (area.getId() == id.intValue()) {
							deleted = true;
							break;
						}
					}
					if (!deleted) {
						for (IdDescription tempArea : tempAreas) {
							if ((area.getDescription().equals(tempArea
									.getDescription()))
									&& (area.getId() != tempArea.getId())) {
								idsDeleted.add(tempArea.getId());
								System.out.println("THIS AREA:"
										+ tempArea.getDescription()
										+ " CHANGE INTO:"
										+ area.getDescription());
								DatabaseChangeManager.changeAnnHouseTable(
										tempArea.getId(), area.getId(),
										connection);
								DatabaseChangeManager.changeAnnSellEarthTable(
										tempArea.getId(), area.getId(),
										connection);
								DatabaseChangeManager.changeGeoOdoiTable(
										tempArea.getId(), area.getId(),
										connection);
								DatabaseChangeManager
										.changeGeoDhmoiKoinothtesTable(tempArea
												.getId(), area.getId(),
												connection);
								DatabaseDeleteManager.deleteAreaRecords(
										tempArea.getId(), connection);
							}
						}
					}
				}
			}
		}
		System.out.println("Exit from cleaning double records....");
	}

	private void cleanDoubleCooperatorsRecords() {

		ArrayList<IdDescription> typeCoos = DatabaseSelectManager
				.getTypesOfCooperators(connection);
		for (IdDescription cooType : typeCoos) {
			ArrayList<IdDescription> coos = DatabaseSelectManager
					.getNamesOfTypeCoo(cooType.getId(), connection);
			ArrayList<IdDescription> tempCoos = (ArrayList<IdDescription>) coos
					.clone();

			ArrayList<Integer> idsDeleted = new ArrayList<Integer>(0);
			for (IdDescription coo : coos) {
				boolean deleted = false;
				for (Integer id : idsDeleted) {
					if (coo.getId() == id.intValue()) {
						deleted = true;
						break;
					}
				}
				if (!deleted) {
					for (IdDescription tempCoo : tempCoos) {
						if ((coo.getDescription().equals(tempCoo
								.getDescription()))
								&& (coo.getId() != tempCoo.getId())) {
							idsDeleted.add(tempCoo.getId());
							System.out.println("THIS COOPERATOR:"
									+ tempCoo.getDescription()
									+ " CHANGE INTO:" + coo.getDescription());
							DatabaseChangeManager.changeAnnHouseCooTable(
									tempCoo.getId(), coo.getId(), connection);
							DatabaseChangeManager.changeAnnSellEarthCooTable(
									tempCoo.getId(), coo.getId(), connection);
							DatabaseDeleteManager.deleteCooRecords(tempCoo.getId(), connection);
						}
					}
				}
			}
		}
	}
	
	private void findWhereUnknownAreasAre(){
		ArrayList<MainArea> unknownAreas = DatabaseSelectManager.getUnknownNomosAreas(connection);
		ArrayList<MainArea> knownAreas = DatabaseSelectManager.getAllKnownAreas(connection);
		for(MainArea unknownArea:unknownAreas){
			for(MainArea knownArea:knownAreas){
				if(WordUtilities.findDistance(unknownArea.getDescription(),knownArea.getDescription())<2){
					System.out.println(unknownArea.getDescription()+" is the same with "+knownArea.getDescription());
					DatabaseChangeManager.changeNomosId(unknownArea.getId(),knownArea.getNomos_id(),connection);
					break;
				}
			}
		}
	}

	private boolean openMySQLConnection() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			connection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/temp09062009", props);
			/*connection = DriverManager.getConnection(
					"jdbc:mysql://localhost/temp09062009", props);*/
			return true;
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
			return false;
		}
	}

	public static void main(String[] args) {
		CleaningDatabase cleaningDatabase = new CleaningDatabase();
	}
}
