package crawling.databasecleaner;

import java.sql.Connection;
import java.sql.Date;
import java.sql.DriverManager;
import java.util.ArrayList;
import java.util.Properties;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseDeleteManager;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.Auction;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.Period;
import crawling.entities.PlotSellingAnnouncement;

public class DublicateEntriesCleaner {

	private int categoryId;

	private int sourceId;

	private int nomosId;

	private int isOffer;
	
	private Date fromDate;
	
	private Date untilDate;

	private static Connection connection;

	public DublicateEntriesCleaner(int categoryCode, int sourceCode,
			int nomosId, int isOffer) {
		this.categoryId = categoryCode;
		this.sourceId = sourceCode;
		this.nomosId = nomosId;
		this.isOffer = isOffer;
		//this.fromDate = fromDate;
		//System.out.println(categoryCode+""+""+sourceCode+""+""+nomosId+""+""+isOffer);
		//this.untilDate = untilDate;
		fromDate=Date.valueOf(("2010-06-02"));
		cleanDublicateEntries();
	}

	private static boolean openMySQLConnection() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			connection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/temp09062009", props);
			/*connection = DriverManager.getConnection(
					"jdbc:mysql://localhost/temp09062009", props);*/

			return true;
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
			return false;
		}
	}

	private void cleanDublicateEntries() {
		//System.out.println(categoryId);
		if (categoryId == AnnKeywords.SELL_EARTH_CODE) {
			cleanSellEarthTable();
			//System.out.println("Cleaning Sell Earth Table From Double Records");
		} else if (categoryId == AnnKeywords.SELL_HOUSE_CODE
				|| categoryId == AnnKeywords.RENT_HOUSE_CODE) {
			cleanHouseTable();
		} else if (categoryId == AnnKeywords.AUCTION_CODE) {
			cleanAuctionTable();
		}
	}

	private void cleanSellEarthTable() {
		long counter=0;
		System.out.println(" Checking Sell Earth Table ");
		ArrayList<PlotSellingAnnouncement> records = DatabaseSelectManager
				.getEarthAnnouncement(isOffer, sourceId, nomosId, connection);
		//System.out.println(records.size());
		for (PlotSellingAnnouncement ann : records) {
			//System.out.println(ann);
			ArrayList<Integer> annsIds = DatabaseSelectManager.getSpecificEarthAnnouncement(isOffer,
							sourceId, nomosId, ann, connection);
			//System.out.println(annsIds.size());
			for (Integer annId : annsIds) {
				if (Utilities.isEqual(annId, ann.getId())) {
					//System.out.println("Tha same");
					continue;
					
				} else {
					counter++;
				System.out.println("Double Record With Id ="+annId )	;	
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									connection);
					ArrayList<Period> commonAnnPeriods = DatabaseSelectManager
							.getPeriodOfAnnouncement(annId, categoryId,
									connection);
					for (Period period : periods) {
						boolean equal = false;
						for (Period commonPeriod : commonAnnPeriods) {
							if (Period.equal(period, commonPeriod)) {
								equal = true;
								break;
							}
						}
						if (!equal) {
							DatabaseUpdateManager.updateAnnPeriodTable(period,
									annId, categoryId, connection);
						}
					}
					System.out.println("Cleaning Double Record");
					DatabaseDeleteManager.deletePeriodsRecord(ann.getId(),
							categoryId, connection);
					DatabaseDeleteManager.deleteAnnSellEarthRecord(ann.getId(),
							connection);
					DatabaseDeleteManager.deletePhonesRecord(ann.getId(),
							categoryId, connection);

				}
			}
			
		}
		System.out.println("Number Of Double Records Found  and Deleted = "+counter);
	}

	private void cleanSellEarthTable1() {
		ArrayList<PlotSellingAnnouncement> records = DatabaseSelectManager
				.getEarthAnnouncement(isOffer, sourceId, nomosId, fromDate,connection);
		ArrayList<PlotSellingAnnouncement> recordsToCheck = (ArrayList<PlotSellingAnnouncement>) records
				.clone();
		PlotSellingAnnouncement temp = null;
		for (PlotSellingAnnouncement rec : records) {
			ArrayList<Date> annDates = new ArrayList<Date>(0);
			annDates.add(DatabaseSelectManager.getSaveDataDate(rec
					.getSearchId(), connection));
			for (PlotSellingAnnouncement recToCheck : recordsToCheck) {
				if (recToCheck.getId() == rec.getId()) {
					temp = recToCheck;
					continue;
				}
				if (PlotSellingAnnouncement.equal(rec, recToCheck)
						&& (rec.getId() != recToCheck.getId())) {
					if (sourceId != AnnKeywords.XRYSH_EYKAIRIA) {
						Date tempDate = DatabaseSelectManager.getSaveDataDate(
								recToCheck.getSearchId(), connection);
						if (tempDate != null) {
							annDates.add(tempDate);
						}
						DatabaseDeleteManager.deleteAnnSellEarthRecord(
								recToCheck.getId(), connection);
						DatabaseDeleteManager.deletePhonesRecord(recToCheck
								.getId(), AnnKeywords.SELL_EARTH_CODE,
								connection);
					} else {
						DatabaseDeleteManager.deleteAnnSellEarthRecord(
								recToCheck.getId(), connection);
						DatabaseDeleteManager.deletePeriodsRecord(recToCheck
								.getId(), AnnKeywords.SELL_EARTH_CODE,
								connection);
					}
				}
			}
			addAnnPeriods(annDates, rec.getId(), categoryId);
			recordsToCheck.remove(temp);

		}
	}

	private void cleanAuctionTable() {
		ArrayList<Auction> records = DatabaseSelectManager
				.getAuctionAnnouncement(isOffer, sourceId, nomosId, connection);
		ArrayList<Auction> recordsToCheck = (ArrayList<Auction>) records
				.clone();
		Auction temp = null;
		for (Auction rec : records) {
			ArrayList<Date> annDates = new ArrayList<Date>(0);
			for (Auction recToCheck : recordsToCheck) {
				if (recToCheck.getId() == rec.getId()) {
					temp = recToCheck;
					continue;
				}
				if (Auction.isEqual(rec, recToCheck)
						&& (rec.getId() != recToCheck.getId())) {
					DatabaseDeleteManager.deleteAuctionRecord(recToCheck
							.getId(), connection);
					DatabaseDeleteManager.deletePeriodsRecord(recToCheck
							.getId(), categoryId, connection);
				}
			}
			recordsToCheck.remove(temp);
		}
	}

	private void cleanHouseTable() {
	//	System.out.println("Cleaning Double Records");
		long counter=0;
		System.out.println("Checking House Table ");
		ArrayList<HouseAnnouncement> records = DatabaseSelectManager
				.getHouseAnnouncement(isOffer, categoryId, sourceId, nomosId,
						connection);
		//System.out.println(records.size());
		for (HouseAnnouncement ann : records) {
		//	System.out.println("���"+"\t"+ann+"\n");
			//System.out.println(ann.getSecArea()+ann.getRoomNumber()+ann.getOtherFeatures()+ann.getSearchId());
		//	System.out.println(isOffer+"  "+categoryId+"  "+sourceId+" "+nomosId+"   "+ann);
			ArrayList<IdDescription> annsIds = DatabaseSelectManager
					.getSpecificHouseAnnouncement(isOffer, categoryId,
							sourceId, nomosId, ann, connection);
			
			//System.out.println("SIZE="    +annsIds.size());
			for (IdDescription annId : annsIds) {
				//System.out.println("Description:   "+annId.getDescription());
			//	System.out.println("Other Features : " + ann.getOtherFeatures());
			//	System.out.println("annID"+annId +"\n");
				//System.out.println("Checking  Advertisment with Id:  "+annId.getId() );
				if (Utilities.isEqual(annId.getId(), ann.getId())) {
					//System.out.println("No Double Records For This Advertisment");	
					continue;
				} else {
					if(Utilities.isEqual(annId.getDescription(),ann.getOtherFeatures())){
						counter++;
						System.out.println("Double Record  with ID:  "+annId.getId());	
					ArrayList<Period> periods = DatabaseSelectManager
							.getPeriodOfAnnouncement(ann.getId(), categoryId,
									connection);
					ArrayList<Period> commonAnnPeriods = DatabaseSelectManager
							.getPeriodOfAnnouncement(annId.getId(), categoryId,
									connection);
					for (Period period : periods) {
						boolean equal = false;
						for (Period commonPeriod : commonAnnPeriods) {
							if (Period.equal(period, commonPeriod)) {
								equal = true;
								break;
							}
						}
						if (!equal) {
							DatabaseUpdateManager.updateAnnPeriodTable(period,
									annId.getId(), categoryId, connection);
						}
					}
					System.out.println(" Cleaning Double Record ");
					DatabaseDeleteManager.deletePeriodsRecord(ann.getId(),
							categoryId, connection);
					DatabaseDeleteManager.deleteAnnHousesRecord(ann.getId(),
							connection);
					DatabaseDeleteManager.deletePhonesRecord(ann.getId(),
							categoryId, connection);
					DatabaseDeleteManager.deleteOrofosRecord(ann.getId(),
							connection);

				}
				}
				
			}
		}
		//System.out.println("No Double Records For This Area");
		System.out.println("Number Of Double Records Found  and Deleted  = "+counter+"\n");
	}

	private void cleanHouseTable1() {
		ArrayList<HouseAnnouncement> records = DatabaseSelectManager
				.getHouseAnnouncement(isOffer, categoryId, sourceId, nomosId,fromDate,
						connection);
		ArrayList<HouseAnnouncement> recordsToCheck = (ArrayList<HouseAnnouncement>) records		.clone();
		HouseAnnouncement temp = null;
		for (HouseAnnouncement rec : records) {
			//System.out.println(rec);
			ArrayList<Date> annDates = new ArrayList<Date>(0);
			for (HouseAnnouncement recToCheck : recordsToCheck) {
				if (recToCheck.getId() == rec.getId()) {
					temp = recToCheck;
					continue;
				}
				if (HouseAnnouncement.equal(rec, recToCheck)
						&& (rec.getId() != recToCheck.getId())) {
					if (sourceId != AnnKeywords.XRYSH_EYKAIRIA) {
						Date tempDate = DatabaseSelectManager.getSaveDataDate(
								recToCheck.getSearchId(), connection);
						if (tempDate != null) {
							annDates.add(tempDate);
						}
						DatabaseDeleteManager.deleteAnnHousesRecord(recToCheck
								.getId(), connection);
						DatabaseDeleteManager.deletePhonesRecord(recToCheck
								.getId(), categoryId, connection);
						DatabaseDeleteManager.deleteOrofosRecord(recToCheck
								.getId(), connection);
					} else {
						DatabaseDeleteManager.deleteAnnHousesRecord(recToCheck
								.getId(), connection);
						DatabaseDeleteManager.deletePeriodsRecord(recToCheck
								.getId(), categoryId, connection);
						DatabaseDeleteManager.deleteOrofosRecord(recToCheck
								.getId(), connection);
					}
				}
			}
			recordsToCheck.remove(temp);
		}
	}

	private void addAnnPeriods(ArrayList<Date> dates, int annId, int annType) {
		ArrayList<Date> sortedDates = Utilities.sortDates(dates);
		for (int i = 0; i < sortedDates.size() - 1; i++) {
			if (sortedDates.size() > 1) {
				DatabaseUpdateManager.updateAnnPeriodTable(new Period(
						sortedDates.get(i), sortedDates.get(i + 1)), annId,
						annType, connection);
			} else if (sortedDates.size() == 1) {
				DatabaseUpdateManager.updateAnnPeriodTable(new Period(
						sortedDates.get(0), sortedDates.get(0)), annId,
						annType, connection);
			}
		}
	}

	public static void main(String[] args) {
		openMySQLConnection();
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(connection);
	for (IdDescription diam : diamerismata) {
		ArrayList<IdDescription> nomoi = DatabaseSelectManager
				.getNomoysOfDiamerismata(diam.getId(), connection);
for (IdDescription nomos : nomoi) {
	System.out.println("****************************************************");	
	System.out.println("NOMOS:" + nomos.getDescription());
		//DublicateEntriesCleaner earthCleanerAggel1 = new DublicateEntriesCleaner(
					//	AnnKeywords.SELL_HOUSE_CODE,
					//	AnnKeywords.XRYSH_EYKAIRIA, Date.valueOf("2009-12-11"), "2010-01-24");
				/*DublicateEntriesCleaner earthCleanerAggel2 = new DublicateEntriesCleaner(
						AnnKeywords.SELL_HOUSE_CODE, AnnKeywords.AGGELIOXWROS,
						1, 1);
				DublicateEntriesCleaner earthCleanerAggel3 = new DublicateEntriesCleaner(
						AnnKeywords.SELL_HOUSE_CODE, AnnKeywords.NEOMESITIKH,
						1, 1);
				DublicateEntriesCleaner earthCleanerAggel8 = new DublicateEntriesCleaner(
						AnnKeywords.SELL_HOUSE_CODE, AnnKeywords.ESTATE, 1, 1);
					*/			
				 DublicateEntriesCleaner earthCleanerAggel4 = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
				/* DublicateEntriesCleaner earthCleanerAggel5 = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.AGGELIOXWROS,nomos.getId(),1);
				 DublicateEntriesCleaner earthCleanerAggel6 = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.NEOMESITIKH,nomos.getId(),1);
				 DublicateEntriesCleaner earthCleanerAggel7 = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.ESTATE,nomos.getId(),1);
				*///System.out.println("**********  Sell earth ***********");
				 DublicateEntriesCleaner earthCleanerAggelDemand = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_EARTH_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				 System.out.println("****************************************************");
			/*	 DublicateEntriesCleaner earthCleanerAggel1 = new
				 DublicateEntriesCleaner(AnnKeywords.AUCTION_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				*/ 
				 //DublicateEntriesCleaner earthCleanerAggelDemand1 = new
				// DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				//  AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
				/*
				 DublicateEntriesCleaner earthCleanerAggel21 = new
				 DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				 AnnKeywords.AGGELIOXWROS,nomos.getId(),1);
				 DublicateEntriesCleaner earthCleanerAggelDemand2 = new
				 DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				 AnnKeywords.AGGELIOXWROS,nomos.getId(),0);
				// DublicateEntriesCleaner earthCleanerAggel3 = new
				// DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				// AnnKeywords.NEOMESITIKH,nomos.getId(),1);
				 DublicateEntriesCleaner earthCleanerAggelDemand3 = new
				 DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				 AnnKeywords.NEOMESITIKH,nomos.getId(),0);
				 //DublicateEntriesCleaner earthCleanerAggel2 = new
				 //DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				// AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				 DublicateEntriesCleaner earthCleanerAggelDemand21 = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
				 System.out.println("NOMOS:"+nomos.getDescription());
				 System.out.println("SELL EARTH CLEANING(OFFER)...");
				 DublicateEntriesCleaner earthCleaner = new
				 DublicateEntriesCleaner(
				 AnnKeywords.SELL_EARTH_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA, 9, 1);
				 System.out.println("RENT HOUSE CLEANING(OFFER)...");
				 DublicateEntriesCleaner rentHouseCleaner = new
				 DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				 System.out.println("SELL HOUSE CLEANING(OFFER)...");
				 DublicateEntriesCleaner sellHouseCleaner = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				 System.out.println("EKSWXIKA CLEANING(OFFER)...");
				 DublicateEntriesCleaner ekswxikaCleaner = new
				 DublicateEntriesCleaner(AnnKeywords.EKSWXIKA_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),1);
				 System.out.println("SELL EARTH CLEANING...");
				 DublicateEntriesCleaner earthCleanerNotOffer = new
				 DublicateEntriesCleaner(
			     AnnKeywords.SELL_EARTH_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA, nomos.getId(), 0);
				 System.out.println("RENT HOUSE CLEANING...");
				 DublicateEntriesCleaner rentHouseCleanerNotOffer = new
				 DublicateEntriesCleaner(AnnKeywords.RENT_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
				 System.out.println("SELL HOUSE CLEANING...");
				 DublicateEntriesCleaner sellHouseCleanerNotOffer = new
				 DublicateEntriesCleaner(AnnKeywords.SELL_HOUSE_CODE,
				 AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
				 System.out.println("EKSWXIKA CLEANING...");
				// DublicateEntriesCleaner ekswxikaCleanerNotOffer = new
				// DublicateEntriesCleaner(AnnKeywords.EKSWXIKA_CODE,
				// AnnKeywords.XRYSH_EYKAIRIA,nomos.getId(),0);
			*/}
		}
	}

	
}
