package crawling.databasecleaner;
/**
 * Tool which clean database from wrong floors and wrong prices. Which means that in some cases there 
 * are advertisementes that have underground garages and instante of the right floor we consider that the
 * floor is -1. In case of price there is a function that returns only the very big prices for renting or
 * buying a house or a piece of earth and another function clean the database from these records and all \
 * the others that have some kind of connection only with them.
 */
import java.sql.Connection;
import java.sql.DriverManager;
import java.util.ArrayList;
import java.util.Properties;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.database.DatabaseChangeManager;
import crawling.database.DatabaseDeleteManager;
import crawling.database.DatabaseSelectManager;
import crawling.entities.IdDescription;
import crawling.entities.IdPrice;

public class ErrorCleaner {

	private Connection connection;

	public ErrorCleaner() {
		if (openMySQLConnection()) {
//			cleanWrongFloors();
			cleanWrongPricesRecords();
		}
	}

	protected boolean openMySQLConnection() {
		try {
			Class.forName("com.mysql.jdbc.Driver");
			Properties props = new Properties();
			props.put("user", "root");
			props.put("password", "");
			props.put("useUnicode", "true");
			props.put("characterEncoding", "utf-8");
			connection = DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/temp09062009", props);
			/*connection = DriverManager.getConnection(
					"jdbc:mysql://localhost/temp09062009", props);*/
			return true;
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("ERROR: Failed to get connection to database!");
			return false;
		}
	}

	/**
	 * Changes floor when the floor is -1 when this is wrong and there is
	 * another floor
	 */
	private void cleanWrongFloors() {
		ArrayList<IdDescription> anns = DatabaseSelectManager
				.getHouseAnnWithYpogeio(connection);
		int count = 0;
		for (IdDescription ann : anns) {
			int floor = findFloor(ann.getDescription());
			if (floor != -10) {
				count++;
				DatabaseChangeManager.changeFloor(floor, ann.getId(),
						connection);
			}
		}
		System.out.println("COUNTER:" + count);
	}

	/**
	 * Finds if there is another floor in the other field except -1 and if so it
	 * returns it
	 * 
	 * @param other
	 *            the other field of the houseAnn record
	 * @return the number of the floor if there is else -10
	 */
	private int findFloor(String other) {
		String[] otherArray = other.split(" ");
		for (String word : otherArray) {
			if ((word.endsWith("ïò") || word.endsWith("ïõ"))
					&& word.length() <= 4) {
				word = word.substring(0, word.length() - 2);
				if (Utilities.hasOnlyNumbers(word)) {
					return Integer.parseInt(Utilities.getOnlyNumbers(word));
				}
			}
		}
		return -10;
	}

	private void cleanWrongPricesRecords() {
		ArrayList<Integer> rentHouseAnns = DatabaseSelectManager
				.getOnlyBigPricesRentHouseAnn(connection);
		DatabaseDeleteManager.deleteOrofosRecords(rentHouseAnns, connection);
		DatabaseDeleteManager
				.deletePeriodsRecords(rentHouseAnns, 0, connection);
		DatabaseDeleteManager.deletePhonesRecords(rentHouseAnns, 0, connection);
		DatabaseDeleteManager.deleteAnnHousesRecords(rentHouseAnns, connection);
		ArrayList<Integer> sellHouseAnns = DatabaseSelectManager
				.getOnlyBigPricesSellHouseAnn(connection);
		DatabaseDeleteManager.deleteOrofosRecords(sellHouseAnns, connection);
		DatabaseDeleteManager
				.deletePeriodsRecords(sellHouseAnns, 0, connection);
		DatabaseDeleteManager.deletePhonesRecords(sellHouseAnns, 0, connection);
		DatabaseDeleteManager.deleteAnnHousesRecords(sellHouseAnns, connection);
		ArrayList<Integer> sellEarthAnns = DatabaseSelectManager
				.getOnlyBigPricesSellEarthAnn(connection);
		DatabaseDeleteManager.deletePeriodsRecords(sellEarthAnns,
				AnnKeywords.SELL_EARTH_CODE, connection);
		DatabaseDeleteManager.deletePhonesRecords(sellEarthAnns,
				AnnKeywords.SELL_EARTH_CODE, connection);
		DatabaseDeleteManager.deleteAnnSellEarthRecords(sellEarthAnns,
				connection);
		System.out.println("Finishing");

	}

	public static void main(String[] args) {
		ErrorCleaner errorCleaner = new ErrorCleaner();
	}

}
