package crawling.estate;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.CategoryValueEntity;
import crawling.entities.DoubleStringFormat;
import crawling.entities.IdDescription;
import crawling.entities.PlotSellingAnnouncement;

public class EstateEarthFeatExtr {
	
	private ArrayList<CategoryValueEntity> features;
	private Integer nomosId;
	private Integer typeOfEarthId;
	private Connection connection;
	//category:cooperator type and value:diakritikos titlos
	private CategoryValueEntity cooperator;
	private CategoryValueEntity surnameName;
	private String other;

	/**
	 * Creates a new <code>EstateEarthFeatExtr</code> object using the features of the announcement
	 * @param features
	 */
	public EstateEarthFeatExtr(ArrayList<CategoryValueEntity> features,Integer nomosId, Integer typeOfEarthId,Connection connection) {
		this.features = features;
		this.nomosId = nomosId;
		this.typeOfEarthId = typeOfEarthId;
		other="";
		cooperator = new CategoryValueEntity();
		surnameName = new CategoryValueEntity();
		this.connection = connection;
	}
	
	public PlotSellingAnnouncement extractPlotFeatures(){
		PlotSellingAnnouncement plotAnn=new PlotSellingAnnouncement();
		for(CategoryValueEntity entity:features){
			String category = entity.getCategory();
			if(category.equals(AnnKeywords.DHMOS)){
				plotAnn.setMainAreaType(extractMainArea(entity.getValue()));
			}else if(category.equals(AnnKeywords.PERIOXH)){
				plotAnn.setSecArea(entity.getValue());
			}else if(category.equals(AnnKeywords.TETR_METRA_OIKOPEDOY)){
				DoubleStringFormat embadon = new DoubleStringFormat();
				embadon.setStringFormat(entity.getValue());
				embadon.setDoubleFormat(Double.valueOf(entity.getValue()));
				plotAnn.setEmbadon(embadon);
			}else if(category.equals(AnnKeywords.TIMH_CAPS)){
				String doubleValue = entity.getValue();
				plotAnn.setPrice(Double.valueOf(Utilities.getOnlyNumbers(doubleValue.substring(0,doubleValue.length()-6))));
			}else if(category.equals(AnnKeywords.THLEFWNO)){
				ArrayList<String> phones = new ArrayList<String>(0);
				String phonesString = entity.getValue();
				if(phonesString.contains("-")){
					String[] phoneArray = phonesString.split("-");
					for(String phone:phoneArray){
						phones.add(phone);
					}
				}else{
					phones.add(phonesString);
				}
				plotAnn.setPhones(phones);
			}else if(category.equals(AnnKeywords.COORDINATOR_TYPE)){
//				System.out.println("TYPOS SYNERGATHS:"+entity.getValue());
				cooperator.setCategory(entity.getValue());
			}else if(category.equals(AnnKeywords.DIAKRITIKOS_TITLOS)){
//				System.out.println("DIAKRITIKOS TITLOS:"+entity.getValue());
//				System.out.println("LENGTH:"+entity.getValue().length());
				cooperator.setValue(entity.getValue());
			}else if(category.equals(AnnKeywords.ONOMA)){
				surnameName.setValue(entity.getValue());
			}else if(category.equals(AnnKeywords.EPWNYMO)){
				surnameName.setCategory(entity.getValue());
			}else if(category.equals(AnnKeywords.XARAKTHRISTIKA_TOPOTHESIAS)){
				plotAnn.setInMap(entity.getValue());
			}else{
				other+=entity.getCategory()+":"+entity.getValue()+",";
			}
		}
		if((cooperator.getValue()!=null) && (cooperator.getCategory()!=null)&&(cooperator.getValue().length()!=1)){
			plotAnn.setCoo_id(extractCooperator(cooperator));
			if(surnameName.getValue()!=null){
			other+=AnnKeywords.ONOMA+":"+surnameName.getValue()+",";
			}
			if(surnameName.getCategory()!=null){
			other+=AnnKeywords.EPWNYMO+":"+surnameName.getCategory();
			}
		}else if((cooperator.getValue()!=null)&&(cooperator.getValue().length()==1)&& (cooperator.getCategory()!=null)){
//			System.out.println("I GET IN HERE");
			if(surnameName.getValue()!=null && surnameName.getCategory()!=null){
			cooperator.setValue(surnameName.getValue()+" "+surnameName.getCategory());
			plotAnn.setCoo_id(extractCooperator(cooperator));
			}
		}else if(cooperator.getValue()==null && cooperator.getCategory()!=null){
//			System.out.println("I GET IN HERE");
			if(surnameName.getValue()!=null && surnameName.getCategory()!=null){
			cooperator.setValue(surnameName.getValue()+" "+surnameName.getCategory());
			plotAnn.setCoo_id(extractCooperator(cooperator));
			}
		}
		plotAnn.setOtherFeatures(other);
		plotAnn.setType(new IdDescription(typeOfEarthId));
		return plotAnn;
	}
	
	private IdDescription extractMainArea(String mainArea){
		IdDescription mainAreaType=new IdDescription();
		ArrayList<IdDescription> perioxesOfNomos = DatabaseSelectManager.getPerioxesOfNomos(nomosId,connection);
		boolean found=false;
		for(IdDescription perioxh: perioxesOfNomos){
			if(mainArea.equals(perioxh)||WordUtilities.findDistance(perioxh.getDescription(),mainArea)<=1 || perioxh.getDescription().toUpperCase().equals(mainArea)
					||mainArea.toUpperCase().equals(perioxh.getDescription())
					||WordUtilities.findDistance(mainArea.toUpperCase(),perioxh.getDescription().toUpperCase())<=1){
				mainAreaType=perioxh;
				found = true;
				break;
			}
		}
		if(!found){
			int id=DatabaseUpdateManager.updatePerioxesTable(mainArea,nomosId,connection);
			mainAreaType.setDescription(mainArea);
			mainAreaType.setId(id);
		}
		return mainAreaType;
	}

	private int extractCooperator(CategoryValueEntity cooperator){
		int cooTypeId = 0;
		int cooId=0;
		String typeOfCoo = cooperator.getCategory();
		ArrayList<IdDescription> cooTypes = DatabaseSelectManager.getTypesOfCooperators(connection);
		for(IdDescription cooType:cooTypes){
			if(cooType.getDescription().equals(typeOfCoo)){
				cooTypeId=cooType.getId();
				break;
			}
		}
		String nameOfCoo = cooperator.getValue();
		ArrayList<IdDescription> coos = DatabaseSelectManager.getNamesOfTypeCoo(cooTypeId,connection);
		if(coos!=null && coos.size()>0){
		for(IdDescription coo:coos){
			if(coo.getDescription().equals(nameOfCoo)){
				cooId=coo.getId();
				break;
			}
		}
		}
		if(cooId==0){
			cooId=DatabaseUpdateManager.updateAnnCooTable(nameOfCoo,cooTypeId,connection);
		}
		return cooId;
	}
}
