package crawling.estate;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.CategoryValueEntity;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.PlotSellingAnnouncement;

public class EstateHouseFeatExtr {
	
	private ArrayList<CategoryValueEntity> features;
	private Integer nomosId;
	private Integer typeOfHouseId;
	private Connection connection;
	//category:cooperator type and value:diakritikos titlos
	private CategoryValueEntity cooperator;
	private CategoryValueEntity surnameName;
	private String other;

	/**
	 * Creates a new <code>EstateEarthFeatExtr</code> object using the features of the announcement
	 * @param features
	 */
	public EstateHouseFeatExtr(ArrayList<CategoryValueEntity> features,Integer nomosId, Integer typeOfHouseId,Connection connection) {
		this.features = features;
		this.nomosId = nomosId;
		this.typeOfHouseId = typeOfHouseId;
		other="";
		cooperator = new CategoryValueEntity();
		this.connection = connection;
		surnameName = new CategoryValueEntity();
	}
	
	public HouseAnnouncement extractHouseFeatures(){
		HouseAnnouncement houseAnn=new HouseAnnouncement();
		for(CategoryValueEntity entity:features){
			String category = entity.getCategory();
			if(category.equals(AnnKeywords.DHMOS)){
				houseAnn.setMainArea(extractMainArea(entity.getValue()));
			}else if(category.equals(AnnKeywords.PERIOXH)){
				houseAnn.setSecArea(entity.getValue());
			}else if(category.contains(AnnKeywords.TETR_METRA_AKINHTOY)){
				DoubleStringFormat embadon = new DoubleStringFormat();
				embadon.setStringFormat(entity.getValue());
				embadon.setDoubleFormat(Double.valueOf(entity.getValue()));
				houseAnn.setEmbadon(embadon);
			}else if(category.equals(AnnKeywords.TIMH_CAPS)){
				String doubleValue = entity.getValue();
				houseAnn.setPrice(Double.valueOf(Utilities.getOnlyNumbers(doubleValue.substring(0,doubleValue.length()-6))));
			}else if(category.equals(AnnKeywords.THLEFWNO)){
				ArrayList<String> phones = new ArrayList<String>(0);
				String phonesString = entity.getValue();
				if(phonesString.contains("-")){
					String[] phoneArray = phonesString.split("-");
					for(String phone:phoneArray){
						phones.add(phone);
					}
				}else{
					phones.add(phonesString);
				}
				houseAnn.setPhones(phones);
			}else if(category.equals(AnnKeywords.COORDINATOR_TYPE)){
				cooperator.setCategory(entity.getValue());
			}else if(category.equals(AnnKeywords.DIAKRITIKOS_TITLOS)){
				cooperator.setValue(entity.getValue());
			}else if(category.equals(AnnKeywords.OROFOS_ESTATE)){
				String orofosValue = entity.getValue();
				ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
				if(orofosValue.equals(AnnKeywords.ISOGEIO_ESTATE)||orofosValue.equals(AnnKeywords.HMIISOGEIO_ESTATE)){
					orofoi.add(0);
				}else if(orofosValue.equals(AnnKeywords.HMIORWFOS_ESTATE)){
					orofoi.add(1);
				}else if(orofosValue.equals(AnnKeywords.YPOGEIO_ESTATE)||orofosValue.equals(AnnKeywords.HMIYPOGEIO_ESTATE)){
					orofoi.add(-1);
				}else{
					orofoi.add(Integer.valueOf(orofosValue.replace("ïò","")));
				}
			}else if(category.equals(AnnKeywords.YPNODWMATIA_ESTATE)){
				houseAnn.setRoomNumber(entity.getValue());
			}else if(category.equals(AnnKeywords.ONOMA)){
				surnameName.setValue(entity.getValue());
			}else if(category.equals(AnnKeywords.EPWNYMO)){
				surnameName.setCategory(entity.getValue());
			}else{
				other+=entity.getCategory()+":"+entity.getValue()+",";
			}
		}
		if((cooperator.getValue()!=null) && (cooperator.getCategory()!=null)&&(cooperator.getValue().length()!=1)){
			houseAnn.setCoo_id(extractCooperator(cooperator));
			if(surnameName.getValue()!=null){
			other+=AnnKeywords.ONOMA+":"+surnameName.getValue()+",";
			}
			if(surnameName.getCategory()!=null){
			other+=AnnKeywords.EPWNYMO+":"+surnameName.getCategory();
			}
		}else if((cooperator.getValue()!=null&&cooperator.getValue().equals("")&& cooperator.getCategory()!=null)||
				(cooperator.getValue()==null && cooperator.getCategory()!=null)){
			if(surnameName.getValue()!=null && surnameName.getCategory()!=null){
			cooperator.setValue(surnameName.getValue()+" "+surnameName.getCategory());
			houseAnn.setCoo_id(extractCooperator(cooperator));
			}
		}
		houseAnn.setOtherFeatures(other);
		houseAnn.setType(new IdDescription(typeOfHouseId));
		return houseAnn;
	}
	
	private IdDescription extractMainArea(String mainArea){
		IdDescription mainAreaType=new IdDescription();
		ArrayList<IdDescription> perioxesOfNomos = DatabaseSelectManager.getPerioxesOfNomos(nomosId,connection);
		boolean found=false;
		for(IdDescription perioxh: perioxesOfNomos){
			if(mainArea.equals(perioxh)||WordUtilities.findDistance(perioxh.getDescription(),mainArea)<=1 || perioxh.getDescription().toUpperCase().equals(mainArea)
					||mainArea.toUpperCase().equals(perioxh.getDescription())
					||WordUtilities.findDistance(mainArea.toUpperCase(),perioxh.getDescription().toUpperCase())<=1){
				mainAreaType=perioxh;
				found = true;
				break;
			}
		}
		if(!found){
			int id=DatabaseUpdateManager.updatePerioxesTable(mainArea,nomosId,connection);
			mainAreaType.setDescription(mainArea);
			mainAreaType.setId(id);
		}
		return mainAreaType;
	}

	private int extractCooperator(CategoryValueEntity cooperator){
		int cooTypeId = 0;
		int cooId=0;
		String typeOfCoo = cooperator.getCategory();
		ArrayList<IdDescription> cooTypes = DatabaseSelectManager.getTypesOfCooperators(connection);
		for(IdDescription cooType:cooTypes){
			if(cooType.getDescription().equals(typeOfCoo)){
				cooTypeId=cooType.getId();
				break;
			}
		}
		String nameOfCoo = cooperator.getValue();
		ArrayList<IdDescription> coos = DatabaseSelectManager.getNamesOfTypeCoo(cooTypeId,connection);
		if(coos!=null && coos.size()>0){
		for(IdDescription coo:coos){
			if(coo.getDescription().equals(nameOfCoo)){
				cooId=coo.getId();
				break;
			}
		}
		}
		if(cooId==0){
			cooId=DatabaseUpdateManager.updateAnnCooTable(nameOfCoo,cooTypeId,connection);
		}
		return cooId;
	}
}
