package crawling.kathimerini;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.database.DatabaseSelectManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.*;

public class KathimeriniHouseFeatExtr extends AnnFeatExtraction {

	private String advText;

	private HouseAnnouncement features;

	private int nomosId;

	private Connection connection;

	public KathimeriniHouseFeatExtr(String advText, int nomosId,
			Connection connection) {
		super(0, advText, connection);
		this.advText = advText;
	}

	public KathimeriniHouseFeatExtr(String advText, HouseAnnouncement features,
			int nomosId, Connection connection) {
		super(0, advText, connection);
		this.advText = advText;
		this.features = features;
	}

	protected void editAnnFeatures() {
		String[] annPieces = advText.split(",");
		DoubleStringFormat embadon = null;
		String bedrooms = null;
		String price = null;
		ArrayList<String> phones = new ArrayList<String>(0);
		advText = advText.replace("<B>" + features.getMainArea().getDescription()
				+ "</B>", "");
		annPieces = advText.split(",");
		for (String piece : annPieces) {
			price = getPrice2(piece.split(" "));
			if (price != null) {
				String priceNum = Utilities.getOnlyNumbers(price);
				if (!priceNum.equals("")) {
					if (price.contains(AnnKeywords.ANA_XRONO)
							|| price.contains(AnnKeywords.ETHSIW)) {
						features.setPrice(Double.parseDouble(priceNum) / 12);
					} else {
						features.setPrice(Double.parseDouble(priceNum));
					}
					advText = advText.replace(AnnKeywords.TIMH, "");
					advText = advText.replace(AnnKeywords.EYRW, "");
					advText = advText.replace(price, "");
					features.setOtherFeatures(advText);
					break;
				}
			}
		}

		boolean isMezoneta = false;
		IdDescription typeOfHouse;
		annPieces = advText.split(",");
		for (String piece : annPieces) {
			typeOfHouse = getType(piece.split(" "), DatabaseSelectManager
					.getTypesOfHouse(getConnection()));
			if (typeOfHouse != null) {
				if (typeOfHouse.getDescription().equals(AnnKeywords.MEZONETA)) {
					isMezoneta = true;
				}
				features.setType(typeOfHouse);
				advText = advText.replace(typeOfHouse.getDescription(), "");
				advText = advText.replace(typeOfHouse.getDescription().toUpperCase(),"");
				features.setOtherFeatures(advText);
				break;
			}
		}

		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		annPieces = advText.split(",");
		for (String piece : annPieces) {
			orofoi = getOrofoys(piece.split(" "), isMezoneta);
			if (orofoi != null) {
				features.setOrofoi(orofoi);
				for (Integer orf : orofoi) {
					advText = advText.replace(orf + "ïò", "");
					advText = advText.replace(orf + "ïõ", "");
				}
				advText = advText.replace(AnnKeywords.OROFWN,"");
				advText = advText.replace(AnnKeywords.OROFOY,"");
				advText = advText.replace(AnnKeywords.OROFOS, "");
				advText = advText.replace(AnnKeywords.ISOGEIO, "");
				advText = advText.replace(AnnKeywords.ISOGEIO_XWRIS, "");
				advText = advText.replace(AnnKeywords.YPOGEIO, "");
				advText = advText.replace(AnnKeywords.HMIOROFOS, "");
				features.setOtherFeatures(advText);
				break;
			}
		}
		for (String piece : annPieces) {
			embadon = getEmbadon(piece.split(" "));
			//embadon=getEmbadon(piece.split)
			if (embadon != null) {
				//System.out.println("HEllo");
				break;
			}
		}
		if (embadon != null) {
			features.setEmbadon(embadon);
			advText = advText.replace(embadon.getStringFormat(),"");
			features.setOtherFeatures(advText);
		}
		for (String piece : annPieces) {
			bedrooms = getBedRooms(piece.split(" "));
			//System.out.println(piece.split(" "));
			if (bedrooms != null) {
		   //System.out.println(bedrooms);	
				break;
			}
		}
		if (bedrooms != null) {
			features.setRoomNumber(bedrooms);
			advText = advText.replace(bedrooms,"");
			advText = advText.replace(AnnKeywords.YD,"");
			advText = advText.replace(AnnKeywords.YPN,"");
			advText = advText.replace(AnnKeywords.YPNO,"");
			advText = advText.replace(AnnKeywords.YPNODWMATIA,"");
			advText = advText.replace(AnnKeywords.YPNOY,"");
			
			features.setOtherFeatures(advText);
		}
		for(String piece :annPieces){
			phones = getPhones2(piece.split(" "));
			if(phones!=null){
				break;
			}
		}
		if(phones!=null){
			features.setPhones(phones);
			for(String phone:phones){
			advText = advText.replace(phone,"");
			}
			advText = advText.replace(AnnKeywords.THLEFWNO,"");
			advText = advText.replace(AnnKeywords.THLEPIKOINWNIAS,"");
			advText = advText.replace(AnnKeywords.THL,"");
			advText = advText.replace(AnnKeywords.THLMIKRO,"");
		}
		advText = advText.replace(", ,","");
		advText = advText.replace(",  ,","");
		advText = advText.replace(" ,   , ","");
		advText = advText.replace(" ,    ,","");
		advText = advText.replace("()","");
		features.setOtherFeatures(advText);
	}


	public HouseAnnouncement getFeatures() {
		return features;
	}

	public void setFeatures(HouseAnnouncement features) {
		this.features = features;
	}

}
