package crawling.kathimerini;

import java.sql.Connection;
import java.sql.DriverManager;
import java.util.*;

import crawling.AnnKeywords;
import crawling.ReadSource;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.Announcement;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.PlotSellingAnnouncement;
import crawling.entities.SearchInfo;


public class KathimeriniTest {
	//URLs and specific words for the advertisements
	public static final String URL = "http://trans.kathimerini.gr/aggelies";
	public static final String MAIN_URL = "http://trans.kathimerini.gr";
	public static final String LINK_START = "href=\'/4dcgi/classif/subcategorie_flag";
	public static final String LINK_END = "</a></td></tr>";
	public static final String[] sell_house_words = {"Aνατολικής Aθήνας","Bόρειας Aθήνας","Δυτικής Aθήνας","Nότιας Aθήνας","Δήμου Aθήνας","	Δήμου Πειραιά","Nομού Aττικής","Aκίνητα Θεσσαλονίκης","Aκίνητα σε όλη τη χώρα"};
	public static final String[] rent_house_words = {"Aκίνητα Eνοικιάζονται", "Aκίνητα Θεσσαλονίκης"};
	public static final String[] sell_earth_words = {"Aνατολικής Aθήνας", "Bόρειας Aθήνας", "Δυτικής Aθήνας", "Nότιας Aθήνας", "Δήμου Aθήνας", "Δήμου Πειραιά", "Nομού Aττικής", "Oικόπεδα Θεσσαλονίκης", "Oικόπεδα σε όλη τη χώρα"};
	
	//********************************************************************************************************************
	// Extraction Tags
	//********************************************************************************************************************
		public static final String LINK_START_TAG = "<td class=small><a href=";

		public static final String LINK_END_TAG = "</a>";

		public static final String ADVS_START_TAG = "<TR><TD><span class=\"sidemenulinks\"><P>";
													 
		public static final String ADVS_END_TAG = "</span>";

		public static final String DEVIDE_TAG = "<HR>";
	    int counter=0;
		private Connection connection;
	
	public KathimeriniTest(){
		ReadSource rsrc = new ReadSource(URL, AnnKeywords.KATHIMERINI);
		String source = rsrc.getSource();
		ArrayList<String> urls = Utilities.extractAllTexts(source,LINK_START, LINK_END);

		for (String u: urls){
			counter++;
			String word = u.substring((u.indexOf(">")+1),u.length());
			String l = LINK_START.substring(LINK_START.indexOf("/"),LINK_START.length());

			String new_url = MAIN_URL + l + u.substring(0,(u.indexOf(word)-2));
			System.out.println("Link: "+new_url);
			boolean b ;
			if (b=is_sell_earth(word,counter)){
				System.out.println("SELL EARTH: " + u);
				advExtraction(new_url, false,AnnKeywords.SELL_EARTH_CODE);
			}
			else if (b=is_sell_house(word,counter)){
				System.out.println("SELL HOUSE: " + u);
				advExtraction(new_url, false,AnnKeywords.SELL_HOUSE_CODE);
			}
			else if (b=is_rent_house(word,counter)){
				System.out.println("RENT HOUSE: " + u);
				advExtraction(new_url, false,AnnKeywords.RENT_HOUSE_CODE);
			}
		}
	}
	//Methods for check the kind of advertisement
	public boolean is_sell_earth(String url, int c) {
		for(String i: sell_earth_words){
			boolean b= i.contains(url);
			if ((b)&&(c < 17)&&(c > 4)){
				return true;
			}
		}
		return false;
	}
	
	public boolean is_sell_house(String url, int c){
		for(String i: sell_house_words){
			boolean b= i.contains(url);
			if ((b)&&(c >= 17)){
				return true;
			}
		}
		return false;
	}
	
	public boolean is_rent_house(String url, int c){
		for(String i: rent_house_words){
			boolean b= i.contains(url);
			if ((b)&&(c < 5)){
				return true;
			}
		}
		return false;
	}
	
	
	private void advExtraction(String URL, boolean isRent, int advType) {
		ReadSource rsrc = new ReadSource(URL, AnnKeywords.KATHIMERINI);
		String source = rsrc.getSource();

		ArrayList<String> urls = Utilities.extractAllTexts(source,LINK_START_TAG, LINK_END_TAG);

		if (!openMySQLConnection()) {
			System.out.println("CAN'T MATCH AREA NAMES!ERROR IN OPENNING CONNECTION TO DATABASE!!!");
		}
		ArrayList<IdDescription> areaNames;
		int cont=0;

		if (urls.size()==0){
			String[] info = {"",""};
			info[0]=URL.substring(URL.indexOf("/4"));
			ArrayList<String> info2=Utilities.extractAllTexts(source, "<div class='ctytle'><center>", "</center>");
			for(String i:info2){
				info[1]=i;
			}

			IdDescription perioxh = null;
			int nomos=0;
			int id=1 ;
	
			if (URL.contains("Aκίνητα Θεσσαλονίκης")|| URL.contains("Oικόπεδα Θεσσαλονίκης")) {
				nomos=2;
				areaNames = DatabaseSelectManager.getPerioxesOfNomos(2,connection);

				perioxh = fixPerioxes(info[1], areaNames);

				if (perioxh == null) {
					id = DatabaseUpdateManager.updatePerioxesTable(info[1], nomos,connection);
					System.out.println("NEW ID   ="+id);
					System.out.println("UpdatePerioxesTable :"+info[1]);
					perioxh = new IdDescription(id,info[1]);
				}
			}
	
			else if (URL.contains("Aκίνητα σε όλη τη χώρα")|| URL.contains("Oικόπεδα σε όλη τη χώρα")) {
				ArrayList<IdDescription> diamerismata = DatabaseSelectManager.getDiamerismata(connection);
				for (IdDescription diamerisma : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diamerisma.getId(),connection);
					for (IdDescription nom : nomoi) {
						areaNames = DatabaseSelectManager.getPerioxesOfNomos(nom.getId(), connection);
						perioxh = fixPerioxes(info[1], areaNames);
						
						if (perioxh != null) {
							nomos=nom.getId();
							break;
						}
					}
					if(perioxh!=null){
						break;
					}
				}
			}
	
			else 
				{
				areaNames = DatabaseSelectManager.getPerioxesOfNomos(1,connection);
				nomos=1;
				perioxh = fixPerioxes(info[1], areaNames);
				System.out.println("Methodos Fix_Perioxes");
				if (perioxh == null) {
					id = DatabaseUpdateManager.updatePerioxesTable(info[1], nomos,connection);
					System.out.println(id);
					System.out.println("NEW ID   ="+id);
					System.out.println("UpdatePerioxesTable   :"+info[1]);
					perioxh = new IdDescription(id,info[1]);
				}
				
			   } // Allagh sta IF Parakatw htan (perioxh!=null)
	

			if (perioxh!=null){
				 SearchInfo searchInfo = new SearchInfo();
				if (advType==AnnKeywords.SELL_HOUSE_CODE)
				{
					searchInfo.setSold(true);
				}
				if (advType==AnnKeywords.RENT_HOUSE_CODE){
					searchInfo.setOffer(1);
				}
				if(advType==AnnKeywords.SELL_EARTH_CODE)
				{
					searchInfo.setSold(true);
				}
			    searchInfo.setCategory(new IdDescription(advType));
			    searchInfo.setDate(new java.sql.Date(System.currentTimeMillis()));
			    searchInfo.setNomos(new IdDescription(nomos));
			    //searchInfo.setOffer(1);
			    searchInfo.setPerioxh(perioxh);
			    searchInfo.setSourceId(AnnKeywords.KATHIMERINI);
			    searchInfo.setSearchId(DatabaseUpdateManager.updateSearchTable(searchInfo,connection));
				ReadSource advsReadSource = new ReadSource(MAIN_URL + info[0],
						AnnKeywords.KATHIMERINI);
				String advsSource = advsReadSource.getSource();
				String advsText = Utilities.getText(advsSource, ADVS_START_TAG,
						ADVS_END_TAG);
				String[] advs = advsText.split(DEVIDE_TAG);
	
			if ((advType == AnnKeywords.SELL_HOUSE_CODE)|| (advType == AnnKeywords.RENT_HOUSE_CODE)) {
				for (String adv : advs) {
					HouseAnnouncement houseAnn = new HouseAnnouncement();
					houseAnn.setMainArea(new IdDescription(perioxh.getId(), info[1]));
					houseAnn.setRent(isRent);
				//	System.out.println(houseAnn);
					KathimeriniHouseFeatExtr featExtr = new KathimeriniHouseFeatExtr(adv, houseAnn, 0, connection);
					featExtr.editAnnFeatures();
					houseAnn = featExtr.getFeatures();
					System.out.println("ANN:"+houseAnn);
					
				DatabaseUpdateManager.updateHouseAnnTable(new Announcement(),houseAnn,searchInfo.getSearchId(),advType,connection);
				}//for
			}//if
	
			else {
				for (String adv : advs) {
					PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement();
					plotAnn.setMainAreaType(new IdDescription(id, info[1]));
					KathimeriniEarthFeatExtr featExtr = new KathimeriniEarthFeatExtr(adv, plotAnn, 0, connection);
					featExtr.editAnnFeatures();
					plotAnn = featExtr.getFeatures();
				//	System.out.println("ANN:"+plotAnn);
					DatabaseUpdateManager.updateSellEarthAnnTable(new Announcement(),plotAnn,searchInfo.getSearchId(),connection);
				}//for
			}//else

			}//if
		}//if (checking --> with links in the code)
		//In this case, the page has got links
		else {
			
		
		for (String url : urls) {
			System.out.println("Extracted text"+url);
			cont++;
			String temp = url.replace("\'", "");
			//System.out.println("Replaced text"+temp);
			String[] info = temp.split(">");
			//Split the string and save tha pattern before ">" into info[0] and tha pettern after ">" into info[1]
			//System.out.println("info"+ info[0]);
			//System.out.println("AREA:" + info[1]);
	
			IdDescription perioxh = null;
			int nomos=0;
			int id=1 ;
	
			if (URL.contains("Aκίνητα Θεσσαλονίκης")|| URL.contains("Oικόπεδα Θεσσαλονίκης")) {
				nomos=2;
				areaNames = DatabaseSelectManager.getPerioxesOfNomos(2,connection);

				perioxh = fixPerioxes(info[1], areaNames);

				if (perioxh == null) {
					id = DatabaseUpdateManager.updatePerioxesTable(info[1], nomos,connection);
					System.out.println("NEW ID   ="+id);
					System.out.println("UpdatePerioxesTable :"+info[1]);
					perioxh = new IdDescription(id,info[1]);
				}
			}
	
			else if (URL.contains("Aκίνητα σε όλη τη χώρα")|| URL.contains("Oικόπεδα σε όλη τη χώρα")) {
				ArrayList<IdDescription> diamerismata = DatabaseSelectManager.getDiamerismata(connection);
				for (IdDescription diamerisma : diamerismata) {
					ArrayList<IdDescription> nomoi = DatabaseSelectManager
							.getNomoysOfDiamerismata(diamerisma.getId(),connection);
					for (IdDescription nom : nomoi) {
						areaNames = DatabaseSelectManager.getPerioxesOfNomos(nom.getId(), connection);
						perioxh = fixPerioxes(info[1], areaNames);
						
						if (perioxh != null) {
							nomos=nom.getId();
							break;
						}
					}
					if(perioxh!=null){
						break;
					}
				}
			}
	
			else 
				{
				areaNames = DatabaseSelectManager.getPerioxesOfNomos(1,connection);
				nomos=1;
				perioxh = fixPerioxes(info[1], areaNames);
				System.out.println("Methodos Fix_Perioxes");
				if (perioxh == null) {
					id = DatabaseUpdateManager.updatePerioxesTable(info[1], nomos,connection);
					System.out.println(id);
					System.out.println("NEW ID   ="+id);
					System.out.println("UpdatePerioxesTable   :"+info[1]);
					perioxh = new IdDescription(id,info[1]);
				}
				
			   } // Allagh sta IF Parakatw htan (perioxh!=null)
	

			if (perioxh!=null){
				 SearchInfo searchInfo = new SearchInfo();
				if (advType==AnnKeywords.SELL_HOUSE_CODE)
				{
					searchInfo.setSold(true);
				}
				if (advType==AnnKeywords.RENT_HOUSE_CODE){
					searchInfo.setOffer(1);
				}
				if(advType==AnnKeywords.SELL_EARTH_CODE)
				{
					searchInfo.setSold(true);
				}
			    searchInfo.setCategory(new IdDescription(advType));
			    searchInfo.setDate(new java.sql.Date(System.currentTimeMillis()));
			    searchInfo.setNomos(new IdDescription(nomos));
			    //searchInfo.setOffer(1);
			    searchInfo.setPerioxh(perioxh);
			    searchInfo.setSourceId(AnnKeywords.KATHIMERINI);
			    searchInfo.setSearchId(DatabaseUpdateManager.updateSearchTable(searchInfo,connection));
				ReadSource advsReadSource = new ReadSource(MAIN_URL + info[0],
						AnnKeywords.KATHIMERINI);
				String advsSource = advsReadSource.getSource();
				String advsText = Utilities.getText(advsSource, ADVS_START_TAG,
						ADVS_END_TAG);
				String[] advs = advsText.split(DEVIDE_TAG);

	
			if ((advType == AnnKeywords.SELL_HOUSE_CODE)|| (advType == AnnKeywords.RENT_HOUSE_CODE)) {
				for (String adv : advs) {
					HouseAnnouncement houseAnn = new HouseAnnouncement();
					houseAnn.setMainArea(new IdDescription(perioxh.getId(), info[1]));
					houseAnn.setRent(isRent);
				//	System.out.println(houseAnn);
					KathimeriniHouseFeatExtr featExtr = new KathimeriniHouseFeatExtr(adv, houseAnn, 0, connection);
					featExtr.editAnnFeatures();
					houseAnn = featExtr.getFeatures();
					System.out.println("ANN:"+houseAnn);
					
				DatabaseUpdateManager.updateHouseAnnTable(new Announcement(),houseAnn,searchInfo.getSearchId(),advType,connection);
				}//for
			}//if
	
			else {
				for (String adv : advs) {
					PlotSellingAnnouncement plotAnn = new PlotSellingAnnouncement();
					plotAnn.setMainAreaType(new IdDescription(id, info[1]));
					KathimeriniEarthFeatExtr featExtr = new KathimeriniEarthFeatExtr(adv, plotAnn, 0, connection);
					featExtr.editAnnFeatures();
					plotAnn = featExtr.getFeatures();
				//	System.out.println("ANN:"+plotAnn);
					DatabaseUpdateManager.updateSellEarthAnnTable(new Announcement(),plotAnn,searchInfo.getSearchId(),connection);
				}//for
			}//else

			}//if	
		}//for
		}
	}//advextraction
	//*********************************************************************************************************************
	//fixPerioxes() Method .Checks if MainArea Of Advertisment Already exists on Database
	//*********************************************************************************************************************
	private IdDescription fixPerioxes(String perioxh,ArrayList<IdDescription> areaNames) {
		for (IdDescription areaName : areaNames) {
			//System.out.println(areaName.getDescription());
			if (areaName.getDescription().equals(perioxh)
					|| WordUtilities.findDistance(areaName.getDescription(),
							perioxh) <= 1
					|| areaName.getDescription().toUpperCase().equals(perioxh)
					|| perioxh.toUpperCase().equals(areaName.getDescription())
					|| WordUtilities.findDistance(perioxh.toUpperCase(), areaName
							.getDescription().toUpperCase()) <= 1) 
				{
				System.out.println("Area Already Exists"+ areaName);
				return areaName;
			}
		}
		return null;
	}
	//*********************************************************************************************************************
	//*********************************************************************************************************************
	//OpenMySQLConnection() Method.Establishes  A New Connection With Database
	//*********************************************************************************************************************
	protected boolean openMySQLConnection() {
			try {
				Class.forName("com.mysql.jdbc.Driver");
				Properties props = new Properties();
				props.put("user", "root");
				props.put("password", "");
				props.put("useUnicode", "true");
				props.put("characterEncoding", "utf-8");
				connection = DriverManager.getConnection(
						"jdbc:mysql://localhost:3306/temp09062009", props);
				/*connection = DriverManager.getConnection(
						"jdbc:mysql://localhost/temp09062009", props);*/
				return true;
			} catch (Exception e) {
				e.printStackTrace();
			System.out.	println("ERROR: Failed to get connection to database!");
				return false;
			}
		}	
	
	
	
	
public static void main(String args[]) {
	System.out.println("\t \t \t **************************************************");
	System.out.println(" \t\t\t *\t\tStarting Kathimerini              *");
	System.out.println("\t \t \t **************************************************");
	KathimeriniTest advs1 = new KathimeriniTest();
	System.out.println("\t \t \t **************************************************");
	System.out.println(" \t\t\t *\t\tFinishing Kathimerini             *");
	System.out.println("\t \t \t **************************************************");
	}
}
