package crawling.neomesitikh;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.database.DatabaseSelectManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.SearchInfo;
import crawling.*;

public class NeomesitikhHouseFeatExtraction extends HouseFeatExtr {


	private SearchInfo searchInfo;

	public NeomesitikhHouseFeatExtraction(Connection connection,
			String advFullText) {
		super(0, advFullText, connection);
	}

	protected void editAnnFeatures() {
		announcement = announcement.replace(AnnKeywords.PWLEITAI, "");
		announcement = announcement.replace(AnnKeywords.PWLEITAI1,"");
		annFeatures.setOtherFeatures(announcement);
		searchInfo = new SearchInfo();
		searchInfo.setOffer(1);
		String[] annPieces = announcement.split(",");
		DoubleStringFormat embadon = null;
		String bedrooms = null;
		setAreas(annPieces[0]);
		if (mainAreaType != null) {
			String price = getPrice();
			if (!price.equals("")) {
				Double priceNum = Utilities.toNumber(price);
				annFeatures.setPrice(priceNum);
				announcement = announcement.replace(AnnKeywords.TIMH_PLUS, "");
				announcement = announcement.replace(AnnKeywords.EYRW, "");
				announcement = announcement.replace(price, "");
				annFeatures.setOtherFeatures(announcement);
			}
			boolean isMezoneta = false;
			IdDescription typeOfHouse;
			annPieces = announcement.split(",");
			for (String piece : annPieces) {
				typeOfHouse = getType(piece.split(" "), DatabaseSelectManager
						.getTypesOfHouse(getConnection()));
				if (typeOfHouse != null) {
					if (typeOfHouse.getDescription().equals(
							AnnKeywords.MEZONETA)) {
						isMezoneta = true;
					}
					annFeatures.setType(typeOfHouse);
					announcement = announcement.replace(typeOfHouse
							.getDescription(), "");
					annFeatures.setOtherFeatures(announcement);
					break;
				}
			}

			ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
			annPieces = announcement.split(",");
			for (String piece : annPieces) {
				orofoi = getOrofoys(piece.split(" "), isMezoneta);
				if (orofoi != null) {
					annFeatures.setOrofoi(orofoi);
					for (Integer orf : orofoi) {
						announcement = announcement.replace(orf + "ïò", "");
						announcement = announcement.replace(orf + "ïõ", "");
					}
					announcement = announcement.replace(AnnKeywords.OROFOS, "");
					announcement = announcement
							.replace(AnnKeywords.ISOGEIO, "");
					announcement = announcement.replace(
							AnnKeywords.ISOGEIO_XWRIS, "");
					announcement = announcement
							.replace(AnnKeywords.YPOGEIO, "");
					announcement = announcement.replace(AnnKeywords.HMIOROFOS,
							"");
					annFeatures.setOtherFeatures(announcement);
					break;
				}
			}

			annPieces = announcement.split(",");
			for (String piece : annPieces) {
				bedrooms = getBedRooms(piece.split(" "));
				if (bedrooms != null) {
					try {
						annFeatures.setRoomNumber(bedrooms.trim());
					} catch (NumberFormatException ex) {
						System.out.println(bedrooms + " :IS NOT A NUMBER!!!");
						ex.printStackTrace();
					}
					announcement = announcement.replace(bedrooms + " "
							+ AnnKeywords.YD, "");
					annFeatures.setOtherFeatures(announcement);
					break;
				}
			}

			annPieces = announcement.split(" ");
			embadon = getEmbadon(annPieces);
			if (embadon != null) {
				announcement = announcement.replace(embadon.getStringFormat(),
						"");
				annFeatures.setEmbadon(embadon);
				annFeatures.setOtherFeatures(announcement);
			}
			announcement = annFeatures.getOtherFeatures();
			announcement = announcement.replace(", ,", "");
			announcement = announcement.replace(",  ,", "");
			announcement = announcement.replace(" ,   , ", "");
			announcement = announcement.replace(" ,    ,", "");
			announcement = announcement.replace("()", "");

			char[] characters = announcement.toCharArray();
			int i = 0;
			int j = characters.length - 1;
			while ((i < characters.length)
					&& (Character.isWhitespace(characters[i])
							|| (characters[i] == ',') || (characters[i] == '-'))) {
				i++;
			}
			while ((j >= 0)
					&& (Character.isWhitespace(characters[j])
							|| (characters[j] == ',') || (characters[j] == '-'))) {
				j--;
			}
			if (j <= 0) {
				announcement = "";
			} else {
				announcement = announcement.substring(i, j);
			}
			annFeatures.setOtherFeatures(announcement);

		}else{
			annFeatures=null;
		}
		

	}

	protected void setAreas(String areaPiece) {
		ArrayList<IdDescription> perioxesOfNomosAttikhs = DatabaseSelectManager
				.getPerioxesOfNomos(AnnKeywords.ATTIKH_ID, getConnection());
		boolean isAlreadyFind = false;
		for (IdDescription mainArea : perioxesOfNomosAttikhs) {
			if (areaPiece.contains(mainArea.getDescription())
					|| areaPiece.contains(mainArea.getDescription()
							.toLowerCase())) {
				mainAreaType.setDescription(mainArea.getDescription());
				mainAreaType.setId(mainArea.getId());
				isAlreadyFind = true;
				searchInfo.setDiamerisma(new IdDescription(
						AnnKeywords.STELLADA_BEYBOIA_ID));
				searchInfo.setNomos(new IdDescription(AnnKeywords.ATTIKH_ID));
				break;
			}
		}
		if (!isAlreadyFind) {
			ArrayList<IdDescription> diamerismata = DatabaseSelectManager
					.getDiamerismata(getConnection());
			for (IdDescription diam : diamerismata) {
				ArrayList<IdDescription> nomoi = DatabaseSelectManager
						.getNomoysOfDiamerismata(diam.getId(), getConnection());
				for (IdDescription nomos : nomoi) {
					ArrayList<IdDescription> tempPerioxes = DatabaseSelectManager
							.getPerioxesOfNomos(nomos.getId(), getConnection());
					for (IdDescription mainArea : tempPerioxes) {
						if (areaPiece.contains(mainArea.getDescription())
								|| areaPiece.contains(mainArea.getDescription()
										.toLowerCase())) {
							mainAreaType.setDescription(mainArea
									.getDescription());
							mainAreaType.setId(mainArea.getId());
							isAlreadyFind = true;
							searchInfo.setDiamerisma(diam);
							searchInfo.setNomos(nomos);
							break;
						}
					}
				}
			}
		}
		if (mainAreaType.getDescription() != null) {
			announcement = announcement.replace(mainAreaType.getDescription(),
					"");
			announcement = announcement.replace(mainAreaType.getDescription()
					.toLowerCase(), "");
			annFeatures.setMainArea(mainAreaType);
			areaPiece = areaPiece.replace(mainAreaType.getDescription(), "");
			areaPiece = areaPiece.replace(mainAreaType.getDescription()
					.toLowerCase(), "");
		} else {
			mainAreaType = null;
		}
		secondArea = areaPiece;
		if (secondArea != null && !secondArea.equals("")
				&& !secondArea.equals(" ")) {
			announcement = announcement.replace(secondArea, "");
			annFeatures.setSecArea(secondArea);
			annFeatures.setOtherFeatures(announcement);
		}

	}

	protected String getPrice() {
		String price = "";
		if (announcement.contains(AnnKeywords.TIMH_PLUS)) {
			int startPoint = announcement.indexOf(AnnKeywords.TIMH_PLUS);
			String tempString = announcement.substring(startPoint, announcement
					.length());
			String[] tempArray = tempString.split(" ");
			if (tempArray.length >= 2) {
				price = tempArray[1];
			}
		}else if (announcement.contains(AnnKeywords.TIMH)) {
			int startPoint = announcement.indexOf(AnnKeywords.TIMH);
			String tempString = announcement.substring(startPoint, announcement
					.length());
			String[] tempArray = tempString.split(" ");
			if (tempArray.length >= 2) {
				price = tempArray[1];
			}
		}	
		return price;
	}

	public HouseAnnouncement getHouseAnn() {
		return annFeatures;
	}

	public void setHouseAnn(HouseAnnouncement houseAnn) {
		this.annFeatures = houseAnn;
	}

	public SearchInfo getSearchInfo() {
		return searchInfo;
	}

	public void setSearchInfo(SearchInfo searchInfo) {
		this.searchInfo = searchInfo;
	}
}
