package crawling.xe;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.Auction;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.SearchInfo;
import crawling.*;
public class AuctionFeatExtr extends AnnFeatExtraction {

	private Auction auction;

	private SearchInfo searchInfo;

	public AuctionFeatExtr(int nomosId, String announcementText,
			Connection connection, SearchInfo searchInfo) {
		super(nomosId, announcementText, connection);
		auction = new Auction();
		auction.setOtherFeatures(announcement);
		this.searchInfo = searchInfo;
		searchInfo.setOffer(1);
		editAnnFeatures();
	}

	/**
	 * Edit the announcement and does the announcement feature extraction
	 * 
	 * @Override
	 */
	protected void editAnnFeatures() {
		// String[] annPieces = announcement.split(",");
		// String areaPiece = annPieces[0];
		// setAreas(areaPiece);
		setMainArea();
		if(mainAreaType.getDescription()!=null){
				announcement = announcement.replace(mainAreaType.getDescription(), "");
				announcement = announcement.replace(mainAreaType.getDescription().toLowerCase(),"");
		auction.setMainAreaType(mainAreaType);
		String price = getStartPrice();
		if(!price.equals("")){
			Double priceNum = Utilities.toNumber(price);
				auction.setPrice(priceNum);
			announcement = announcement.replace(AnnKeywords.TIMH_EKKINHSHS, "");
			announcement = announcement.replace(AnnKeywords.EYRW, "");
			announcement = announcement.replace(price, "");
			auction.setOtherFeatures(announcement);
		}
		String percentage=getPercentage();
		if(!percentage.equals("")){
			auction.setPercentage(percentage);
			announcement = announcement.replace(AnnKeywords.POSOSTO_SYNIDIOKTHSIAS,"");
			announcement = announcement.replace(percentage,"");
		}
		String odos=getOdos();
		if(!odos.equals("")){
			auction.setSecArea(odos);
			announcement=announcement.replace(odos,"");
		}
		String[] tempArray=announcement.split(" ");
		IdDescription type = getType(tempArray,DatabaseSelectManager.getTypesOfAuction(getConnection()));
		if(type!=null){
			auction.setType(type);
		}
		auction.setOtherFeatures(announcement);
		}else{
			auction=null;
		}
	}

	protected void setMainArea() {
		ArrayList<IdDescription> perioxesOfNomosAttikhs = DatabaseSelectManager
				.getPerioxesOfNomos(AnnKeywords.ATTIKH_ID, getConnection());
		boolean isAlreadyFind = false;
		for (IdDescription mainArea : perioxesOfNomosAttikhs) {
			if (announcement.contains(mainArea.getDescription())
					|| announcement.contains(mainArea.getDescription()
							.toLowerCase())) {
				mainAreaType.setDescription(mainArea.getDescription());
				mainAreaType.setId(mainArea.getId());
				isAlreadyFind = true;
				searchInfo.setDiamerisma(new IdDescription(AnnKeywords.STELLADA_BEYBOIA_ID));
				searchInfo.setNomos(new IdDescription(AnnKeywords.ATTIKH_ID));
				break;
			}
		}
		if (!isAlreadyFind) {
			ArrayList<IdDescription> diamerismata = DatabaseSelectManager
					.getDiamerismata(getConnection());
			for (IdDescription diam : diamerismata) {
				ArrayList<IdDescription> nomoi = DatabaseSelectManager
						.getNomoysOfDiamerismata(diam.getId(), getConnection());
				for (IdDescription nomos : nomoi) {
					ArrayList<IdDescription> tempPerioxes = DatabaseSelectManager
							.getPerioxesOfNomos(nomos.getId(), getConnection());
					for (IdDescription mainArea : tempPerioxes) {
						if (announcement.contains(mainArea.getDescription())
								|| announcement.contains(mainArea
										.getDescription().toLowerCase())) {
							mainAreaType.setDescription(mainArea
									.getDescription());
							mainAreaType.setId(mainArea.getId());
							isAlreadyFind = true;
							searchInfo.setDiamerisma(diam);
							searchInfo.setNomos(nomos);
							break;
						}
					}
				}
			}
		}
	}

	
	protected String getStartPrice(){
		String price="";
		if(announcement.contains(AnnKeywords.TIMH_EKKINHSHS)){
			int startPoint = announcement.indexOf(AnnKeywords.TIMH_EKKINHSHS);
			String tempString = announcement.substring(startPoint,announcement.length());
			String[] tempArray = tempString.split(" ");
			if(tempArray.length>=3){
				price=tempArray[2];
			}
		}
		return price;
	}
	
	protected String getPercentage(){
		String percentage="";
		if(announcement.contains(AnnKeywords.POSOSTO_SYNIDIOKTHSIAS)){
			int startPoint = announcement.indexOf(AnnKeywords.POSOSTO_SYNIDIOKTHSIAS);
			String tempString = announcement.substring(startPoint,announcement.length());
			String[] tempArray = tempString.split(" ");
			if(tempArray.length>=9){
				percentage=tempArray[8];
			}
		}
		return percentage;
	}
	
	protected String getOdos(){
		String odos="";
		int startPoint=-1;
		String tempString="";
		if(announcement.contains(AnnKeywords.EPI_THS_ODOY)){
			startPoint=announcement.indexOf(AnnKeywords.EPI_THS_ODOY);
			tempString=announcement.substring(startPoint,announcement.length());
			String[] tempArray = tempString.split(" ");
			if(tempArray.length>=4){
				odos+=AnnKeywords.EPI_THS_ODOY;
				odos+=" "+tempArray[3];
				if(tempArray.length>=5){
					char[] tempChars = tempArray[4].toCharArray();
					if(Character.isUpperCase(tempChars[0])&& tempArray[4].length()>2){
						odos+=" "+tempArray[4];
						if(tempArray.length>=6){
							tempChars = tempArray[5].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray[5].length()>2){
								odos+=" "+tempArray[5];
							}else if(tempArray[5].equals("êáé")){
								odos+=" "+tempArray[6];
								if(tempArray.length>=8){
									tempChars = tempArray[7].toCharArray();
									if(Character.isUpperCase(tempChars[0])&& tempArray[7].length()>2){
										odos+=" "+tempArray[7];
									}
								}
							}
						}
					}else if(tempArray[4].equals("êáé")){
						odos+=" "+tempArray[4];
						odos+=" "+tempArray[5];
						if(tempArray.length>=7){
							tempChars = tempArray[6].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray[6].length()>2){
								odos+=" "+tempArray[6];
							}
						}
					}
					
				}
			}
			return odos;
		}
		if(announcement.contains(AnnKeywords.EPI_THS_LEWFOROY)){
			startPoint=announcement.indexOf(AnnKeywords.EPI_THS_LEWFOROY);
			tempString=announcement.substring(startPoint,announcement.length());
			String[] tempArray = tempString.split(" ");
			if(tempArray.length>=4){
				odos+=AnnKeywords.EPI_THS_LEWFOROY;
				odos+=" "+tempArray[3];
				if(tempArray.length>=5){
					char[] tempChars = tempArray[4].toCharArray();
					if(Character.isUpperCase(tempChars[0])&& tempArray[4].length()>2){
						odos+=" "+tempArray[4];
						if(tempArray.length>=6){
							tempChars = tempArray[5].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray[5].length()>2){
								odos+=" "+tempArray[5];
							}else if(tempArray[5].equals("êáé")){
								odos+=" "+tempArray[6];
								if(tempArray.length>=8){
									tempChars = tempArray[7].toCharArray();
									if(Character.isUpperCase(tempChars[0])&& tempArray[7].length()>2){
										odos+=" "+tempArray[7];
									}
								}
							}
						}
					}else if(tempArray[4].equals("êáé")){
						odos+=" "+tempArray[4];
						odos+=" "+tempArray[5];
						if(tempArray.length>=7){
							tempChars = tempArray[6].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray[6].length()>2){
								odos+=" "+tempArray[6];
							}
						}
					}
					
				}
			}
			return odos;
		}
		if(announcement.contains(AnnKeywords.EPI_TWN_ODWN)){
			startPoint=announcement.indexOf(AnnKeywords.EPI_TWN_ODWN);
			tempString =announcement.substring(startPoint,announcement.length());
			String[] tempArray1 = tempString.split(" ");
			if(tempArray1.length>=4){
				odos+=AnnKeywords.EPI_TWN_ODWN;
				odos+=" "+tempArray1[3];
				if(tempArray1.length>=5){
					char[] tempChars = tempArray1[4].toCharArray();
					if(Character.isUpperCase(tempChars[0])&& tempArray1[4].length()>2){
						odos+=" "+tempArray1[4];
						if(tempArray1.length>=6){
							tempChars = tempArray1[5].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray1[5].length()>2){
								odos+=" "+tempArray1[5];
							}else if(tempArray1[5].equals("êáé")){
								odos+=" "+tempArray1[6];
								if(tempArray1.length>=8){
									tempChars = tempArray1[7].toCharArray();
									if(Character.isUpperCase(tempChars[0])&& tempArray1[7].length()>2){
										odos+=" "+tempArray1[7];
									}
								}
							}
						}
					}else if(tempArray1[4].equals("êáé")){
						odos+=" "+tempArray1[4];
						odos+=" "+tempArray1[5];
						if(tempArray1.length>=7){
							tempChars = tempArray1[6].toCharArray();
							if(Character.isUpperCase(tempChars[0])&& tempArray1[6].length()>2){
								odos+=" "+tempArray1[6];
							}
						}
					}
					
				}
			}
			return odos;
		}
		return odos;
	}
	
	protected IdDescription getType(String[] text,
			ArrayList<IdDescription> types) {
		for (String txt : text) {
			for (IdDescription type : types) {
				if (txt.equals(type.getDescription())||WordUtilities.findDistance(txt,type.getDescription())<=3) {
					announcement=announcement.replace(txt,"");
					return type;
				}
			}
		}
		return null;
	}

	public Auction getAuction() {
		return auction;
	}

	public void setAuction(Auction auction) {
		this.auction = auction;
	}

	public SearchInfo getSearchInfo() {
		return searchInfo;
	}

	public void setSearchInfo(SearchInfo searchInfo) {
		this.searchInfo = searchInfo;
	}
}
