package crawling.xe;

import java.sql.Connection;
import java.util.ArrayList;

import crawling.AnnKeywords;
import crawling.Utilities;
import crawling.WordUtilities;
import crawling.database.DatabaseSelectManager;
import crawling.database.DatabaseUpdateManager;
import crawling.entities.DoubleStringFormat;
import crawling.entities.HouseAnnouncement;
import crawling.entities.IdDescription;
import crawling.entities.SearchInfo;
import crawling.*;
public class EkswxikaFeatExtr extends AnnFeatExtraction {

	private SearchInfo searchInfo;

	private HouseAnnouncement annFeatures;

	public EkswxikaFeatExtr(int nomosId, String announcementText,
			Connection connection, SearchInfo searchInfo) {
		super(nomosId, announcementText, connection);
		annFeatures = new HouseAnnouncement();
		annFeatures.setOtherFeatures(announcement);
		this.searchInfo = searchInfo;
		searchInfo.setOffer(1);
		editAnnFeatures();
	}

	/**
	 * Edit the announcement and does the announcement feature extraction
	 * 
	 * @Override
	 */
	protected void editAnnFeatures() {
		String[] annPieces = announcement.split(",");
		String areaPiece = annPieces[0];
		setAreas(areaPiece);
		DoubleStringFormat embadon = null;
		String bedrooms = null;
		String price = null;
		String otherFeatures = annFeatures.getOtherFeatures();

		annPieces = otherFeatures.split(",");
		for (String piece : annPieces) {
			price = getPrice(piece.split(" "));
			if (price != null) {
				String priceNum = Utilities.getOnlyNumbers(price);
				if (!priceNum.equals("")) {
					annFeatures.setPrice(Double.parseDouble(priceNum));
					otherFeatures = otherFeatures.replace(AnnKeywords.TIMH, "");
					otherFeatures = otherFeatures.replace(AnnKeywords.EYRW, "");
					otherFeatures = otherFeatures.replace(price, "");
					annFeatures.setOtherFeatures(otherFeatures);
					break;
				}
			}
		}

		boolean isMezoneta = false;
		IdDescription typeOfHouse;
		annPieces = otherFeatures.split(",");
		for (String piece : annPieces) {
			typeOfHouse = getType(piece.split(" "), DatabaseSelectManager
					.getTypesOfHouse(getConnection()));
			if (typeOfHouse != null) {
				if (typeOfHouse.getDescription().equals(AnnKeywords.MEZONETA)) {
					isMezoneta = true;
				}
				annFeatures.setType(typeOfHouse);
				otherFeatures = otherFeatures.replace(typeOfHouse
						.getDescription(), "");
				annFeatures.setOtherFeatures(otherFeatures);
				break;
			}
		}

		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
		annPieces = otherFeatures.split(",");
		for (String piece : annPieces) {
			orofoi = getOrofoys(piece.split(" "), isMezoneta);
			if (orofoi != null) {
				annFeatures.setOrofoi(orofoi);
				for (Integer orf : orofoi) {
					otherFeatures = otherFeatures.replace(orf + "ïò", "");
					otherFeatures = otherFeatures.replace(orf + "ïõ", "");
				}
				otherFeatures = otherFeatures.replace(AnnKeywords.OROFOS, "");
				otherFeatures = otherFeatures.replace(AnnKeywords.ISOGEIO, "");
				otherFeatures = otherFeatures.replace(
						AnnKeywords.ISOGEIO_XWRIS, "");
				otherFeatures = otherFeatures.replace(AnnKeywords.YPOGEIO, "");
				otherFeatures = otherFeatures
						.replace(AnnKeywords.HMIOROFOS, "");
				annFeatures.setOtherFeatures(otherFeatures);
				break;
			}
		}

		annPieces = otherFeatures.split(",");
		for (String piece : annPieces) {
			bedrooms = getBedRooms(piece.split(" "));
			if (bedrooms != null) {
				try {
					annFeatures.setRoomNumber(bedrooms.trim());
				} catch (NumberFormatException ex) {
					System.out.println(bedrooms + " :IS NOT A NUMBER!!!");
					ex.printStackTrace();
				}
				otherFeatures = otherFeatures.replace(bedrooms + " "
						+ AnnKeywords.YD, "");
				annFeatures.setOtherFeatures(otherFeatures);
				break;
			}
		}

		annPieces = otherFeatures.split(" ");
		embadon = getEmbadon(annPieces);
		if (embadon != null) {
			otherFeatures = otherFeatures
					.replace(embadon.getStringFormat(), "");
			annFeatures.setEmbadon(embadon);
			annFeatures.setOtherFeatures(otherFeatures);
		}
		otherFeatures = annFeatures.getOtherFeatures();
		otherFeatures = otherFeatures.replace(", ,", "");
		otherFeatures = otherFeatures.replace(",  ,", "");
		otherFeatures = otherFeatures.replace(" ,   , ", "");
		otherFeatures = otherFeatures.replace(" ,    ,", "");
		otherFeatures = otherFeatures.replace("()", "");

		char[] characters = otherFeatures.toCharArray();
		int i = 0;
		int j = characters.length - 1;
		while ((i < characters.length)
				&& (Character.isWhitespace(characters[i])
						|| (characters[i] == ',') || (characters[i] == '-'))) {
			i++;
		}
		while ((j >= 0)
				&& (Character.isWhitespace(characters[j])
						|| (characters[j] == ',') || (characters[j] == '-'))) {
			j--;
		}
		if (j <= 0) {
			otherFeatures = "";
		} else {
			otherFeatures = otherFeatures.substring(i, j);
		}
		annFeatures.setOtherFeatures(otherFeatures);
	}

//	/**
//	 * Returns an <code>ArrayList</code> of the levels of the house found in
//	 * the text in case of mezoneta there are 2 levels
//	 * 
//	 * @param text
//	 * @param isMezoneta
//	 * @returnan <code>ArrayList</code> of the levels of the house found in
//	 *           the text in case of mezoneta
//	 */
//	protected ArrayList<Integer> getOrofoys(String[] text, boolean isMezoneta) {
//		ArrayList<Integer> orofoi = new ArrayList<Integer>(0);
//		for (int i = 0; i < text.length; i++) {
//			if (text[i].trim().equals(AnnKeywords.OROFOS)) {
//				if (isMezoneta && i - 3 >= 0 && text[i - 2].equals("-")) {
//					Integer temp = getOrofos(text[i - 3].trim());
//					if (temp != null) {
//						orofoi.add(temp);
//					}
//					Integer temp2 = getOrofos(text[i - 1].trim());
//					if (temp2 != null) {
//						orofoi.add(temp2);
//					}
//					return orofoi;
//				}
//				if (isMezoneta && i - 1 > 0) {
//					String tmp = text[i - 1].trim();
//					String[] tmpArray = tmp.split("-");
//					if (tmpArray.length > 1) {
//						for (String tmp1 : tmpArray) {
//							Integer num = getOrofos(tmp1.trim());
//							if (num != null) {
//								orofoi.add(num);
//							}
//						}
//						return orofoi;
//					}
//				}
//				Integer temp3 = getOrofos(text[i - 1].trim());
//				if (temp3 != null) {
//					orofoi.add(temp3);
//				}
//				return orofoi;
//			}
//			if (text[i].equals(AnnKeywords.ISOGEIO)
//					|| text[i].equals(AnnKeywords.YPOGEIO)
//					|| text[i].equals(AnnKeywords.ISOGEIO_XWRIS)) {
//				if (isMezoneta && i + 2 < text.length
//						&& text[i + 1].equals("-")) {
//					Integer temp4 = getOrofos(text[i].trim());
//					if (temp4 != null) {
//						orofoi.add(temp4);
//					}
//					Integer temp5 = getOrofos(text[i + 2].trim());
//					if (temp5 != null) {
//						orofoi.add(temp5);
//					}
//					return orofoi;
//				}
//				if (isMezoneta && i + 1 < text.length) {
//					String tmp = text[i + 1].trim();
//					String[] tmpArray = tmp.split("-");
//					if (tmpArray.length > 1) {
//						for (String tmp1 : tmpArray) {
//							Integer num = getOrofos(tmp1.trim());
//							if (num != null) {
//								orofoi.add(num);
//							}
//						}
//						return orofoi;
//					}
//				}
//				Integer temp6 = getOrofos(text[i].trim());
//				if (temp6 != null) {
//					orofoi.add(temp6);
//				}
//				return orofoi;
//			}
//		}
//		return null;
//	}
//
//	protected Integer getOrofos(String temp) {
//		if (temp.endsWith("��") || temp.endsWith("��")) {
//			temp = temp.substring(0, temp.length() - 2);
//			try {
//				Integer orf = Integer.parseInt(temp.trim());
//				return orf;
//			} catch (NumberFormatException ex) {
//				return null;
//			}
//		}
//		if (temp.equals(AnnKeywords.ISOGEIO)
//				|| temp.equals(AnnKeywords.ISOGEIO_XWRIS)) {
//			return 0;
//		}
//		if (temp.equals(AnnKeywords.YPOGEIO)) {
//			return -1;
//		}
//		return null;
//	}

//	/**
//	 * Returns number of bedrooms in a house
//	 * 
//	 * @param text
//	 * @return number of bedrooms in a house
//	 */
//	protected String getBedRooms(String[] text) {
//		for (int i = 0; i < text.length; i++) {
//			if (text[i].equals(AnnKeywords.YD)
//					|| text[i].equals(AnnKeywords.YPNODWMATIA)
//					|| text[i].equals(AnnKeywords.KREBATOKAMARES)
//					|| text[i].equals(AnnKeywords.YPNO)) {
//				return text[i - 1];
//			}
//		}
//		return null;
//	}

	protected void setAreas(String areaPiece) {
		String mainArea;
		// we take every word of the areaPiece
		String[] pieces = areaPiece.split(" ");
		secondArea = null;
		// in every announcement the first word is the main area
		mainArea = pieces[0].trim();
		int size = pieces.length;
		// we do more only if there are more words until the ,
		if (size > 1) {
			String secondWord = pieces[1];
			// some times second word is part of the main area
			// we can understand that if the second word is upper case too
			char[] chars = secondWord.toCharArray();
			boolean isDigit = false;
			if (chars != null && chars.length > 0) {
				isDigit = Character.isDigit(chars[0]);
			}
			if (!isDigit && Character.isLetter(chars[0])
					&& secondWord.toUpperCase() == secondWord
					&& !secondWord.endsWith(".") && !secondWord.endsWith("'")
					&& !secondWord.startsWith("-")) {
				mainArea += " " + secondWord.trim();
				/** ****************************************************** */
				if (size > 2) {
					String thirdWord = pieces[2];
					if (thirdWord.startsWith("(")) {
						// secondArea = secondWord.substring(1);
						for (int i = 2; i < size; i++) {
							String temp = pieces[i];
							if (temp.startsWith("(")) {
								temp = temp.replace("(", "");
							}
							if (temp.endsWith(")")) {
								temp = temp.replace(")", "");
								if (secondArea == null) {
									secondArea = temp;
								} else {
									secondArea += " " + temp;
								}
								break;
							}
							if (secondArea == null) {
								secondArea = temp;
							} else {
								secondArea += " " + temp;
							}
						}
					} else {
						// if thirdWord isn't part of the main area
						// we check if the thirdWord is one of the keywords if
						// so
						// this meens that there is a second area after that or
						// this
						// is the second area
						for (String keyWord : AnnKeywords.SECONDAREA_KEYWORDS) {
							if (keyWord.equals(thirdWord)) {
								secondArea = thirdWord;
								break;
							}
						}
						// if second word isn't one of the keywords we check if
						// this word
						// starts with an upper case character if so we claim
						// that it is part
						// of second area
						if (secondArea == null) {
							char[] secWrdChars = thirdWord.toCharArray();
							if (secWrdChars.length > 0
									&& Character.isUpperCase(secWrdChars[0])) {
								secondArea = thirdWord;
								for (int i = 3; i < size; i++) {
									secondArea += " " + pieces[i];
								}
							}
							// // if size of the pieces' table is 3 and previous
							// // word is
							// // second area third word is second area too.
							// if (size == 4 && secondArea != null) {
							// secondArea += " " + pieces[3];
							// }
							// if the previous word is a keyword then all the
							// other words are
							// second area

						} else {
							// if the previous word is a keyword then all the
							// other words are
							// second area
							for (int i = 3; i < size; i++) {
								secondArea += " " + pieces[i];
							}
						}
					}
				}
				/** ******************************************************************** */
			} else {
				// there is a possibility that second area is between ()
				if (secondWord.startsWith("(")) {
					// secondArea = secondWord.substring(1);
					for (int i = 1; i < size; i++) {
						String temp = pieces[i];
						if (temp.startsWith("(")) {
							temp = temp.replace("(", "");
						}
						if (temp.endsWith(")")) {
							temp = temp.replace(")", "");
							if (secondArea == null) {
								secondArea = temp;
							} else {
								secondArea += " " + temp;
							}
							break;
						}
						if (secondArea == null) {
							secondArea = temp;
						} else {
							secondArea += " " + temp;
						}
					}
				} else {
					// if secondWord isn't part of the main area
					// we check if the secondWord is one of the keywords if so
					// this meens that there is a second area after that or this
					// is the second area
					for (String keyWord : AnnKeywords.SECONDAREA_KEYWORDS) {
						if (keyWord.equals(secondWord)) {
							secondArea = secondWord;
							break;
						}
					}
					// if second word isn't one of the keywords we check if this
					// word
					// starts with an upper case character if so we claim that
					// it is part
					// of second area
					if (secondArea == null) {
						char[] secWrdChars = secondWord.toCharArray();
						if (Character.isUpperCase(secWrdChars[0])) {
							secondArea = secondWord;
							for (int i = 2; i < size; i++) {
								secondArea += " " + pieces[i];
							}
						}
						// // if size of the pieces' table is 3 and previous
						// word
						// // is
						// // second area third word is second area too.
						// if (size == 3) {
						// secondArea += " " + pieces[2];
						// }
					} else {
						// if the previous word is a keyword then all the other
						// words are
						// second area
						for (int i = 2; i < size; i++) {
							secondArea += " " + pieces[i];
						}
					}
				}
			}
		}
		if (secondArea != null && secondArea.startsWith("-")) {
			secondArea = secondArea.substring(1);
		}
		ArrayList<IdDescription> diamerismata = DatabaseSelectManager
				.getDiamerismata(getConnection());
		for (IdDescription diam : diamerismata) {
			ArrayList<IdDescription> nomoi = DatabaseSelectManager
					.getNomoysOfDiamerismata(diam.getId(), getConnection());
			for (IdDescription nomos : nomoi) {
				ArrayList<IdDescription> tempPerioxes = DatabaseSelectManager
						.getPerioxesOfNomos(nomos.getId(), getConnection());
				for (IdDescription type : tempPerioxes) {
					if (type.getDescription().equals(mainArea) ||
							WordUtilities.findDistance(type.getDescription(),mainArea)<=1 ||
							 type.getDescription().toUpperCase().equals(mainArea)
							 ||mainArea.toUpperCase().equals(type.getDescription())
							 ||WordUtilities.findDistance(mainArea.toUpperCase(),type.getDescription().toUpperCase())<=1) {
						mainAreaType.setDescription(type.getDescription());
						mainAreaType.setId(type.getId());
						searchInfo.setDiamerisma(diam);
						searchInfo.setNomos(nomos);
						break;
					}
				}
			}
		}
		annFeatures.setMainArea(mainAreaType);
		if (secondArea != null) {
			annFeatures.setSecArea(secondArea);
		}
		String otherFeatures = annFeatures.getOtherFeatures();
		if(mainAreaType.getDescription()!=null){
		otherFeatures = otherFeatures.replace(mainAreaType.getDescription(), "");
		}
		if(secondArea != null){
		otherFeatures = otherFeatures.replace(secondArea, "");
		}
		annFeatures.setOtherFeatures(otherFeatures);
	}

	public HouseAnnouncement getAnnFeatures() {
		return annFeatures;
	}

	public void setAnnFeatures(HouseAnnouncement annFeatures) {
		this.annFeatures = annFeatures;
	}

	public SearchInfo getSearchInfo() {
		return searchInfo;
	}

	public void setSearchInfo(SearchInfo searchInfo) {
		this.searchInfo = searchInfo;
	}

}
